@@ -136,6 +136,8 @@ void TypePrettyPrinter::visit(NamedType *type)
     prependSpaceUnlessBracket();
     _text.prepend(overview()->prettyName(type->name()));
     prependCv(_fullySpecifiedType);
+    if (_fullySpecifiedType.isAuto() && _overview->combineAutoAndName)
+        _text.append(" auto"); // Constrained function parameters.
 }
 
 void TypePrettyPrinter::visit(Namespace *type)
@@ -301,6 +303,46 @@ void TypePrettyPrinter::prependSpaceBeforeIndirection(const FullySpecifiedType &
         _text.prepend(QLatin1Char(' '));
 }
 
+QString TypePrettyPrinter::visitTemplateArgumentList(Scope *scope, int paramCount, bool forceNames)
+{
+    QString text = "<";
+    for (int i = 0; i < paramCount; ++i) {
+        Symbol * const param = scope->memberAt(i);
+        if (!param)
+            continue;
+        if (i > 0)
+            text.append(", ");
+        if (TypenameArgument *arg = param->asTypenameArgument()) {
+            text.append(arg->isClassDeclarator() ? "class" : "typename");
+            QString name = _overview->prettyName(arg->name());
+            if (name.isEmpty() && forceNames)
+                name.append('T').append(QString::number(i + 1));
+            if (!name.isEmpty())
+                text.append(' ').append(name);
+        } else if (TemplateTypeArgument *arg = param->asTemplateTypeArgument()) {
+            if (arg->conceptName()) {
+                text.append(_overview->prettyName(arg->conceptName()));
+                if (arg->memberCount())
+                    text.append(visitTemplateArgumentList(arg, arg->memberCount(), false));
+            } else if (arg->memberCount()) {
+                text.append(visitTemplateParameterList(arg, arg->memberCount(), false));
+                text.append(arg->isClassDeclarator() ? " class" : " typename");
+            }
+            if (arg->name())
+                text.append(' ').append(_overview->prettyName(arg->name()));
+        } else if (param->asArgument()) {
+            text.append(_overview->prettyType(param->type(), param->name()));
+        }
+    }
+    return text.append('>');
+
+}
+
+QString TypePrettyPrinter::visitTemplateParameterList(Scope *scope, int paramCount, bool forceNames)
+{
+    return "template" + visitTemplateArgumentList(scope, paramCount, forceNames);
+}
+
 void TypePrettyPrinter::prependSpaceAfterIndirection(bool hasName)
 {
     const bool hasCvSpecifier = _fullySpecifiedType.isConst() || _fullySpecifiedType.isVolatile();
@@ -412,18 +454,20 @@ void TypePrettyPrinter::visit(Function *type)
         _name.clear();
     }
 
-    Overview retAndArgOverview;
-    retAndArgOverview.starBindFlags = _overview->starBindFlags;
-    retAndArgOverview.showReturnTypes = true;
-    retAndArgOverview.showArgumentNames = false;
-    retAndArgOverview.showFunctionSignatures = true;
-    retAndArgOverview.showTemplateParameters = true;
+    Overview argOverview;
+    argOverview.starBindFlags = _overview->starBindFlags;
+    argOverview.showReturnTypes = true;
+    argOverview.showArgumentNames = false;
+    argOverview.showFunctionSignatures = true;
+    argOverview.showTemplateParameters = true;
+    const Overview retOverview = argOverview;
+    argOverview.combineAutoAndName = true;
 
     if (_overview->showReturnTypes) {
         if (_overview->trailingReturnType) {
             _text.prepend("auto ");
         } else {
-            const QString returnType = retAndArgOverview.prettyType(type->returnType());
+            const QString returnType = retOverview.prettyType(type->returnType());
             if (!returnType.isEmpty()) {
                 if (!endsWithPtrOrRef(returnType)
                         || !(_overview->starBindFlags & Overview::BindToIdentifier)) {
@@ -437,28 +481,9 @@ void TypePrettyPrinter::visit(Function *type)
     if (_overview->showEnclosingTemplate) {
         for (auto [s, i] = std::tuple{type->enclosingScope(), nameParts.length() - 1}; s && i >= 0;
              s = s->enclosingScope()) {
-            if (Template *templ = s->asTemplate()) {
-                QString templateScope = "template<";
-                const int paramCount = templ->templateParameterCount();
-                for (int i = 0; i < paramCount; ++i) {
-                    if (Symbol *param = templ->templateParameterAt(i)) {
-                        if (i > 0)
-                            templateScope.append(", ");
-                        if (TypenameArgument *typenameArg = param->asTypenameArgument()) {
-                            templateScope.append(QLatin1String(
-                                typenameArg->isClassDeclarator() ? "class " : "typename "));
-                            QString name = _overview->prettyName(typenameArg->name());
-                            if (name.isEmpty())
-                                name.append('T').append(QString::number(i + 1));
-                            templateScope.append(name);
-                        } else if (Argument *arg = param->asArgument()) {
-                            templateScope.append(operator()(arg->type(),
-                                                            _overview->prettyName(arg->name())));
-                        }
-                    }
-                }
-                if (paramCount > 0)
-                    _text.prepend(templateScope + ">\n");
+            if (Template *templ = s->asTemplate(); templ && templ->templateParameterCount()) {
+                _text.prepend(
+                    visitTemplateParameterList(templ, templ->templateParameterCount(), true) + '\n');
             }
         }
     }
@@ -479,7 +504,7 @@ void TypePrettyPrinter::visit(Function *type)
                 if (_overview->showArgumentNames)
                     name = arg->name();
 
-                _text += retAndArgOverview.prettyType(arg->type(), name);
+                _text += argOverview.prettyType(arg->type(), name);
 
                 if (_overview->showDefaultArguments) {
                     if (const StringLiteral *initializer = arg->initializer()) {
@@ -528,7 +553,7 @@ void TypePrettyPrinter::visit(Function *type)
     }
 
     if (_overview->showReturnTypes && _overview->trailingReturnType) {
-        const QString returnType = retAndArgOverview.prettyType(type->returnType());
+        const QString returnType = retOverview.prettyType(type->returnType());
         if (!returnType.isEmpty())
             _text.append(" -> ").append(returnType);
     }
