@@ -1,17 +1,18 @@
 // Copyright (C) 2018 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
 #include "languageserverprotocol_global.h"
 
+#include <utils/textcodec.h>
+
 #include <QByteArray>
 #include <QCoreApplication>
 #include <QLoggingCategory>
 
 QT_BEGIN_NAMESPACE
 class QBuffer;
-class QTextCodec;
 QT_END_NAMESPACE
 
 namespace LanguageServerProtocol {
@@ -20,17 +21,16 @@ LANGUAGESERVERPROTOCOL_EXPORT Q_DECLARE_LOGGING_CATEGORY(parseLog)
 
 class LANGUAGESERVERPROTOCOL_EXPORT BaseMessage
 {
-    Q_DECLARE_TR_FUNCTIONS(BaseMessage)
 public:
     BaseMessage();
     BaseMessage(const QByteArray &mimeType, const QByteArray &content,
-                int expectedLength, QTextCodec *codec);
+                int expectedLength, const Utils::TextEncoding &codec);
     BaseMessage(const QByteArray &mimeType, const QByteArray &content);
 
     bool operator==(const BaseMessage &other) const;
 
     static void parse(QBuffer *data, QString &parseError, BaseMessage &message);
-    static QTextCodec *defaultCodec();
+    static Utils::TextEncoding defaultEncoding();
 
     bool isComplete() const;
     bool isValid() const;
@@ -39,7 +39,7 @@ public:
     QByteArray mimeType;
     QByteArray content;
     int contentLength = -1;
-    QTextCodec *codec = defaultCodec();
+    Utils::TextEncoding encoding = defaultEncoding();
 
 private:
     QByteArray lengthHeader() const;
