@@ -1,8 +1,10 @@
 // Copyright (C) 2016 Jochen Becher
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "project.h"
 
+using Utils::FilePath;
+
 namespace qmt {
 
 Project::Project()
@@ -23,7 +25,7 @@ bool Project::hasFileName() const
     return !m_fileName.isEmpty();
 }
 
-void Project::setFileName(const QString &fileName)
+void Project::setFileName(const FilePath &fileName)
 {
     m_fileName = fileName;
 }
