@@ -1,30 +1,28 @@
 // Copyright (C) 2019 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
 #include "utils_global.h"
 
-#include "environmentfwd.h"
-
 #include <QPersistentModelIndex>
 #include <QTimer>
 #include <QValidator>
 
 QT_BEGIN_NAMESPACE
 class QModelIndex;
+class QTreeView;
 QT_END_NAMESPACE
 
 namespace Utils {
 
-class NameValueModel;
+class EnvironmentModel;
 
 class QTCREATOR_UTILS_EXPORT NameValueValidator : public QValidator
 {
-    Q_OBJECT
 public:
     NameValueValidator(QWidget *parent,
-                       NameValueModel *model,
+                       EnvironmentModel *model,
                        QTreeView *view,
                        const QModelIndex &index,
                        const QString &toolTipText);
@@ -35,9 +33,10 @@ public:
 
 private:
     const QString m_toolTipText;
-    NameValueModel *m_model;
+    EnvironmentModel *m_model;
     QTreeView *m_view;
     QPersistentModelIndex m_index;
     mutable QTimer m_hideTipTimer;
 };
+
 } // namespace Utils
