@@ -1,16 +1,12 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "networkaccessmanager.h"
 
 #include <QCoreApplication>
-#include <QLibraryInfo>
 #include <QLocale>
 #include <QNetworkReply>
-
-#ifdef Q_OS_UNIX
-#include <sys/utsname.h>
-#endif
+#include <QSysInfo>
 
 /*!
    \class Utils::NetworkAccessManager
@@ -75,5 +71,4 @@ QNetworkReply* NetworkAccessManager::createRequest(Operation op, const QNetworkR
     return QNetworkAccessManager::createRequest(op, req, outgoingData);
 }
 
-
 } // namespace utils
