@@ -15,7 +15,6 @@
 
 QT_BEGIN_NAMESPACE
 class QDebug;
-class QTextCodec;
 QT_END_NAMESPACE
 
 namespace Utils {
@@ -28,6 +27,7 @@ class DeviceProcessHooks;
 class ProcessInterface;
 class ProcessResultData;
 class ProcessRunData;
+class TextEncoding;
 
 class QTCREATOR_UTILS_EXPORT Process final : public QObject
 {
@@ -111,6 +111,9 @@ public:
     bool isRunAsRoot() const;
     void setAbortOnMetaChars(bool abort);
 
+    using ProcessInterfaceCreator = std::function<ProcessInterface *()>;
+    void setProcessInterfaceCreator(const ProcessInterfaceCreator &creator);
+
     void setProcessChannelMode(QProcess::ProcessChannelMode mode);
     QProcess::ProcessChannelMode processChannelMode() const;
 
@@ -144,7 +147,7 @@ public:
     void runBlocking(std::chrono::seconds timeout = std::chrono::seconds(10),
                      EventLoopMode eventLoopMode = EventLoopMode::Off);
 
-    void setCodec(const QTextCodec *codec); // for stdOut and stdErr
+    void setEncoding(const TextEncoding &encoding); // for stdOut and stdErr
     void setUtf8Codec(); // for stdOut and stdErr
     void setUtf8StdOutCodec(); // for stdOut, stdErr uses executable.processStdErrCodec()
 
@@ -225,13 +228,12 @@ public:
     std::function<ProcessInterface *(const FilePath &)> processImplHook;
 };
 
-class QTCREATOR_UTILS_EXPORT ProcessTaskAdapter final : public Tasking::TaskAdapter<Process>
+class ProcessTaskAdapter final
 {
 public:
-    ProcessTaskAdapter();
-    void start() final;
+    QTCREATOR_UTILS_EXPORT void operator()(Process *task, Tasking::TaskInterface *iface);
 };
 
-using ProcessTask = Tasking::CustomTask<ProcessTaskAdapter>;
+using ProcessTask = Tasking::CustomTask<Process, ProcessTaskAdapter>;
 
 } // namespace Utils
