@@ -2,6 +2,8 @@
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "qtcsettings.h"
+
+#include "qtcsettings_p.h"
 #include "store.h"
 
 namespace Utils {
@@ -31,6 +33,19 @@ namespace Utils {
     \sa QSettings::setValue()
 */
 
+/*!
+    Begins the settings group \a prefix, calls the \a function, and ends the settings group.
+
+    \sa beginGroup()
+    \sa endGroup()
+*/
+void QtcSettings::withGroup(const Key &prefix, const std::function<void(QtcSettings *)> &function)
+{
+    beginGroup(prefix);
+    function(this);
+    endGroup();
+}
+
 void QtcSettings::beginGroup(const Key &prefix)
 {
     QSettings::beginGroup(stringFromKey(prefix));
@@ -66,4 +81,41 @@ KeyList QtcSettings::childKeys() const
     return keysFromStrings(QSettings::childKeys());
 }
 
+QtcSettings *theUserSettings = nullptr;
+QtcSettings *theInstallSettings = nullptr;
+
+QtcSettings &userSettings()
+{
+    static QtcSettings fallback;
+    QTC_ASSERT(theUserSettings, return fallback);
+    return *theUserSettings;
+}
+
+QtcSettings &installSettings()
+{
+    static QtcSettings fallback;
+    QTC_ASSERT(theInstallSettings, return fallback);
+    return theInstallSettings ? *theInstallSettings : fallback;
+}
+
+void Internal::SettingsSetup::setupSettings(QtcSettings *userSettings, QtcSettings *installSettings)
+{
+    QTC_CHECK(userSettings);
+    QTC_CHECK(!theUserSettings);
+    theUserSettings = userSettings;
+
+    QTC_CHECK(installSettings);
+    QTC_CHECK(!theInstallSettings);
+    theInstallSettings = installSettings;
+}
+
+void Internal::SettingsSetup::destroySettings()
+{
+    delete theUserSettings;
+    theUserSettings = nullptr;
+
+    delete theInstallSettings;
+    theInstallSettings = nullptr;
+}
+
 } // namespace Utils
