@@ -102,8 +102,8 @@ public:
     void eraseAvd(const IDevice::Ptr &device);
 
     Group m_avdListRecipe{};
-    TaskTreeRunner m_avdListRunner;
-    TaskTreeRunner m_avdDeviceWatcherRunner;
+    SingleTaskTreeRunner m_avdListRunner;
+    SingleTaskTreeRunner m_avdDeviceWatcherRunner;
     std::unique_ptr<Process> m_removeAvdProcess;
     QFileSystemWatcher m_avdFileSystemWatcher;
     Guard m_avdPathGuard;
@@ -299,7 +299,7 @@ AndroidDeviceWidget::AndroidDeviceWidget(const IDevice::Ptr &device)
     formLayout->addRow(Tr::tr("Device name:"), new QLabel(dev->displayName()));
     formLayout->addRow(Tr::tr("Device type:"), new QLabel(dev->deviceTypeName()));
 
-    QLabel *serialNumberLabel = new QLabel;
+    QPointer<QLabel> serialNumberLabel = new QLabel;
     formLayout->addRow(Tr::tr("Serial number:"), serialNumberLabel);
 
     const QString abis = dev->supportedAbis().join(", ");
@@ -325,11 +325,12 @@ AndroidDeviceWidget::AndroidDeviceWidget(const IDevice::Ptr &device)
     }
 
     // See QTCREATORBUG-31912 why this needs to be delayed.
-    QTimer::singleShot(0, this, [serialNumberLabel, dev] {
+    QTimer::singleShot(0, serialNumberLabel, [serialNumberLabel, dev] {
         const QString serialNumber = dev->serialNumber(); // This executes a blocking process.
         const QString printableSerialNumber = serialNumber.isEmpty() ? Tr::tr("Unknown")
                                                                      : serialNumber;
-        serialNumberLabel->setText(printableSerialNumber);
+        if (serialNumberLabel)
+            serialNumberLabel->setText(printableSerialNumber);
     });
 }
 
@@ -600,13 +601,13 @@ void AndroidDevice::startAvd()
             DeviceManager::setDeviceState(id(), IDevice::DeviceReadyToUse);
     };
 
-    const Group root {
+    const Group recipe {
         serialNumberStorage,
         startAvdRecipe(avdName(), serialNumberStorage),
-        onGroupDone(onDone, CallDoneIf::Success)
+        onGroupDone(onDone, CallDone::OnSuccess)
     };
 
-    m_taskTreeRunner.start(root);
+    m_taskTreeRunner.start(recipe);
 }
 
 IDevice::DeviceInfo AndroidDevice::deviceInformation() const
@@ -928,7 +929,7 @@ void AndroidDeviceManagerInstance::setupDevicesWatcher()
         return DoneResult::Success; // Continue the Forever loop.
     };
 
-    m_avdDeviceWatcherRunner.start(Group { Forever { ProcessTask(onSetup, onDone) } });
+    m_avdDeviceWatcherRunner.start({ Forever { ProcessTask(onSetup, onDone) } });
 
     // Setup AVD filesystem watcher to listen for changes when an avd is created/deleted,
     // or started/stopped
@@ -1045,7 +1046,7 @@ Group createAvdRecipe(const Storage<std::optional<QString>> &errorStorage,
 
     return {
         storage,
-        ProcessTask(onSetup, onDone, CallDoneIf::Error)
+        ProcessTask(onSetup, onDone, CallDone::OnError)
     };
 }
 
@@ -1075,12 +1076,14 @@ public:
             if (const auto androidDev = static_cast<AndroidDevice *>(dev.get())) {
                 qCDebug(androidDeviceLog, "Created new Android AVD id \"%s\".",
                         qPrintable(androidDev->avdName()));
+                androidDev->addActionsIfNotFound();
                 return dev;
             }
             AndroidDeviceWidget::criticalDialog(
                 Tr::tr("The device info returned from AvdDialog is invalid."));
             return IDevice::Ptr();
         });
+        setExecutionTypeId(Constants::ANDROID_EXECUTION_TYPE_ID);
     }
 };
 
