@@ -36,6 +36,7 @@
 
 #include <QCheckBox>
 #include <QComboBox>
+#include <QDialog>
 #include <QDialogButtonBox>
 #include <QFormLayout>
 #include <QLabel>
@@ -44,17 +45,36 @@
 #include <QPushButton>
 
 using namespace Core;
+using namespace Debugger;
 using namespace ProjectExplorer;
 using namespace Tasking;
 using namespace Utils;
 
-namespace Autotest {
-namespace Internal {
+namespace Autotest::Internal {
 
 static Q_LOGGING_CATEGORY(runnerLog, "qtc.autotest.testrunner", QtWarningMsg)
 
 static TestRunner *s_instance = nullptr;
 
+class RunConfigurationSelectionDialog final : public QDialog
+{
+public:
+    explicit RunConfigurationSelectionDialog(const QString &buildTargetKey);
+    QString displayName() const;
+    QString executable() const;
+    bool rememberChoice() const;
+private:
+    void populate();
+    void updateLabels();
+    QLabel *m_details;
+    QLabel *m_executable;
+    QLabel *m_arguments;
+    QLabel *m_workingDir;
+    QComboBox *m_rcCombo;
+    QCheckBox *m_rememberCB;
+    QDialogButtonBox *m_buttonBox;
+};
+
 TestRunner *TestRunner::instance()
 {
     return s_instance;
@@ -69,7 +89,7 @@ TestRunner::TestRunner()
     connect(this, &TestRunner::requestStopTestRun, this, [this] { cancelCurrent(UserCanceled); });
     connect(BuildManager::instance(), &BuildManager::buildQueueFinished,
             this, &TestRunner::onBuildQueueFinished);
-    connect(&m_taskTreeRunner, &TaskTreeRunner::aboutToStart, this, [this](TaskTree *taskTree) {
+    connect(&m_taskTreeRunner, &SingleTaskTreeRunner::aboutToStart, this, [this](TaskTree *taskTree) {
         auto progress = new TaskProgress(taskTree);
         progress->setDisplayName(Tr::tr("Running Tests"));
         progress->setAutoStopOnCancel(false);
@@ -85,7 +105,7 @@ TestRunner::TestRunner()
         if (testSettings().popupOnStart())
             popupResultsPane();
     });
-    connect(&m_taskTreeRunner, &TaskTreeRunner::done, this, &TestRunner::onFinished);
+    connect(&m_taskTreeRunner, &SingleTaskTreeRunner::done, this, &TestRunner::onFinished);
 }
 
 TestRunner::~TestRunner()
@@ -169,8 +189,8 @@ void TestRunner::runTests(TestRunMode mode, const QList<ITestConfiguration *> &s
     m_skipTargetsCheck = false;
     m_runMode = mode;
     if (mode != TestRunMode::RunAfterBuild
-            && projectExplorerSettings().buildBeforeDeploy != BuildBeforeRunMode::Off
-            && !projectExplorerSettings().saveBeforeBuild) {
+            && globalProjectExplorerSettings().buildBeforeDeploy() != BuildBeforeRunMode::Off
+            && !globalProjectExplorerSettings().saveBeforeBuild()) {
         if (!ProjectExplorerPlugin::saveModifiedFiles())
             return;
     }
@@ -200,7 +220,7 @@ void TestRunner::runTests(TestRunMode mode, const QList<ITestConfiguration *> &s
     m_targetConnect = connect(project, &Project::activeTargetChanged,
                               this, [this] { cancelCurrent(KitChanged); });
 
-    if (projectExplorerSettings().buildBeforeDeploy == BuildBeforeRunMode::Off
+    if (globalProjectExplorerSettings().buildBeforeDeploy() == BuildBeforeRunMode::Off
             || mode == TestRunMode::DebugWithoutDeploy
             || mode == TestRunMode::RunWithoutDeploy || mode == TestRunMode::RunAfterBuild) {
         runOrDebugTests();
@@ -226,16 +246,13 @@ static QString firstNonEmptyTestCaseTarget(const TestConfiguration *config)
 
 static RunConfiguration *getRunConfiguration(const QString &buildTargetKey)
 {
-    const Project *project = ProjectManager::startupProject();
-    if (!project)
-        return nullptr;
-    const Target *target = project->activeTarget();
-    if (!target)
+    const BuildConfiguration * const buildConfig = activeBuildConfigForActiveProject();
+    if (!buildConfig)
         return nullptr;
 
     RunConfiguration *runConfig = nullptr;
     const QList<RunConfiguration *> runConfigurations
-            = Utils::filtered(target->runConfigurations(), [](const RunConfiguration *rc) {
+            = Utils::filtered(buildConfig->runConfigurations(), [](const RunConfiguration *rc) {
         return !rc->runnable().command.isEmpty();
     });
 
@@ -252,7 +269,7 @@ static RunConfiguration *getRunConfiguration(const QString &buildTargetKey)
     if (runConfigurations.size() == 1)
         return runConfigurations.first();
 
-    RunConfigurationSelectionDialog dialog(buildTargetKey, ICore::dialogParent());
+    RunConfigurationSelectionDialog dialog(buildTargetKey);
     if (dialog.exec() == QDialog::Accepted) {
         const QString dName = dialog.displayName();
         if (dName.isEmpty())
@@ -308,9 +325,9 @@ int TestRunner::precheckTestConfigurations()
 
 void TestRunner::onBuildSystemUpdated()
 {
-    Target *target = ProjectManager::startupTarget();
-    if (QTC_GUARD(target))
-        disconnect(target, &Target::buildSystemUpdated, this, &TestRunner::onBuildSystemUpdated);
+    BuildSystem *bs = activeBuildSystemForActiveProject();
+    if (QTC_GUARD(bs))
+        disconnect(bs, &BuildSystem::updated, this, &TestRunner::onBuildSystemUpdated);
     if (!m_skipTargetsCheck) {
         m_skipTargetsCheck = true;
         runOrDebugTests();
@@ -482,7 +499,9 @@ static void processOutput(TestOutputReader *outputreader, const QString &msg, Ou
                                                 "\t Use the -dograb option to enforce grabbing.";
         if (message.startsWith(gdbSpecialOut))
             message = message.mid(gdbSpecialOut.length() + 1);
-        message.chop(1); // all messages have an additional \n at the end
+        // messages should have additional \n at the end (exception debug - we may get buffered)
+        if (message.endsWith('\n'))
+            message.chop(1);
 
         for (const auto &line : message.split('\n')) {
             if (format == OutputFormat::StdOutFormat)
@@ -558,13 +577,14 @@ void TestRunner::debugTests()
                 .arg(config->displayName());
         reportResult(ResultType::MessageWarn, details);
     }
-    auto debugger = new Debugger::DebuggerRunTool(runControl);
-    debugger->runParameters().setInferior(inferior);
-    debugger->runParameters().setDisplayName(config->displayName());
+    DebuggerRunParameters rp = DebuggerRunParameters::fromRunControl(runControl);
+    rp.setInferior(inferior);
+    rp.setDisplayName(config->displayName());
+    runControl->setRunRecipe(debuggerRecipe(runControl, rp));
 
     bool useOutputProcessor = true;
     if (Kit *kit = config->project()->activeKit()) {
-        if (Debugger::DebuggerKitAspect::engineType(kit) == Debugger::CdbEngineType) {
+        if (DebuggerKitAspect::engineType(kit) == CdbEngineType) {
             reportResult(ResultType::MessageWarn,
                          Tr::tr("Unable to display test results when using CDB."));
             useOutputProcessor = false;
@@ -595,8 +615,9 @@ void TestRunner::debugTests()
 
 static bool executablesEmpty()
 {
-    Target *target = ProjectManager::startupTarget();
-    const QList<RunConfiguration *> configs = target->runConfigurations();
+    const BuildConfiguration * const buildConfig = activeBuildConfigForActiveProject();
+    QTC_ASSERT(buildConfig, return false);
+    const QList<RunConfiguration *> configs = buildConfig->runConfigurations();
     QTC_ASSERT(!configs.isEmpty(), return false);
     if (auto execAspect = configs.first()->aspect<ExecutableAspect>())
         return execAspect->executable().isEmpty();
@@ -608,15 +629,15 @@ void TestRunner::runOrDebugTests()
     if (!m_skipTargetsCheck) {
         if (executablesEmpty()) {
             m_skipTargetsCheck = true;
-            Target *target = ProjectManager::startupTarget();
-            QTimer::singleShot(5000, this, [this, target = QPointer<Target>(target)] {
-                if (target) {
-                    disconnect(target, &Target::buildSystemUpdated,
+            BuildSystem *bs = activeBuildSystemForActiveProject();
+            QTimer::singleShot(5000, this, [this, bs = QPointer<BuildSystem>(bs)] {
+                if (bs) {
+                    disconnect(bs, &BuildSystem::updated,
                                this, &TestRunner::onBuildSystemUpdated);
                 }
                 runOrDebugTests();
             });
-            connect(target, &Target::buildSystemUpdated, this, &TestRunner::onBuildSystemUpdated);
+            connect(bs, &BuildSystem::updated, this, &TestRunner::onBuildSystemUpdated);
             return;
         }
     }
@@ -720,9 +741,8 @@ void TestRunner::reportResult(ResultType type, const QString &description)
 
 /*************************************************************************************************/
 
-RunConfigurationSelectionDialog::RunConfigurationSelectionDialog(const QString &buildTargetKey,
-                                                                 QWidget *parent)
-    : QDialog(parent)
+RunConfigurationSelectionDialog::RunConfigurationSelectionDialog(const QString &buildTargetKey)
+    : QDialog(ICore::dialogParent())
 {
     setWindowTitle(Tr::tr("Select Run Configuration"));
 
@@ -783,16 +803,14 @@ void RunConfigurationSelectionDialog::populate()
 {
     m_rcCombo->addItem({}, QStringList{{}, {}, {}}); // empty default
 
-    if (auto project = ProjectManager::startupProject()) {
-        if (auto target = project->activeTarget()) {
-            for (RunConfiguration *rc : target->runConfigurations()) {
-                auto runnable = rc->runnable();
-                const QStringList rcDetails
-                    = {runnable.command.executable().toUserOutput(),
-                       runnable.command.arguments(),
-                       runnable.workingDirectory.toUserOutput()};
-                m_rcCombo->addItem(rc->displayName(), rcDetails);
-            }
+    if (auto buildConfig = activeBuildConfigForActiveProject()) {
+        for (RunConfiguration *rc : buildConfig->runConfigurations()) {
+            auto runnable = rc->runnable();
+            const QStringList rcDetails
+                = {runnable.command.executable().toUserOutput(),
+                   runnable.command.arguments(),
+                   runnable.workingDirectory.toUserOutput()};
+            m_rcCombo->addItem(rc->displayName(), rcDetails);
         }
     }
 }
@@ -807,5 +825,4 @@ void RunConfigurationSelectionDialog::updateLabels()
     m_workingDir->setText(values.at(2));
 }
 
-} // namespace Internal
-} // namespace Autotest
+} // namespace Internal::Autotest
