@@ -13,7 +13,6 @@
 
 #include <extensionsystem/pluginmanager.h>
 
-#include <solutions/tasking/tasktreerunner.h>
 #include <solutions/tasking/tasktree.h>
 
 #include <utils/algorithm.h>
@@ -75,14 +74,15 @@ public:
     ~LocalBuild()
     {
         QTC_CHECK(m_startedDashboards.isEmpty()); // shutdownAll() must be done already
-        QTC_ASSERT(m_runningLocalBuilds.isEmpty(), qDeleteAll(m_runningLocalBuilds));
-        QTC_CHECK(m_startedDashboardTrees.empty());
+        QTC_CHECK(!m_localBuildInfosRunner.isRunning());
+        QTC_CHECK(!m_startedDashboardsRunner.isRunning());
     }
 
     std::optional<LocalDashboardAccess> localDashboardAccessFor(const QString &projectName) const;
 
     void startDashboard(const QString &projectName, const LocalDashboard &dashboard,
-                        const std::function<void()> &callback);
+                        const std::function<void()> &onSuccess,
+                        const std::function<void()> &onFail);
     bool shutdownAll(const std::function<void()> &callback);
 
     bool startLocalBuildFor(const QString &projectName);
@@ -90,7 +90,7 @@ public:
 
     bool hasRunningBuildFor(const QString &projectName)
     {
-        return m_runningLocalBuilds.contains(projectName);
+        return m_localBuildInfosRunner.isKeyRunning(projectName);
     }
 
     LocalBuildInfo localBuildInfoFor(const QString &projectName)
@@ -110,41 +110,38 @@ private:
     void handleLocalBuildOutputFor(const QString &projectName, const QString &line);
 
     QHash<QString, LocalDashboard> m_startedDashboards;
-    std::unordered_map<QString, std::unique_ptr<TaskTree>> m_startedDashboardTrees;
+    MappedTaskTreeRunner<QString> m_startedDashboardsRunner;
 
-    QHash<QString, TaskTreeRunner *> m_runningLocalBuilds;
     QHash<QString, LocalBuildInfo> m_localBuildInfos;
+    MappedTaskTreeRunner<QString> m_localBuildInfosRunner;
+
+    SingleTaskTreeRunner m_shutdownRunner;
     FilePath m_lastBauhausFromDB;
 };
 
 void LocalBuild::startDashboard(const QString &projectName, const LocalDashboard &dashboard,
-                                const std::function<void()> &callback)
+                                const std::function<void()> &onSuccess,
+                                const std::function<void()> &onFail)
 {
     if (ExtensionSystem::PluginManager::isShuttingDown())
         return;
 
-    const Storage<LocalDashboard> storage;
     const auto onSetup = [dash = dashboard](Process &process) {
         process.setCommand(dash.startCommandLine);
         process.setEnvironment(dash.environment);
     };
 
-    TaskTree *taskTree = new TaskTree;
-    m_startedDashboardTrees.insert_or_assign(projectName, std::unique_ptr<TaskTree>(taskTree));
-    const auto onDone = [this, callback, dash = dashboard, projectName] (const Process &process) {
-        const auto onFinish = qScopeGuard([this, projectName] {
-            auto it = m_startedDashboardTrees.find(projectName);
-            QTC_ASSERT(it != m_startedDashboardTrees.end(), return);
-            it->second.release()->deleteLater();
-            m_startedDashboardTrees.erase(it);
-        });
+    const auto onDone
+            = [this, onSuccess, onFail, dash = dashboard, projectName](const Process &process) {
         if (process.result() != ProcessResult::FinishedWithSuccess) {
-            qCDebug(localDashLog) << "Process failed...." << int(process.result());
+            qCDebug(localDashLog) << "Process failed..." << int(process.result());
             const QString errOutput = process.cleanedStdErr();
             if (errOutput.isEmpty())
                 showErrorMessage(Tr::tr("Failed to start local dashboard."));
             else
                 showErrorMessage(errOutput);
+            if (onFail)
+                onFail();
             return;
         }
         const QString output = process.cleanedStdOut();
@@ -163,27 +160,19 @@ void LocalBuild::startDashboard(const QString &projectName, const LocalDashboard
         updated.pass = data.value("password").toString().toUtf8();
 
         m_startedDashboards.insert(updated.id, updated);
-        if (callback)
-            callback();
+        if (onSuccess)
+            onSuccess();
     };
 
     m_startedDashboards.insert(dashboard.id, dashboard);
     qCDebug(localDashLog) << "Dashboard [start]" << dashboard.startCommandLine.toUserOutput();
-    taskTree->setRecipe({ProcessTask(onSetup, onDone)});
-    taskTree->start();
+    m_startedDashboardsRunner.start(projectName, {ProcessTask(onSetup, onDone)});
 }
 
 bool LocalBuild::shutdownAll(const std::function<void()> &callback)
 {
-    for (auto it : std::as_const(m_runningLocalBuilds)) // runners that perform a local build
-        it->cancel();
-
-    for (auto it = m_startedDashboardTrees.begin(), end = m_startedDashboardTrees.end();
-         it != end; ++it) {
-        if (it->second)
-            it->second->cancel();
-    }
-
+    m_localBuildInfosRunner.cancel();
+    m_startedDashboardsRunner.cancel();
     if (m_startedDashboards.isEmpty())
         return false;
 
@@ -207,14 +196,12 @@ bool LocalBuild::shutdownAll(const std::function<void()> &callback)
         }
     }.withTimeout(std::chrono::seconds(5));
 
-    TaskTree *taskTree = new TaskTree(recipe);
-    QObject::connect(taskTree, &TaskTree::done, taskTree, [taskTree, callback] {
-        taskTree->deleteLater();
+    const auto onShutdownDone = [callback] {
         if (callback)
             callback();
-    });
-    taskTree->start();
+    };
 
+    m_shutdownRunner.start(recipe, {}, onShutdownDone);
     return true;
 }
 
@@ -310,21 +297,29 @@ static CommandLine parseCommandLine(const QString &jsonArrayCmd)
     return CommandLine{FilePath::fromUserInput(first).withExecutableSuffix(), fullCommand};
 }
 
-void startLocalDashboard(const QString &projectName, const std::function<void ()> &callback)
+void startLocalDashboard(const QString &projectName,
+                         const std::function<void ()> &onSuccess,
+                         const std::function<void ()> &onFail)
 {
     QSqlDatabase db = localDashboardDB();
+    bool failed = false;
+    auto cleanup = qScopeGuard([&db, &failed, onFail]{
+        if (db.isValid())
+            db.close();
+        if (failed && onFail)
+            onFail();
+    });
     QTC_ASSERT(db.isValid(), return); // we should be here only if we had some valid db before
     if (!db.open()) {
         qCDebug(sqlLog) << "open db failed" << db.lastError().text();
         return;
     }
-    auto cleanup = qScopeGuard([&db]{ db.close(); });
 
     QSqlQuery query(db);
     query.prepare("SELECT ID, Dashboard_Start_Command_Line, Dashboard_Stop_Command_Line "
                   "FROM axLocalProjects WHERE Remote_Project_Name=(:projectName)");
     query.bindValue(":projectName", projectName);
-    if (!query.exec() || !query.next())
+    if ((failed = !query.exec()) || (failed = !query.next()))
         return;
 
     const QString id = query.value("ID").toString();
@@ -334,7 +329,7 @@ void startLocalDashboard(const QString &projectName, const std::function<void ()
     query.prepare("SELECT Name, Value FROM axDashboardEnvironments WHERE LocalProject_ID=(:id)");
     query.bindValue(":id", id);
 
-    if (!query.exec())
+    if ((failed = !query.exec()))
         return;
 
     const QString userAgent("Axivion" + QCoreApplication::applicationName() +
@@ -358,7 +353,7 @@ void startLocalDashboard(const QString &projectName, const std::function<void ()
     const CommandLine stop = parseCommandLine(stopCmdLine);
 
     LocalDashboard localDashboard{id, start, stop, env, {}, {}, {}, {}};
-    s_localBuildInstance.startDashboard(projectName, localDashboard, callback);
+    s_localBuildInstance.startDashboard(projectName, localDashboard, onSuccess, onFail);
 }
 
 class LocalBuildDialog : public QDialog
@@ -580,9 +575,6 @@ bool LocalBuild::startLocalBuildFor(const QString &projectName)
     if (!settings().bauhausPython().isEmpty())
         env.set("BAUHAUS_PYTHON", settings().bauhausPython().toUserOutput());
 
-    TaskTreeRunner *localBuildRunner = new TaskTreeRunner;
-    m_runningLocalBuilds.insert(projectName, localBuildRunner);
-
     const auto onSetup = [this, projectName, cmdLine, env](Process &process) {
         CommandLine cmd = HostOsInfo::isWindowsHost() ? CommandLine{"cmd", {"/c"}}
                                                       : CommandLine{"/bin/sh", {"-c"}};
@@ -607,9 +599,6 @@ bool LocalBuild::startLocalBuildFor(const QString &projectName)
         m_localBuildInfos.insert(projectName, {LocalBuildState::Finished, process.cleanedStdOut(),
                                                process.cleanedStdErr()});
         qCDebug(localBuildLog) << "buildState changed >" << state << projectName;
-        TaskTreeRunner *runner = m_runningLocalBuilds.take(projectName);
-        if (runner)
-            runner->deleteLater();
         updateLocalBuildStateFor(projectName, state, 100);
     };
 
@@ -617,15 +606,13 @@ bool LocalBuild::startLocalBuildFor(const QString &projectName)
     updateLocalBuildStateFor(projectName, Tr::tr("Starting"), 1);
     qCDebug(localBuildLog) << "starting local build (" << projectName << "):"
                            << cmdLine.toUserOutput();
-    localBuildRunner->start({ProcessTask(onSetup, onDone)});
+    m_localBuildInfosRunner.start(projectName, {ProcessTask(onSetup, onDone)});
     return true;
 }
 
 void LocalBuild::cancelLocalBuildFor(const QString &projectName)
 {
-    TaskTreeRunner *runner = m_runningLocalBuilds.value(projectName);
-    if (runner)
-        runner->cancel();
+    m_localBuildInfosRunner.cancelKey(projectName);
 }
 
 void LocalBuild::removeFinishedLocalBuilds()
