@@ -1,5 +1,5 @@
 // Copyright (C) 2020 Denis Shienkov <denis.shienkov@gmail.com>
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "uvtargetdeviceselection.h"
 
@@ -52,9 +52,9 @@ constexpr char deviceAlgorithmIndexKeyC[] = "DeviceAlgorithmIndex";
 
 // DeviceSelection
 
-QVariantMap DeviceSelection::toMap() const
+Store DeviceSelection::toMap() const
 {
-    QVariantMap map;
+    Store map;
     // Software package.
     map.insert(packageDescrKeyC, package.desc);
     map.insert(packageFileKeyC, package.file);
@@ -79,30 +79,30 @@ QVariantMap DeviceSelection::toMap() const
     // Device MEMORY.
     QVariantList memoryList;
     for (const DeviceSelection::Memory &memory : std::as_const(memories)) {
-        QVariantMap m;
+        Store m;
         m.insert(deviceMemoryIdKeyC, memory.id);
         m.insert(deviceMemoryStartKeyC, memory.start);
         m.insert(deviceMemorySizeKeyC, memory.size);
-        memoryList.push_back(m);
+        memoryList.push_back(variantFromStore(m));
     }
     map.insert(deviceMemoryKeyC, memoryList);
     // Device ALGORITHM.
     QVariantList algorithmList;
     for (const DeviceSelection::Algorithm &algorithm : std::as_const(algorithms)) {
-        QVariantMap m;
+        Store m;
         m.insert(deviceAlgorithmPathKeyC, algorithm.path);
         m.insert(deviceAlgorithmFlashStartKeyC, algorithm.flashStart);
         m.insert(deviceAlgorithmFlashSizeKeyC, algorithm.flashSize);
         m.insert(deviceAlgorithmRamStartKeyC, algorithm.ramStart);
         m.insert(deviceAlgorithmRamSizeKeyC, algorithm.ramSize);
-        algorithmList.push_back(m);
+        algorithmList.push_back(variantFromStore(m));
     }
     map.insert(deviceAlgorithmKeyC, algorithmList);
     map.insert(deviceAlgorithmIndexKeyC, algorithmIndex);
     return map;
 }
 
-void DeviceSelection::fromMap(const QVariantMap &map)
+void DeviceSelection::fromMap(const Store &map)
 {
     // Software package.
     package.desc = map.value(packageDescrKeyC).toString();
@@ -264,6 +264,7 @@ void DeviceSelectionMemoryModel::refresh()
 DeviceSelectionMemoryView::DeviceSelectionMemoryView(DeviceSelection &selection, QWidget *parent)
     : TreeView(parent)
 {
+    setUniformRowHeights(false);
     setRootIsDecorated(true);
     setSelectionMode(QAbstractItemView::SingleSelection);
 
