@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "clangcompletioncontextanalyzer.h"
 
@@ -61,6 +61,10 @@ void ClangCompletionContextAnalyzer::analyze()
                 m_document, m_position, m_languageFeatures);
     m_completionOperator = activationSequenceContextProcessor.completionKind();
     int afterOperatorPosition = activationSequenceContextProcessor.startOfNamePosition();
+    if (afterOperatorPosition == INT_MIN) {
+        m_completionAction = AbortExisting;
+        return;
+    }
     m_positionEndOfExpression = activationSequenceContextProcessor.operatorStartPosition();
     m_positionForProposal = activationSequenceContextProcessor.startOfNamePosition();
 
