@@ -1,12 +1,13 @@
 // Copyright (C) 2018 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
+#include <cppeditor/cppcodemodelsettings.h>
 #include <cppeditor/cppprojectfile.h>
 #include <cppeditor/projectpart.h>
 
-#include <utils/fileutils.h>
+#include <utils/filepath.h>
 
 #include <QSet>
 
@@ -19,9 +20,11 @@ public:
     FileInfo() = default;
     FileInfo(Utils::FilePath file,
              CppEditor::ProjectFile::Kind kind,
+             const CppEditor::CppCodeModelSettings &settings,
              CppEditor::ProjectPart::ConstPtr projectPart)
         : file(std::move(file))
         , kind(kind)
+        , settings(settings)
         , projectPart(projectPart)
     {}
 
@@ -31,6 +34,7 @@ public:
 
     Utils::FilePath file;
     CppEditor::ProjectFile::Kind kind;
+    CppEditor::CppCodeModelSettings settings;
     CppEditor::ProjectPart::ConstPtr projectPart;
 };
 using FileInfos = std::vector<FileInfo>;
