@@ -31,7 +31,7 @@ namespace Internal {
 
 static QString lineColumnString(const Link &link)
 {
-    return QString("%1:%2").arg(link.targetLine).arg(link.targetColumn);
+    return QString("%1:%2").arg(link.target.line).arg(link.target.column + 1);
 }
 
 static QString fixitStatus(FixitStatus status)
@@ -124,8 +124,8 @@ QString createDiagnosticToolTipString(
 QString createFullLocationString(const Link &location)
 {
     return location.targetFilePath.toUserOutput()
-            + QLatin1Char(':') + QString::number(location.targetLine)
-            + QLatin1Char(':') + QString::number(location.targetColumn);
+            + QLatin1Char(':') + QString::number(location.target.line)
+            + QLatin1Char(':') + QString::number(location.target.column);
 }
 
 QString hintAboutBuildBeforeAnalysis()
@@ -349,7 +349,7 @@ QString clazyDocUrl(const QString &check)
     QVersionNumber version = ClangToolsSettings::clazyVersion();
     if (!version.isNull())
         version = QVersionNumber(version.majorVersion(), version.minorVersion());
-    const QString versionString = version.isNull() ? "master" : version.toString();
+    const QString versionString = version.isNull() ? "master" : version.toString().prepend("v");
     static const char urlTemplate[]
             = "https://github.com/KDE/clazy/blob/%1/docs/checks/README-%2.md";
     return QString::fromLatin1(urlTemplate).arg(versionString, check);
