@@ -5,10 +5,12 @@
 
 #include "builddirparameters.h"
 #include "cmakebuildtarget.h"
+#include "cmaketool.h"
 #include "fileapireader.h"
 
 #include <projectexplorer/buildconfiguration.h>
 #include <projectexplorer/buildsystem.h>
+#include <projectexplorer/task.h>
 
 #include <utils/synchronizedvalue.h>
 #include <utils/temporarydirectory.h>
@@ -40,7 +42,7 @@ class CMakeBuildSystem final : public ProjectExplorer::BuildSystem
     Q_OBJECT
 
 public:
-    explicit CMakeBuildSystem(CMakeBuildConfiguration *bc);
+    explicit CMakeBuildSystem(ProjectExplorer::BuildConfiguration *bc);
     ~CMakeBuildSystem() final;
 
     void triggerParsing() final;
@@ -67,7 +69,8 @@ public:
     void buildNamedTarget(const QString &target) final;
 
     Utils::FilePaths filesGeneratedFrom(const Utils::FilePath &sourceFile) const final;
-    QString name() const final { return QLatin1String("cmake"); }
+
+    bool addDependencies(ProjectExplorer::Node *context, const QStringList &dependencies) final;
 
     // Actions:
     void runCMake();
@@ -93,7 +96,7 @@ public:
     CMakeBuildConfiguration *cmakeBuildConfiguration() const;
 
     QList<ProjectExplorer::TestCaseInfo> const testcasesInfo() const final;
-    Utils::CommandLine commandLineForTests(const QList<QString> &tests,
+    Utils::CommandLine commandLineForTests(const QStringList &tests,
                                            const QStringList &options) const final;
 
     ProjectExplorer::MakeInstallCommand makeInstallCommand(
@@ -133,11 +136,12 @@ public:
     QString cmakeGenerator() const;
     bool hasSubprojectBuildSupport() const;
 
+    QVariant additionalData(Utils::Id id) const override;
+
+    bool isDestructing() const { return m_isDestructing; }
 signals:
     void configurationCleared();
     void configurationChanged(const CMakeConfig &config);
-    void errorOccurred(const QString &message);
-    void warningOccurred(const QString &message);
 
 private:
     CMakeConfig initialCMakeConfiguration() const;
@@ -197,8 +201,6 @@ private:
     void updateProjectData();
     void updateFallbackProjectData();
     QList<ProjectExplorer::ExtraCompiler *> findExtraCompilers();
-    void updateQmlJSCodeModel(const QStringList &extraHeaderPaths,
-                              const QList<QByteArray> &moduleMappings);
     void updateInitialCMakeExpandableVars();
 
     void updateFileSystemNodes();
@@ -219,6 +221,8 @@ private:
 
     void setupCMakeSymbolsHash();
 
+    void updateQmlCodeModelInfo(ProjectExplorer::QmlCodeModelInfo &projectInfo) final;
+
     struct ProjectFileArgumentPosition
     {
         cmListFileArgument argumentPosition;
@@ -226,7 +230,7 @@ private:
         QString relativeFileName;
         bool fromGlobbing = false;
     };
-    std::optional<ProjectFileArgumentPosition> projectFileArgumentPosition(
+    Utils::Result<ProjectFileArgumentPosition> projectFileArgumentPosition(
         const QString &targetName, const QString &fileName);
 
     ProjectExplorer::TreeScanner m_treeScanner;
@@ -251,8 +255,6 @@ private:
     QStringList m_projectImportedTargets;
     QStringList m_projectFindPackageVariables;
 
-    QHash<QString, ProjectFileArgumentPosition> m_filesToBeRenamed;
-
     // Parsing state:
     BuildDirParameters m_parameters;
     int m_reparseParameters = REPARSE_DEFAULT;
@@ -269,7 +271,17 @@ private:
 
     QString m_error;
     QString m_warning;
+
+    QStringList m_extraHeaderPaths;
+    QList<QByteArray> m_moduleMappings;
+    ProjectExplorer::Task m_generatorError;
+
+    bool m_isDestructing = false;
 };
 
+#ifdef WITH_TESTS
+QObject *createAddDependenciesTest();
+#endif
+
 } // namespace Internal
 } // namespace CMakeProjectManager
