@@ -16,6 +16,7 @@
 #include <coreplugin/icore.h>
 
 #include <projectexplorer/buildsystem.h>
+#include <projectexplorer/kitaspect.h>
 #include <projectexplorer/projectmanager.h>
 #include <projectexplorer/projecttree.h>
 #include <projectexplorer/target.h>
@@ -293,16 +294,18 @@ void CMakeToolManager::deregisterCMakeTool(const Id &id)
     }
 }
 
-CMakeTool *CMakeToolManager::defaultProjectOrDefaultCMakeTool()
+CMakeKeywords CMakeToolManager::defaultProjectOrDefaultCMakeKeyWords()
 {
-    CMakeTool *tool = nullptr;
+    if (auto bs = activeBuildSystemForCurrentProject()) {
+        CMakeKeywords keywords = CMakeKitAspect::cmakeKeywords(bs->kit());
+        if (!keywords.variables.isEmpty())
+            return keywords;
+    }
 
-    if (auto bs = activeBuildSystemForCurrentProject())
-        tool = CMakeKitAspect::cmakeTool(bs->kit());
-    if (!tool)
-        tool = CMakeToolManager::defaultCMakeTool();
+    if (auto tool = CMakeToolManager::defaultCMakeTool())
+        return tool->keywords();
 
-    return tool;
+    return {};
 }
 
 CMakeTool *CMakeToolManager::defaultCMakeTool()
@@ -321,9 +324,18 @@ void CMakeToolManager::setDefaultCMakeTool(const Id &id)
     ensureDefaultCMakeToolIsValid();
 }
 
-CMakeTool *CMakeToolManager::findByCommand(const Utils::FilePath &command)
+CMakeTool *CMakeToolManager::findByCommand(const FilePath &command)
 {
-    return Utils::findOrDefault(d->m_cmakeTools, Utils::equal(&CMakeTool::cmakeExecutable, command));
+    return Utils::findOrDefault(
+        d->m_cmakeTools,
+        Utils::equal(&CMakeTool::cmakeExecutable, CMakeTool::cmakeExecutable(command)));
+}
+
+Id CMakeToolManager::idForExecutable(const FilePath &cmakeExecutable)
+{
+    if (CMakeTool *tool = findByCommand(cmakeExecutable))
+        return tool->id();
+    return {};
 }
 
 CMakeTool *CMakeToolManager::findById(const Id &id)
@@ -331,11 +343,17 @@ CMakeTool *CMakeToolManager::findById(const Id &id)
     return Utils::findOrDefault(d->m_cmakeTools, Utils::equal(&CMakeTool::id, id));
 }
 
+FilePath CMakeToolManager::executableForId(const Id id)
+{
+    if (CMakeTool *tool = findById(id))
+        return tool->cmakeExecutable();
+    return {};
+}
+
 void CMakeToolManager::restoreCMakeTools()
 {
     NANOTRACE_SCOPE("CMakeProjectManager", "CMakeToolManager::restoreCMakeTools");
-    Internal::CMakeToolSettingsAccessor::CMakeTools tools
-            = d->m_accessor.restoreCMakeTools(ICore::dialogParent());
+    Internal::CMakeToolSettingsAccessor::CMakeTools tools = d->m_accessor.restoreCMakeTools();
     d->m_cmakeTools = std::move(tools.cmakeTools);
     setDefaultCMakeTool(tools.defaultToolId);
 
@@ -471,29 +489,24 @@ FilePath CMakeToolManager::mappedFilePath(Project *project, const FilePath &path
     return fullHashPath.exists() ? fullHashPath : path;
 }
 
-QList<Id> CMakeToolManager::autoDetectCMakeForDevice(const FilePaths &searchPaths,
-                                                const QString &detectionSource,
-                                                QString *logMessage)
+QList<Id> CMakeToolManager::autoDetectCMakeForDevice(
+    const FilePaths &searchPaths, const QString &detectionSource, const LogCallback &logCallback)
 {
     QList<Id> result;
-    QStringList messages{Tr::tr("Searching CMake binaries...")};
     for (const FilePath &path : searchPaths) {
         const FilePath cmake = path.pathAppended("cmake").withExecutableSuffix();
         if (cmake.isExecutableFile()) {
             const Id currentId = registerCMakeByPath(cmake, detectionSource);
             if (currentId.isValid())
                 result.push_back(currentId);
-            messages.append(Tr::tr("Found \"%1\"").arg(cmake.toUserOutput()));
+            logCallback(Tr::tr("Found \"%1\".").arg(cmake.toUserOutput()));
         }
     }
-    if (logMessage)
-        *logMessage = messages.join('\n');
-
     return result;
 }
 
 
-Id CMakeToolManager::registerCMakeByPath(const FilePath &cmakePath, const QString &detectionSource)
+Id CMakeToolManager::registerCMakeByPath(const FilePath &cmakePath, const QString &detectionSourceId)
 {
     Id id = Id::fromString(cmakePath.toUserOutput());
 
@@ -501,9 +514,9 @@ Id CMakeToolManager::registerCMakeByPath(const FilePath &cmakePath, const QStrin
     if (cmakeTool)
         return cmakeTool->id();
 
-    auto newTool = std::make_unique<CMakeTool>(CMakeTool::ManualDetection, id);
+    const DetectionSource detectionSource{DetectionSource::Manual, detectionSourceId};
+    auto newTool = std::make_unique<CMakeTool>(detectionSource, id);
     newTool->setFilePath(cmakePath);
-    newTool->setDetectionSource(detectionSource);
     newTool->setDisplayName(cmakePath.toUserOutput());
     id = newTool->id();
     registerCMakeTool(std::move(newTool));
@@ -511,32 +524,32 @@ Id CMakeToolManager::registerCMakeByPath(const FilePath &cmakePath, const QStrin
     return id;
 }
 
-void CMakeToolManager::removeDetectedCMake(const QString &detectionSource, QString *logMessage)
+void CMakeToolManager::removeDetectedCMake(
+    const QString &detectionSource, const LogCallback &logCallback)
 {
-    QStringList logMessages{Tr::tr("Removing CMake entries...")};
     while (true) {
-        auto toRemove = Utils::take(d->m_cmakeTools, Utils::equal(&CMakeTool::detectionSource, detectionSource));
+        auto toRemove = Utils::take(d->m_cmakeTools, [detectionSource](const auto &tool) {
+            return tool->detectionSource().id == detectionSource
+                   && tool->detectionSource().isAutoDetected();
+        });
         if (!toRemove.has_value())
             break;
-        logMessages.append(Tr::tr("Removed \"%1\"").arg((*toRemove)->displayName()));
+        logCallback(Tr::tr("Removing CMake tool \"%1\".").arg((*toRemove)->displayName()));
         emit m_instance->cmakeRemoved((*toRemove)->id());
     }
 
     ensureDefaultCMakeToolIsValid();
     updateDocumentation();
-    if (logMessage)
-        *logMessage = logMessages.join('\n');
 }
 
-void CMakeToolManager::listDetectedCMake(const QString &detectionSource, QString *logMessage)
+void CMakeToolManager::listDetectedCMake(
+    const QString &detectionSource, const LogCallback &logCallback)
 {
-    QTC_ASSERT(logMessage, return);
-    QStringList logMessages{Tr::tr("CMake:")};
     for (const auto &tool : std::as_const(d->m_cmakeTools)) {
-        if (tool->detectionSource() == detectionSource)
-            logMessages.append(tool->displayName());
+        if (tool->detectionSource().id == detectionSource
+            && tool->detectionSource().isAutoDetected())
+            logCallback(tool->displayName());
     }
-    *logMessage = logMessages.join('\n');
 }
 
 void CMakeToolManager::notifyAboutUpdate(CMakeTool *tool)
@@ -548,7 +561,7 @@ void CMakeToolManager::notifyAboutUpdate(CMakeTool *tool)
 
 void CMakeToolManager::saveCMakeTools()
 {
-    d->m_accessor.saveCMakeTools(cmakeTools(), d->m_defaultCMake, ICore::dialogParent());
+    d->m_accessor.saveCMakeTools(cmakeTools(), d->m_defaultCMake);
 }
 
 void CMakeToolManager::ensureDefaultCMakeToolIsValid()
@@ -560,7 +573,7 @@ void CMakeToolManager::ensureDefaultCMakeToolIsValid()
         if (findById(d->m_defaultCMake))
             return;
         auto cmakeTool = Utils::findOrDefault(cmakeTools(), [](CMakeTool *tool) {
-            return tool->detectionSource().isEmpty() && tool->cmakeExecutable().isLocal();
+            return tool->detectionSource().id.isEmpty() && tool->cmakeExecutable().isLocal();
         });
         if (cmakeTool)
             d->m_defaultCMake = cmakeTool->id();
