@@ -15,15 +15,16 @@
 #include <projectexplorer/projecttree.h>
 
 #include <utils/algorithm.h>
-#include <utils/icon.h>
 #include <utils/fileutils.h>
+#include <utils/icon.h>
 #include <utils/mimeconstants.h>
 #include <utils/mimeutils.h>
-#include <utils/qtcprocess.h>
 #include <utils/qtcassert.h>
+#include <utils/qtcprocess.h>
+#include <utils/textfileformat.h>
 
 #include <QLoggingCategory>
-#include <QtConcurrent>
+#include <QtConcurrentMap>
 
 using namespace ProjectExplorer;
 using namespace Utils;
@@ -64,25 +65,24 @@ static CMakeFileResult extractCMakeFilesData(const QFuture<void> &cancelFuture,
     // Load and parse cmake files. We use concurrency here to speed up the process of
     // reading many small files, which can get slow especially on remote devices.
     QFuture<CMakeFileInfo> mapResult
-        = QtConcurrent::mapped(cmakeFileSet, [cancelFuture, sourceDirectory](const auto &info) {
+        = QtConcurrent::mapped(cmakeFileSet, [cancelFuture, sourceDirectory](const CMakeFileInfo &info) {
               if (cancelFuture.isCanceled())
                   return CMakeFileInfo();
               const FilePath sfn = sourceDirectory.resolvePath(info.path);
-              CMakeFileInfo absolute(info);
+              CMakeFileInfo absolute = info;
               absolute.path = sfn;
 
-              const auto mimeType = Utils::mimeTypeForFile(info.path);
+              const MimeType mimeType = Utils::mimeTypeForFile(info.path);
               if (mimeType.matchesName(Utils::Constants::CMAKE_MIMETYPE)
                   || mimeType.matchesName(Utils::Constants::CMAKE_PROJECT_MIMETYPE)) {
-                  Result<QByteArray> fileContent = sfn.fileContents();
+                  QByteArray fileContent;
                   std::string errorString;
-                  if (fileContent) {
-                      fileContent = fileContent->replace("\r\n", "\n");
-                      if (!absolute.cmakeListFile.ParseString(fileContent->toStdString(),
+                  if (TextFileFormat::readFileUtf8(sfn, TextEncoding::Utf8, &fileContent)) {
+                      if (!absolute.cmakeListFile.ParseString(fileContent.toStdString(),
                                                               sfn.fileName().toStdString(),
                                                               errorString)) {
-                          qCWarning(cmakeLogger) << "Failed to parse:" << sfn.path()
-                                                 << QString::fromLatin1(errorString);
+                          qCDebug(cmakeLogger) << "Failed to parse:" << sfn.path()
+                                               << QString::fromLatin1(errorString);
                       }
                   }
               }
@@ -97,7 +97,7 @@ static CMakeFileResult extractCMakeFilesData(const QFuture<void> &cancelFuture,
 
     CMakeFileResult result;
 
-    for (const auto &info : mapResult.results()) {
+    for (const CMakeFileInfo &info : mapResult.results()) {
         if (cancelFuture.isCanceled())
             return {};
 
@@ -423,8 +423,7 @@ static RawProjectParts generateRawProjectParts(const QFuture<void> &cancelFuture
             // keep quiet about it:-)
             if (ci.defines.empty() && ci.includes.empty() && allOf(ci.sources, [&t](const int sid) {
                     const SourceInfo &source = t.sources[static_cast<size_t>(sid)];
-                    return Node::fileTypeForFileName(FilePath::fromString(source.path))
-                           == FileType::Header;
+                    return Node::fileTypeForFileName(source.path) == FileType::Header;
                 })) {
                 qWarning() << "Not reporting all-header compilegroup of target" << t.name
                            << "to code model.";
@@ -528,18 +527,18 @@ static RawProjectParts generateRawProjectParts(const QFuture<void> &cancelFuture
                                                  && !isUnityFile(buildDirectory, filePath);
                                          });
 
-            rpp.setFiles(Utils::transform(filtered, &FilePath::toFSPathString),
+            rpp.setFiles(filtered,
                          {},
-                         [headerMimeType](const QString &path) {
+                         [headerMimeType](const FilePath &path) {
                              if (CppEditor::ProjectFile::isAmbiguousHeader(path))
                                  return headerMimeType;
                              return Utils::mimeTypeForFile(path).name();
                          });
 
             FilePath precompiled_header
-                = FilePath::fromString(findOrDefault(t.sources, [&ending](const SourceInfo &si) {
+                = findOrDefault(t.sources, [&ending](const SourceInfo &si) {
                                            return si.path.endsWith(ending);
-                                       }).path);
+                                       }).path;
             if (!precompiled_header.isEmpty()) {
                 precompiled_header = sourceDirectory.resolvePath(precompiled_header);
 
@@ -563,7 +562,7 @@ static RawProjectParts generateRawProjectParts(const QFuture<void> &cancelFuture
                 FilePath qtc_precompiled_header = precompiled_header.parentDir().pathAppended(qtcPchFile);
                 FileUtils::copyIfDifferent(precompiled_header, qtc_precompiled_header);
 
-                rpp.setPreCompiledHeaders({qtc_precompiled_header.path()});
+                rpp.setPreCompiledHeaders({qtc_precompiled_header});
             }
 
             RawProjectPartFlags projectFlags;
@@ -795,9 +794,9 @@ static void addTargets(FolderNode *root,
     };
 
     auto createTargetNode = [](auto &cmakeListsNodes,
-                               const Utils::FilePath &dir,
+                               const FilePath &dir,
                                const QString &displayName) -> CMakeTargetNode * {
-        auto *cmln = cmakeListsNodes.value(dir);
+        FolderNode *cmln = cmakeListsNodes.value(dir);
         QTC_ASSERT(cmln, return nullptr);
 
         QString targetId = displayName;
