@@ -15,7 +15,6 @@
 #include <QCheckBox>
 #include <QDialog>
 #include <QDialogButtonBox>
-#include <QFutureWatcher>
 #include <QJsonDocument>
 #include <QJsonObject>
 #include <QLabel>
@@ -312,7 +311,7 @@ public:
     QString m_input;
     LocatorFilterEntries m_output;
     int m_parallelLimit = 0;
-    TaskTreeRunner m_taskTreeRunner;
+    SingleTaskTreeRunner m_taskTreeRunner;
 };
 
 LocatorMatcher::LocatorMatcher()
@@ -387,7 +386,7 @@ void LocatorMatcher::start()
         });
     };
 
-    const Group root {
+    const Group recipe {
         parallel,
         collectorStorage,
         AsyncTask<LocatorFilterEntries>(onCollectorSetup, onCollectorDone),
@@ -396,7 +395,7 @@ void LocatorMatcher::start()
             TaskTreeTask(onTaskTreeSetup)
         }
     };
-    d->m_taskTreeRunner.start(root, {}, [this](DoneWith result) {
+    d->m_taskTreeRunner.start(recipe, {}, [this](DoneWith result) {
         emit done(result == DoneWith::Success);
     });
 }
@@ -1321,7 +1320,7 @@ FilePaths LocatorFileCache::processFilePaths(const QFuture<void> &future,
             filterEntry.displayName = path.fileName();
             filterEntry.filePath = path;
             filterEntry.extraInfo = path.shortNativePath();
-            filterEntry.linkForEditor = Link(path, inputLink.targetLine, inputLink.targetColumn);
+            filterEntry.linkForEditor = Link(path, inputLink.target.line, inputLink.target.column);
             filterEntry.highlightInfo = hasPathSeparator
                 ? ILocatorFilter::highlightInfo(regExp.match(filterEntry.extraInfo),
                                                 LocatorFilterEntry::HighlightInfo::ExtraInfo)
@@ -1399,7 +1398,7 @@ ExecutableItem LocatorFileCache::matcher() const
         that->update(async.result());
     };
 
-    return AsyncTask<LocatorFileCachePrivate>(onSetup, onDone, CallDoneIf::Success);
+    return AsyncTask<LocatorFileCachePrivate>(onSetup, onDone, CallDone::OnSuccess);
 }
 
 } // Core
