@@ -1,27 +1,24 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "navigationsubwidget.h"
-#include "navigationwidget.h"
 
 #include "actionmanager/actionmanager.h"
 #include "actionmanager/command.h"
+#include "coreplugintr.h"
+#include "icore.h"
 #include "inavigationwidgetfactory.h"
-
-#include <coreplugin/icore.h>
+#include "navigationwidget.h"
 
 #include <utils/styledbar.h>
+#include <utils/stylehelper.h>
 #include <utils/utilsicons.h>
 
-#include <QDebug>
-
 #include <QHBoxLayout>
 #include <QMenu>
 #include <QResizeEvent>
 #include <QToolButton>
 
-Q_DECLARE_METATYPE(Core::INavigationWidgetFactory *)
-
 using namespace Utils;
 
 namespace Core {
@@ -53,16 +50,16 @@ NavigationSubWidget::NavigationSubWidget(NavigationWidget *parentWidget, int pos
 
     auto splitAction = new QToolButton();
     splitAction->setIcon(Utils::Icons::SPLIT_HORIZONTAL_TOOLBAR.icon());
-    splitAction->setToolTip(tr("Split"));
+    splitAction->setToolTip(Tr::tr("Split"));
     splitAction->setPopupMode(QToolButton::InstantPopup);
-    splitAction->setProperty("noArrow", true);
+    splitAction->setProperty(StyleHelper::C_NO_ARROW, true);
     m_splitMenu = new QMenu(splitAction);
     splitAction->setMenu(m_splitMenu);
     connect(m_splitMenu, &QMenu::aboutToShow, this, &NavigationSubWidget::populateSplitMenu);
 
     m_closeButton = new QToolButton();
     m_closeButton->setIcon(Utils::Icons::CLOSE_SPLIT_BOTTOM.icon());
-    m_closeButton->setToolTip(tr("Close"));
+    m_closeButton->setToolTip(Tr::tr("Close"));
 
     toolBarLayout->addWidget(splitAction);
     toolBarLayout->addWidget(m_closeButton);
@@ -134,7 +131,7 @@ void NavigationSubWidget::populateSplitMenu()
                                                                  command->keySequence().toString(
                                                                      QKeySequence::NativeText));
         QAction *action = m_splitMenu->addAction(displayName);
-        connect(action, &QAction::triggered, this, [this, i]() { emit splitMe(i); });
+        connect(action, &QAction::triggered, this, [this, i] { emit splitMe(i); });
     }
 }
 
@@ -166,7 +163,7 @@ void NavigationSubWidget::restoreSettings()
     if (!m_navigationWidget || !factory())
         return;
 
-    QSettings *settings = Core::ICore::settings();
+    QtcSettings *settings = Core::ICore::settings();
     settings->beginGroup(m_parentWidget->settingsGroup());
     factory()->restoreSettings(settings, position(), m_navigationWidget);
     settings->endGroup();
@@ -220,7 +217,7 @@ bool CommandComboBox::event(QEvent *e)
     if (e->type() == QEvent::ToolTip) {
         const QString text = currentText();
         if (const Core::Command *cmd = command(text)) {
-            const QString tooltip = tr("Activate %1 View").arg(text);
+            const QString tooltip = Tr::tr("Activate %1 View").arg(text);
             setToolTip(cmd->stringWithAppendedShortcut(tooltip));
         } else {
             setToolTip(text);
