@@ -114,6 +114,25 @@ void OpenDocumentsTreeView::setCloseButtonVisible(bool visible)
     m_delegate->setCloseButtonVisible(visible);
 }
 
+void OpenDocumentsTreeView::mousePressEvent(QMouseEvent *e)
+{
+    // ignore press in "close button" column
+    // to avoid selection
+    if (indexAt(e->position().toPoint()).column() != 1)
+        TreeView::mousePressEvent(e);
+}
+
+void OpenDocumentsTreeView::mouseReleaseEvent(QMouseEvent *e)
+{
+    // manually handle click in "close button" column
+    // to avoid selection
+    const QModelIndex mouseIndex = indexAt(e->position().toPoint());
+    if (mouseIndex.column() == 1)
+        emit activated(mouseIndex);
+    else
+        TreeView::mouseReleaseEvent(e);
+}
+
 bool OpenDocumentsTreeView::eventFilter(QObject *obj, QEvent *event)
 {
     if (obj == this && event->type() == QEvent::KeyPress
