@@ -4,16 +4,20 @@
 #include "systemsettings.h"
 
 #include "coreconstants.h"
-#include "coreplugin.h"
 #include "coreplugintr.h"
 #include "editormanager/editormanager_p.h"
 #include "dialogs/ioptionspage.h"
 #include "fileutils.h"
 #include "icore.h"
-#include "iversioncontrol.h"
+#include "iversioncontrol.h" // sic!
 #include "vcsmanager.h"
 
+#ifdef ENABLE_CRASHREPORTING
+#include "coreplugin.h"
+#endif
+
 #include <utils/algorithm.h>
+#include <utils/appinfo.h>
 #include <utils/checkablemessagebox.h>
 #include <utils/elidinglabel.h>
 #include <utils/environment.h>
@@ -25,8 +29,10 @@
 #include <utils/unixutils.h>
 
 #include <QComboBox>
+#include <QDesktopServices>
 #include <QGuiApplication>
 #include <QLineEdit>
+#include <QMenu>
 #include <QMessageBox>
 #include <QPushButton>
 #include <QToolButton>
@@ -36,7 +42,7 @@ using namespace Layouting;
 
 namespace Core::Internal {
 
-#ifdef ENABLE_CRASHPAD
+#ifdef CRASHREPORTING_USES_CRASHPAD
 // TODO: move to somewhere in Utils
 static QString formatSize(qint64 size)
 {
@@ -51,7 +57,7 @@ static QString formatSize(qint64 size)
     return i == 0 ? QString("%0 %1").arg(outputSize).arg(units[i]) // Bytes
                   : QString("%0 %1").arg(outputSize, 0, 'f', 2).arg(units[i]); // KB, MB, GB, TB
 }
-#endif // ENABLE_CRASHPAD
+#endif // CRASHREPORTING_USES_CRASHPAD
 
 SystemSettings &systemSettings()
 {
@@ -60,7 +66,12 @@ SystemSettings &systemSettings()
 }
 
 SystemSettings::SystemSettings()
+    : m_startupSystemEnvironment(Environment::systemEnvironment())
 {
+    const EnvironmentItems changes = EnvironmentItem::fromStringList(
+        ICore::settings()->value(kEnvironmentChanges).toStringList());
+    setEnvironmentChanges(changes);
+
     setAutoApply(false);
 
     patchCommand.setSettingsKey("General/PatchCommand");
@@ -129,32 +140,32 @@ SystemSettings::SystemSettings()
     reloadSetting.addOption(Tr::tr("Always Ask"));
     reloadSetting.addOption(Tr::tr("Reload All Unchanged Editors"));
     reloadSetting.addOption(Tr::tr("Ignore Modifications"));
-    reloadSetting.setDefaultValue(IDocument::AlwaysAsk);
+    reloadSetting.setDefaultValue(IDocument::ReloadUnmodified);
     reloadSetting.setLabelText(Tr::tr("When files are externally modified:"));
 
     askBeforeExit.setSettingsKey("AskBeforeExit");
     askBeforeExit.setLabelText(Tr::tr("Ask for confirmation before exiting"));
     askBeforeExit.setLabelPlacement(BoolAspect::LabelPlacement::Compact);
 
-#ifdef ENABLE_CRASHPAD
+#ifdef ENABLE_CRASHREPORTING
     enableCrashReporting.setSettingsKey("CrashReportingEnabled");
     enableCrashReporting.setLabelPlacement(BoolAspect::LabelPlacement::Compact);
     enableCrashReporting.setLabelText(Tr::tr("Enable crash reporting"));
     enableCrashReporting.setToolTip(
-        Tr::tr("Allow crashes to be automatically reported. Collected reports are "
-           "used for the sole purpose of fixing bugs."));
-
-    showCrashButton.setSettingsKey("ShowCrashButton");
-#endif
+        "<p>"
+        + Tr::tr("Allow crashes to be automatically reported. Collected reports are "
+                 "used for the sole purpose of fixing bugs.")
+        + "</p><p>"
+        + Tr::tr("Crash reports are saved in \"%1\".").arg(appInfo().crashReports.toUserOutput()));
+#endif // ENABLE_CRASHREPORTING
     readSettings();
 
     autoSaveInterval.setEnabler(&autoSaveModifiedFiles);
     autoSuspendMinDocumentCount.setEnabler(&autoSuspendEnabled);
     bigFileSizeLimitInMB.setEnabler(&warnBeforeOpeningBigFiles);
 
-    connect(&autoSaveModifiedFiles, &BaseAspect::changed,
-            this, &EditorManagerPrivate::updateAutoSave);
-    connect(&autoSaveInterval, &BaseAspect::changed, this, &EditorManagerPrivate::updateAutoSave);
+    autoSaveModifiedFiles.addOnChanged(this, &EditorManagerPrivate::updateAutoSave);
+    autoSaveInterval.addOnChanged(this, &EditorManagerPrivate::updateAutoSave);
 }
 
 class SystemSettingsWidget : public IOptionsPageWidget
@@ -167,8 +178,8 @@ public:
         , m_terminalOpenArgs(new QLineEdit)
         , m_terminalExecuteArgs(new QLineEdit)
         , m_environmentChangesLabel(new Utils::ElidingLabel)
-#ifdef ENABLE_CRASHPAD
-        , m_clearCrashReportsButton(new QPushButton(Tr::tr("Clear Local Crash Reports"), this))
+#ifdef CRASHREPORTING_USES_CRASHPAD
+        , m_crashReportsMenuButton(new QPushButton(Tr::tr("Manage"), this))
         , m_crashReportsSizeText(new QLabel(this))
 #endif
 
@@ -192,9 +203,12 @@ public:
         resetFileBrowserButton->setToolTip(Tr::tr("Reset to default."));
         auto helpExternalFileBrowserButton = new QToolButton;
         helpExternalFileBrowserButton->setText(Tr::tr("?"));
-#ifdef ENABLE_CRASHPAD
+#ifdef ENABLE_CRASHREPORTING
         auto helpCrashReportingButton = new QToolButton(this);
         helpCrashReportingButton->setText(Tr::tr("?"));
+        connect(helpCrashReportingButton, &QAbstractButton::clicked, this, [this] {
+            showHelpDialog(Tr::tr("Crash Reporting"), CorePlugin::msgCrashpadInformation());
+        });
 #endif
         auto resetTerminalButton = new QPushButton(Tr::tr("Reset"));
         resetTerminalButton->setToolTip(Tr::tr("Reset to default.", "Terminal"));
@@ -234,11 +248,28 @@ public:
         grid.addRow({Tr::tr("Maximum number of entries in \"Recent Files\":"),
                     Row{s.maxRecentFiles, st}});
         grid.addRow({s.askBeforeExit});
-#ifdef ENABLE_CRASHPAD
-        grid.addRow({s.enableCrashReporting,
-                     Row{m_clearCrashReportsButton,
-                         m_crashReportsSizeText,
-                         helpCrashReportingButton, st}});
+#ifdef ENABLE_CRASHREPORTING
+        Row crashDetails;
+#ifdef CRASHREPORTING_USES_CRASHPAD
+        m_crashReportsMenuButton->setToolTip(s.enableCrashReporting.toolTip());
+        m_crashReportsSizeText->setToolTip(s.enableCrashReporting.toolTip());
+        auto crashReportsMenu = new QMenu(m_crashReportsMenuButton);
+        m_crashReportsMenuButton->setMenu(crashReportsMenu);
+        crashDetails.addItems({m_crashReportsMenuButton, m_crashReportsSizeText});
+#endif // CRASHREPORTING_USES_CRASHPAD
+        crashDetails.addItem(helpCrashReportingButton);
+        if (qtcEnvironmentVariableIsSet("QTC_SHOW_CRASHBUTTON")) {
+            auto crashButton = new QPushButton("CRASH!!!");
+            connect(crashButton, &QPushButton::clicked, [] {
+                // do a real crash
+                volatile int *a = reinterpret_cast<volatile int *>(NULL);
+                *a = 1;
+            });
+            crashDetails.addItem(crashButton);
+        }
+        crashDetails.addItem(st);
+        grid.addRow({s.enableCrashReporting, crashDetails});
+
 #endif
 
         Column {
@@ -263,35 +294,54 @@ public:
             m_externalFileBrowserEdit->setText(UnixUtils::fileBrowser(ICore::settings()));
         }
 
-#ifdef ENABLE_CRASHPAD
-        if (s.showCrashButton()) {
-            auto crashButton = new QPushButton("CRASH!!!");
-            crashButton->show();
-            connect(crashButton, &QPushButton::clicked, [] {
-                // do a real crash
-                volatile int* a = reinterpret_cast<volatile int *>(NULL); *a = 1;
-            });
-        }
+#if defined(ENABLE_CRASHREPORTING) && defined(CRASHREPORTING_USES_CRASHPAD)
+        const FilePaths reportsPaths
+            = {ICore::crashReportsPath() / "completed",
+               ICore::crashReportsPath() / "reports",
+               ICore::crashReportsPath() / "attachments",
+               ICore::crashReportsPath() / "pending",
+               ICore::crashReportsPath() / "new"};
 
-        connect(helpCrashReportingButton, &QAbstractButton::clicked, this, [this] {
-            showHelpDialog(Tr::tr("Crash Reporting"), CorePlugin::msgCrashpadInformation());
-        });
-        connect(&s.enableCrashReporting, &BaseAspect::changed, this, [this] {
-            const QString restartText = Tr::tr("The change will take effect after restart.");
-            Core::RestartDialog restartDialog(Core::ICore::dialogParent(), restartText);
-            restartDialog.exec();
-            if (restartDialog.result() == QDialog::Accepted)
-                apply();
+        auto openLocationAction = new QAction(Tr::tr("Go to Crash Reports"));
+        connect(openLocationAction, &QAction::triggered, this, [reportsPaths] {
+            const FilePath path = reportsPaths.first().parentDir();
+            if (!QDesktopServices::openUrl(path.toUrl())) {
+                qWarning() << "Failed to open path:" << path;
+            }
         });
+        crashReportsMenu->addAction(openLocationAction);
 
+        auto clearAction = new QAction(Tr::tr("Clear Crash Reports"));
+        crashReportsMenu->addAction(clearAction);
+
+        const auto updateClearCrashWidgets = [this, reportsPaths] {
+            qint64 size = 0;
+            FilePath::iterateDirectories(
+                reportsPaths,
+                [&size](const FilePath &item) {
+                    size += item.fileSize();
+                    return IterationPolicy::Continue;
+                },
+                FileFilter({}, QDir::Files, QDirIterator::Subdirectories));
+            m_crashReportsMenuButton->setEnabled(size > 0);
+            m_crashReportsSizeText->setText(formatSize(size));
+        };
         updateClearCrashWidgets();
-        connect(m_clearCrashReportsButton, &QPushButton::clicked, this, [&] {
-            const FilePaths &crashFiles = ICore::crashReportsPath().dirEntries(QDir::Files);
-            for (const FilePath &file : crashFiles)
-                file.removeFile();
-            updateClearCrashWidgets();
-        });
-#endif
+        connect(
+            clearAction,
+            &QAction::triggered,
+            this,
+            [updateClearCrashWidgets, reportsPaths] {
+                FilePath::iterateDirectories(
+                    reportsPaths,
+                    [](const FilePath &item) {
+                        item.removeRecursively();
+                        return IterationPolicy::Continue;
+                    },
+                    FileFilter({}, QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot));
+                updateClearCrashWidgets();
+            });
+#endif // ENABLE_CRASHREPORTING && CRASHREPORTING_USES_CRASHPAD
 
         if (HostOsInfo::isAnyUnixHost()) {
             connect(resetTerminalButton,
@@ -337,12 +387,11 @@ public:
         updatePath();
 
         m_environmentChangesLabel->setElideMode(Qt::ElideRight);
-        m_environmentChanges = CorePlugin::environmentChanges();
+        m_environmentChanges = systemSettings().environmentChanges();
         updateEnvironmentChangesLabel();
         connect(environmentButton, &QPushButton::clicked, this, [this, environmentButton] {
             std::optional<EnvironmentItems> changes
-                = Utils::EnvironmentDialog::getEnvironmentItems(environmentButton,
-                                                                m_environmentChanges);
+                = runEnvironmentItemsDialog(environmentButton, m_environmentChanges);
             if (!changes)
                 return;
             m_environmentChanges = *changes;
@@ -352,6 +401,8 @@ public:
 
         connect(VcsManager::instance(), &VcsManager::configurationChanged,
                 this, &SystemSettingsWidget::updatePath);
+
+        setOnCancel([] { systemSettings().cancel(); });
     }
 
 private:
@@ -363,8 +414,6 @@ private:
     void updateTerminalUi(const Utils::TerminalCommand &term);
     void updatePath();
     void updateEnvironmentChangesLabel();
-    void updateClearCrashWidgets();
-
     void showHelpDialog(const QString &title, const QString &helpText);
 
     QComboBox *m_fileSystemCaseSensitivityChooser;
@@ -373,8 +422,8 @@ private:
     QLineEdit *m_terminalOpenArgs;
     QLineEdit *m_terminalExecuteArgs;
     Utils::ElidingLabel *m_environmentChangesLabel;
-#ifdef ENABLE_CRASHPAD
-    QPushButton *m_clearCrashReportsButton;
+#ifdef CRASHREPORTING_USES_CRASHPAD
+    QPushButton *m_crashReportsMenuButton;
     QLabel *m_crashReportsSizeText;
 #endif
     QPointer<QMessageBox> m_dialog;
@@ -410,7 +459,7 @@ void SystemSettingsWidget::apply()
         }
     }
 
-    CorePlugin::setEnvironmentChanges(m_environmentChanges);
+    systemSettings().setEnvironmentChanges(m_environmentChanges);
 }
 
 void SystemSettingsWidget::resetTerminal()
@@ -466,26 +515,31 @@ void SystemSettingsWidget::showHelpDialog(const QString &title, const QString &h
     mb->show();
 }
 
-#ifdef ENABLE_CRASHPAD
-void SystemSettingsWidget::updateClearCrashWidgets()
-{
-    QDir crashReportsDir(ICore::crashReportsPath().path());
-    crashReportsDir.setFilter(QDir::Files);
-    qint64 size = 0;
-    const FilePaths crashFiles = ICore::crashReportsPath().dirEntries(QDir::Files);
-    for (const FilePath &file : crashFiles)
-        size += file.fileSize();
-    m_clearCrashReportsButton->setEnabled(!crashFiles.isEmpty());
-    m_crashReportsSizeText->setText(formatSize(size));
-}
-#endif
-
 void SystemSettingsWidget::showHelpForFileBrowser()
 {
     if (HostOsInfo::isAnyUnixHost() && !HostOsInfo::isMacHost())
         showHelpDialog(Tr::tr("Variables"), UnixUtils::fileBrowserHelpText());
 }
 
+EnvironmentItems SystemSettings::environmentChanges() const
+{
+    return m_environmentChanges;
+}
+
+void SystemSettings::setEnvironmentChanges(const EnvironmentItems &changes)
+{
+    if (m_environmentChanges == changes)
+        return;
+    m_environmentChanges = changes;
+    Environment systemEnv = m_startupSystemEnvironment;
+    systemEnv.modify(changes);
+    Environment::setSystemEnvironment(systemEnv);
+    ICore::settings()->setValueWithDefault(kEnvironmentChanges,
+                                           EnvironmentItem::toStringList(changes));
+    if (ICore::instance())
+        emit ICore::instance()->systemEnvironmentChanged();
+}
+
 // SystemSettingsPage
 
 class SystemSettingsPage final : public IOptionsPage
