@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
@@ -32,10 +32,11 @@ class IAssistProposal;
 
 namespace CppEditor {
 class CppEditorWidget;
-class CppModelManager;
 
 namespace Internal::Tests {
 
+bool isClangFormatPresent();
+
 class CppTestDocument;
 typedef QSharedPointer<CppTestDocument> TestDocumentPtr;
 
@@ -60,7 +61,7 @@ public:
     QString baseDirectory() const { return m_baseDirectory; }
     void setBaseDirectory(const QString &baseDirectory) { m_baseDirectory = baseDirectory; }
 
-    QString filePath() const;
+    Utils::FilePath filePath() const;
     bool writeToDisk() const;
 
     bool hasCursorMarker() const { return m_cursorPosition != -1; }
@@ -83,7 +84,7 @@ public:
     CppEditorWidget *m_editorWidget = nullptr;
 };
 
-using TestDocuments = QVector<CppTestDocument>;
+using TestDocuments = QList<CppTestDocument>;
 
 class VerifyCleanCppModelManager
 {
@@ -123,36 +124,35 @@ public:
     ~TestCase();
 
     bool succeededSoFar() const;
-    static bool openCppEditor(const QString &fileName, TextEditor::BaseTextEditor **editor,
+    static bool openCppEditor(const Utils::FilePath &filePath, TextEditor::BaseTextEditor **editor,
                               CppEditorWidget **editorWidget = nullptr);
     void closeEditorAtEndOfTestCase(Core::IEditor *editor);
 
     static bool closeEditorWithoutGarbageCollectorInvocation(Core::IEditor *editor);
 
     static bool parseFiles(const QString &filePath);
-    static bool parseFiles(const QSet<QString> &filePaths);
+    static bool parseFiles(const QSet<Utils::FilePath> &filePaths);
 
     static CPlusPlus::Snapshot globalSnapshot();
     static bool garbageCollectGlobalSnapshot();
 
-    static bool waitForProcessedEditorDocument(const QString &filePath, int timeOutInMs = 5000);
+    static bool waitForProcessedEditorDocument(
+            const Utils::FilePath &filePath, int timeOutInMs = 5000);
+
     static CPlusPlus::Document::Ptr waitForRehighlightedSemanticDocument(
-            CppEditorWidget *editorWidget);
+        CppEditorWidget *editorWidget, int timeoutInMs = defaultTimeOutInMs);
 
     enum { defaultTimeOutInMs = 30 * 1000 /*= 30 secs*/ };
     static bool waitUntilProjectIsFullyOpened(ProjectExplorer::Project *project,
                                               int timeOutInMs = defaultTimeOutInMs);
-    static CPlusPlus::Document::Ptr waitForFileInGlobalSnapshot(
-            const QString &filePath,
+    static CPlusPlus::Document::Ptr waitForFileInGlobalSnapshot(const Utils::FilePath &filePath,
             int timeOutInMs = defaultTimeOutInMs);
     static QList<CPlusPlus::Document::Ptr> waitForFilesInGlobalSnapshot(
-            const QStringList &filePaths,
-            int timeOutInMs = defaultTimeOutInMs);
+            const Utils::FilePaths &filePaths, int timeOutInMs = defaultTimeOutInMs);
 
-    static bool writeFile(const QString &filePath, const QByteArray &contents);
+    static bool writeFile(const Utils::FilePath &filePath, const QByteArray &contents);
 
 protected:
-    CppModelManager *m_modelManager;
     bool m_succeededSoFar;
 
 private:
@@ -167,10 +167,12 @@ public:
     ~ProjectOpenerAndCloser(); // Closes opened projects
 
     ProjectInfo::ConstPtr open(
-            const QString &projectFile,
+            const Utils::FilePath &projectFile,
             bool configureAsExampleProject = false,
             ProjectExplorer::Kit *kit = nullptr);
 
+    QList<ProjectExplorer::Project *> projects() const { return m_openProjects; };
+
 private:
     QList<ProjectExplorer::Project *> m_openProjects;
 };
@@ -184,8 +186,9 @@ public:
 
     bool isValid() const { return m_isValid; }
     QString path() const { return m_temporaryDir.path().path(); }
+    Utils::FilePath filePath() const { return m_temporaryDir.path(); }
 
-    QString createFile(const QByteArray &relativePath, const QByteArray &contents);
+    Utils::FilePath createFile(const QByteArray &relativePath, const QByteArray &contents);
 
 protected:
     Utils::TemporaryDirectory m_temporaryDir;
@@ -196,11 +199,23 @@ class CPPEDITOR_EXPORT TemporaryCopiedDir : public TemporaryDir
 {
 public:
     explicit TemporaryCopiedDir(const QString &sourceDirPath);
-    QString absolutePath(const QByteArray &relativePath) const;
+    Utils::FilePath absolutePath(const QString &relativePath) const;
 
 private:
     TemporaryCopiedDir();
 };
 
+class SourceFilesRefreshGuard : public QObject
+{
+public:
+    SourceFilesRefreshGuard();
+
+    void expect(int refreshCount) { m_missing = refreshCount; }
+    bool wait();
+
+private:
+    int m_missing = 1;
+};
+
 } // namespace Tests
 } // namespace CppEditor
