@@ -16,7 +16,6 @@
 
 #ifdef WITH_TESTS
 #include "cppquickfix_test.h"
-#include <QtTest>
 #endif
 
 using namespace CPlusPlus;
@@ -269,7 +268,7 @@ private:
                   : changes.cppFile(targetLoc.targetFilePath);
         const Document::Ptr &targetCppDoc = targetFile->cppDocument();
         const QList<AST *> targetAstPath = ASTPath(targetCppDoc)(
-            targetLoc.targetLine, targetLoc.targetColumn + 1);
+            targetLoc.target.line, targetLoc.target.column + 1);
         if (targetAstPath.isEmpty())
             return;
         const AST *targetDeclAst = nullptr;
@@ -324,7 +323,7 @@ private:
                     int lineIndentColumn = sts.indentationColumn(text) + columnOffset;
                     text.replace(0,
                                  TabSettings::firstNonSpace(text),
-                                 tts.indentationString(0, lineIndentColumn, 0, insertionBlock));
+                                 tts.indentationString(0, lineIndentColumn, 0));
                 }
                 functionDoc += text;
             }
@@ -380,12 +379,6 @@ private:
 //! Converts C-style to C++-style comments and vice versa
 class ConvertCommentStyle : public CppQuickFixFactory
 {
-#ifdef WITH_TESTS
-public:
-    static QObject* createTest();
-#endif
-
-private:
     void doMatch(const CppQuickFixInterface &interface,
                  TextEditor::QuickFixOperations &result) override
     {
@@ -422,12 +415,6 @@ private:
 //! Moves function documentation between declaration and implementation.
 class MoveFunctionComments : public CppQuickFixFactory
 {
-#ifdef WITH_TESTS
-public:
-    static QObject* createTest();
-#endif
-
-private:
     void doMatch(const CppQuickFixInterface &interface,
                  TextEditor::QuickFixOperations &result) override
     {
@@ -472,403 +459,26 @@ private:
 };
 
 #ifdef WITH_TESTS
-using namespace Tests;
-
-class ConvertCommentStyleTest : public QObject
+class ConvertCommentStyleTest : public Tests::CppQuickFixTestObject
 {
     Q_OBJECT
-
-private slots:
-    void test_data()
-    {
-        QTest::addColumn<QString>("input");
-        QTest::addColumn<QString>("expectedOutput");
-
-        QTest::newRow("C -> C++ / no selection / single line") << R"(
-int var1;
-/* Other comment, unaffected */
-/* Our @comment */
-/* Another unaffected comment */
-int var2;)" << R"(
-int var1;
-/* Other comment, unaffected */
-// Our comment
-/* Another unaffected comment */
-int var2;)";
-
-        QTest::newRow("C -> C++ / no selection / multi-line / preserved header and footer") << R"(
-/****************************************************
- * some info
- * more @info
- ***************************************************/)" << R"(
-/////////////////////////////////////////////////////
-// some info
-// more info
-/////////////////////////////////////////////////////)";
-
-        QTest::newRow("C -> C++ / no selection / multi-line / non-preserved header and footer") << R"(
-/*
- * some info
- * more @info
- */)" << R"(
-// some info
-// more info
-)";
-
-        QTest::newRow("C -> C++ / no selection / qdoc") << R"(
-/*!
-    \qmlproperty string Type::element.name
-    \qmlproperty int Type::element.id
-
-    \brief Holds the @element name and id.
-*/)" << R"(
-//! \qmlproperty string Type::element.name
-//! \qmlproperty @int Type::element.id
-//!
-//! \brief Holds the element name and id.
-)";
-
-        QTest::newRow("C -> C++ / no selection / doxygen") << R"(
-/*! \class Test
-    \brief A test class.
-
-    A more detailed @class description.
-*/)" << R"(
-//! \class Test
-//! \brief A test class.
-//!
-//! A more detailed class description.
-)";
-
-        QTest::newRow("C -> C++ / selection / single line") << R"(
-int var1;
-/* Other comment, unaffected */
-@{start}/* Our comment */@{end}
-/* Another unaffected comment */
-int var2;)" << R"(
-int var1;
-/* Other comment, unaffected */
-// Our comment
-/* Another unaffected comment */
-int var2;)";
-
-        QTest::newRow("C -> C++ / selection / multi-line / preserved header and footer") << R"(
-/****************************************************
- * @{start}some info
- * more info@{end}
- ***************************************************/)" << R"(
-/////////////////////////////////////////////////////
-// some info
-// more info
-/////////////////////////////////////////////////////)";
-
-        QTest::newRow("C -> C++ / selection / multi-line / non-preserved header and footer") << R"(
-/*@{start}
- * some in@{end}fo
- * more info
- */)" << R"(
-// some info
-// more info
-)";
-
-        QTest::newRow("C -> C++ / selection / qdoc") << R"(
-/*!@{start}
-    \qmlproperty string Type::element.name
-    \qmlproperty int Type::element.id
-
-    \brief Holds the element name and id.
-*/@{end})" << R"(
-//! \qmlproperty string Type::element.name
-//! \qmlproperty int Type::element.id
-//!
-//! \brief Holds the element name and id.
-)";
-
-        QTest::newRow("C -> C++ / selection / doxygen") << R"(
-/** Expand envi@{start}ronment variables in a string.
- *
- * Environment variables are accepted in the @{end}following forms:
- * $SOMEVAR, ${SOMEVAR} on Unix and %SOMEVAR% on Windows.
- * No escapes and quoting are supported.
- * If a variable is not found, it is not substituted.
- */)" << R"(
-//! Expand environment variables in a string.
-//!
-//! Environment variables are accepted in the following forms:
-//! $SOMEVAR, ${SOMEVAR} on Unix and %SOMEVAR% on Windows.
-//! No escapes and quoting are supported.
-//! If a variable is not found, it is not substituted.
-)";
-
-        QTest::newRow("C -> C++ / selection / multiple comments") << R"(
-@{start}/* Affected comment */
-/* Another affected comment */
-/* A third affected comment */@{end}
-/* An unaffected comment */)" << R"(
-// Affected comment
-// Another affected comment
-// A third affected comment
-/* An unaffected comment */)";
-
-        // FIXME: Remove adjacent newline along with last block
-        // FIXME: Use CppRefactoringFile to auto-indent continuation lines?
-        QTest::newRow("C -> C++, indented") << R"(
-struct S {
-    /*
-     * @This is an
-     * indented comment.
-     */
-    void func();
-)" << R"(
-struct S {
-    // This is an
-// indented comment.
-
-    void func();
-)";
-
-        QTest::newRow("C++ -> C / no selection / single line") << R"(
-// Other comment, unaffected
-// Our @comment
-// Another unaffected comment)" << R"(
-// Other comment, unaffected
-/* Our comment */
-// Another unaffected comment)";
-
-        QTest::newRow("C++ -> C / selection / single line") << R"(
-// Other comment, unaffected
-@{start}// Our comment@{end}
-// Another unaffected comment)" << R"(
-// Other comment, unaffected
-/* Our comment */
-// Another unaffected comment)";
-
-        QTest::newRow("C++ -> C / selection / multi-line / preserved header and footer") << R"(
-@{start}/////////////////////////////////////////////////////
-// some info
-// more info
-/////////////////////////////////////////////////////@{end})" << R"(
-/****************************************************/
-/* some info                                        */
-/* more info                                        */
-/****************************************************/)";
-
-        QTest::newRow("C++ -> C / selection / qdoc") << R"(
-@{start}//! \qmlproperty string Type::element.name
-//! \qmlproperty int Type::element.id
-//!
-//! \brief Holds the element name and id.@{end}
-)" << R"(
-/*!
-    \qmlproperty string Type::element.name
-    \qmlproperty int Type::element.id
-
-    \brief Holds the element name and id.
-*/
-)";
-
-        QTest::newRow("C++ -> C / selection / doxygen") << R"(
-@{start}//! \class Test
-//! \brief A test class.
-//!
-//! A more detailed class description.@{end}
-)" << R"(
-/*!
-    \class Test
-    \brief A test class.
-
-    A more detailed class description.
-*/
-)";
-    }
-
-    void test()
-    {
-        QFETCH(QString, input);
-        QFETCH(QString, expectedOutput);
-
-        ConvertCommentStyle factory;
-        QuickFixOperationTest(
-            {CppTestDocument::create("file.h", input.toUtf8(), expectedOutput.toUtf8())},
-            &factory);
-    }
+public:
+    using CppQuickFixTestObject::CppQuickFixTestObject;
 };
-
-class MoveFunctionCommentsTest : public QObject
+class MoveFunctionCommentsTest : public Tests::CppQuickFixTestObject
 {
     Q_OBJECT
-
-private slots:
-    void test_data()
-    {
-        QTest::addColumn<QByteArrayList>("headers");
-        QTest::addColumn<QByteArrayList>("sources");
-
-        const QByteArrayList headersFuncDecl2Def{R"(
-// Function comment
-void @aFunction();
-)", R"(
-void aFunction();
-)"};
-        const QByteArrayList sourcesFuncDecl2Def{R"(
-#include "file.h"
-
-void aFunction() {}
-)", R"(
-#include "file.h"
-
-// Function comment
-void aFunction() {}
-)"};
-        QTest::newRow("function: from decl to def") << headersFuncDecl2Def << sourcesFuncDecl2Def;
-
-        const QByteArrayList headersFuncDef2Decl{R"(
-void aFunction();
-)", R"(
-/* function */
-/* comment */
-void aFunction();
-)"};
-        const QByteArrayList sourcesFuncDef2Decl{R"(
-#include "file.h"
-
-/* function */
-/* comment */
-void a@Function() {}
-)", R"(
-#include "file.h"
-
-void aFunction() {}
-)"};
-        QTest::newRow("function: from def to decl") << headersFuncDef2Decl << sourcesFuncDef2Decl;
-
-        const QByteArrayList headersFuncNoDef{R"(
-// Function comment
-void @aFunction();
-)", R"(
-// Function comment
-void aFunction();
-)"};
-        QTest::newRow("function: no def") << headersFuncNoDef << QByteArrayList();
-
-        const QByteArrayList headersFuncNoDecl{R"(
-// Function comment
-inline void @aFunction() {}
-)", R"(
-// Function comment
-inline void aFunction() {}
-)"};
-        QTest::newRow("function: no decl") << headersFuncNoDecl << QByteArrayList();
-
-        const QByteArrayList headersFuncTemplateDecl2Def{R"(
-// Function comment
-template<typename T> T @aFunction();
-
-template<typename T> inline T aFunction() { return T(); }
-)", R"(
-template<typename T> T aFunction();
-
-// Function comment
-template<typename T> inline T aFunction() { return T(); }
-)"};
-        QTest::newRow("function template: from decl to def") << headersFuncTemplateDecl2Def
-                                                             << QByteArrayList();
-
-        const QByteArrayList headersFuncTemplateDef2Decl{R"(
-template<typename T> T aFunction();
-
-// Function comment
-template<typename T> inline T @aFunction() { return T(); }
-)", R"(
-// Function comment
-template<typename T> T aFunction();
-
-template<typename T> inline T aFunction() { return T(); }
-)"};
-        QTest::newRow("function template: from def to decl") << headersFuncTemplateDef2Decl
-                                                             << QByteArrayList();
-
-        const QByteArrayList headersMemberDecl2Def{R"(
-class C {
-    /**
-      * \brief Foo::aMember
-      */
-    void @aMember();
-)", R"(
-class C {
-    void aMember();
-)"};
-        const QByteArrayList sourcesMemberDecl2Def{R"(
-#include "file.h"
-
-void C::aMember() {}
-)", R"(
-#include "file.h"
-
-/**
-  * \brief Foo::aMember
-  */
-void C::aMember() {}
-)"};
-        QTest::newRow("member function: from decl to def") << headersMemberDecl2Def
-                                                           << sourcesMemberDecl2Def;
-
-        const QByteArrayList headersMemberDef2Decl{R"(
-class C {
-    void aMember();
-)", R"(
-class C {
-    /**
-      * \brief Foo::aMember
-      */
-    void aMember();
-)"};
-        const QByteArrayList sourcesMemberDef2Decl{R"(
-#include "file.h"
-
-/**
-  * \brief Foo::aMember
-  */
-void C::aMember() {@}
-)", R"(
-#include "file.h"
-
-void C::aMember() {}
-)"};
-        QTest::newRow("member function: from def to decl") << headersMemberDef2Decl
-                                                           << sourcesMemberDef2Decl;
-    }
-
-    void test()
-    {
-        QFETCH(QByteArrayList, headers);
-        QFETCH(QByteArrayList, sources);
-
-        QList<TestDocumentPtr> documents;
-        QCOMPARE(headers.size(), 2);
-        documents << CppTestDocument::create("file.h", headers.at(0), headers.at(1));
-        if (!sources.isEmpty()) {
-            QCOMPARE(sources.size(), 2);
-            documents << CppTestDocument::create("file.cpp", sources.at(0), sources.at(1));
-        }
-        MoveFunctionComments factory;
-        QByteArray failMessage;
-        if (QByteArray(QTest::currentDataTag()) == "function template: from def to decl")
-            failMessage = "decl/def switch doesn't work for templates";
-        QuickFixOperationTest(documents, &factory, {}, {}, failMessage);
-    }
+public:
+    using CppQuickFixTestObject::CppQuickFixTestObject;
 };
-
-QObject * ConvertCommentStyle::createTest() { return new ConvertCommentStyleTest; }
-QObject * MoveFunctionComments::createTest() { return new MoveFunctionCommentsTest; }
-
 #endif
+
 } // namespace
 
 void registerRewriteCommentQuickfixes()
 {
-    CppQuickFixFactory::registerFactory<ConvertCommentStyle>();
-    CppQuickFixFactory::registerFactory<MoveFunctionComments>();
+    REGISTER_QUICKFIX_FACTORY_WITH_STANDARD_TEST(ConvertCommentStyle);
+    REGISTER_QUICKFIX_FACTORY_WITH_STANDARD_TEST(MoveFunctionComments);
 }
 
 } // namespace CppEditor::Internal
