@@ -109,6 +109,13 @@ private:
 
 struct DebuggerData
 {
+    ~DebuggerData() {
+        if (terminalProcess && runControl) {
+            auto processInterface = terminalProcess->takeProcessInterface();
+            if (processInterface)
+                processInterface->setParent(runControl);
+        }
+    }
     DebuggerRunParameters runParameters;
     RunControl *runControl = nullptr;
     EnginesDriver enginesDriver = {};
@@ -128,7 +135,7 @@ ExecutableItem coreFileRecipe(const Storage<DebuggerData> &storage)
         {
             TemporaryFile tmp("tmpcore-XXXXXX");
             QTC_CHECK(tmp.open());
-            storage->tempCoreFile = FilePath::fromString(tmp.fileName());
+            storage->tempCoreFile = tmp.filePath();
         }
         QFile *tempCoreFile = fileStorage.activeStorage();
         process.setWorkingDirectory(TemporaryDirectory::masterDirectoryFilePath());
@@ -166,7 +173,7 @@ ExecutableItem coreFileRecipe(const Storage<DebuggerData> &storage)
     };
 }
 
-ExecutableItem terminalRecipe(const Storage<DebuggerData> &storage, const SingleBarrier &barrier)
+ExecutableItem terminalRecipe(const Storage<DebuggerData> &storage, const StoredBarrier &barrier)
 {
     const auto onSetup = [storage, barrier] {
         DebuggerRunParameters &runParameters = storage->runParameters;
@@ -177,7 +184,7 @@ ExecutableItem terminalRecipe(const Storage<DebuggerData> &storage, const Single
         if (useCdbConsole)
             runParameters.setUseTerminal(false);
         if (!runParameters.useTerminal()) {
-            barrier->barrier()->advance();
+            barrier->advance();
             return;
         }
 
@@ -192,7 +199,7 @@ ExecutableItem terminalRecipe(const Storage<DebuggerData> &storage, const Single
         process->setRunData(stub);
 
         QObject::connect(process, &Process::started, process,
-                         [runParameters = &runParameters, process, barrier = barrier->barrier()] {
+                         [runParameters = &runParameters, process, barrier = barrier.activeStorage()] {
             runParameters->setApplicationPid(process->processId());
             runParameters->setApplicationMainThreadId(process->applicationMainThreadId());
             barrier->advance();
@@ -246,10 +253,6 @@ ExecutableItem fixupParamsRecipe(const Storage<DebuggerData> &storage)
             return false;
         }
 
-        // QML and/or mixed are not prepared for it.
-        // runControl->setSupportsReRunning(!q->m_runParameters.isQmlDebugging);
-        runControl->setSupportsReRunning(false); // FIXME: Broken in general.
-
         // FIXME: Disabled due to Android. Make Android device report available ports instead.
         // int neededPorts = 0;
         // if (useQmlDebugger())
@@ -301,13 +304,9 @@ ExecutableItem fixupParamsRecipe(const Storage<DebuggerData> &storage)
     });
 }
 
-ExecutableItem debugServerRecipe(const Storage<DebuggerData> &storage, const SingleBarrier &barrier)
+ProcessTask debugServerTask(const Storage<DebuggerData> &storage)
 {
-    const auto useDebugServer = [storage] {
-        return storage->runControl->usesDebugChannel() && !storage->runParameters.skipDebugServer();
-    };
-
-    const auto onSetup = [storage, barrier](Process &process) {
+    const auto onSetup = [storage](Process &process) {
         process.setUtf8Codec();
         DebuggerRunParameters &runParameters = storage->runParameters;
         RunControl *runControl = storage->runControl;
@@ -320,7 +319,7 @@ ExecutableItem debugServerRecipe(const Storage<DebuggerData> &storage, const Sin
             cmd.addArg(qmlDebugTcpArguments(QmlDebuggerServices, runControl->qmlChannel()));
             cmd.addArgs(commandLine.arguments(), CommandLine::Raw);
         } else {
-            cmd.setExecutable(runControl->device()->debugServerPath());
+            cmd.setExecutable(runControl->device()->deviceToolPath(Constants::DEBUGSERVER_TOOL_ID));
 
             if (cmd.isEmpty()) {
                 if (runControl->device()->osType() == Utils::OsTypeMac) {
@@ -415,8 +414,6 @@ ExecutableItem debugServerRecipe(const Storage<DebuggerData> &storage, const Sin
             runControl->postMessage(process->readAllStandardError(), StdErrFormat, false);
         });
 
-        QObject::connect(&process, &Process::started, barrier->barrier(), &Barrier::advance);
-
         return SetupResult::Continue;
     };
 
@@ -424,13 +421,7 @@ ExecutableItem debugServerRecipe(const Storage<DebuggerData> &storage, const Sin
         storage->runControl->postMessage(process.errorString(), ErrorMessageFormat);
     };
 
-    return Group {
-        If (useDebugServer) >> Then {
-            ProcessTask(onSetup, onDone, CallDoneIf::Error)
-        } >> Else {
-            Sync([barrier] { barrier->barrier()->advance(); })
-        }
-    };
+    return ProcessTask(onSetup, onDone, CallDone::OnError);
 }
 
 static ExecutableItem doneAwaiter(const Storage<DebuggerData> &storage)
@@ -472,8 +463,7 @@ ExecutableItem startEnginesRecipe(const Storage<DebuggerData> &storage)
         driver->showMessage(DebuggerSettings::dump(), LogDebug);
 
         driver->start();
-        QObject::connect(driver, &EnginesDriver::started,
-                         runStorage().activeStorage(), &RunInterface::started);
+        QObject::connect(driver, &EnginesDriver::started, runControl, &RunControl::reportStarted);
         return true;
     };
 
@@ -659,11 +649,13 @@ void EnginesDriver::start()
                 m_runControl->postMessage(msg, NormalMessageFormat);
                 emit done(engine->runParameters().exitCode() ? DoneResult::Error : DoneResult::Success);
             }
+            if (engine->isPrimaryEngine())
+                stop();
         });
         connect(engine, &DebuggerEngine::postMessageRequested, m_runControl, &RunControl::postMessage);
 
         if (engine->isPrimaryEngine()) {
-            connect(engine, &DebuggerEngine::attachToCoreRequested, this, [this](const QString &coreFile) {
+            connect(engine, &DebuggerEngine::attachToCoreRequested, this, [this](const FilePath &coreFile) {
                 auto rc = new RunControl(ProjectExplorer::Constants::DEBUG_RUN_MODE);
                 rc->copyDataFromRunControl(m_runControl);
                 auto name = QString(
@@ -674,10 +666,9 @@ void EnginesDriver::start()
                 rp.setStartMode(AttachToCore);
                 rp.setCloseMode(DetachAtClose);
                 rp.setDisplayName(name);
-                rp.setCoreFilePath(FilePath::fromString(coreFile));
+                rp.setCoreFilePath(coreFile);
                 rp.setSnapshot(true);
-                auto debugger = createDebuggerWorker(rc, rp);
-                Q_UNUSED(debugger)
+                rc->setRunRecipe(debuggerRecipe(rc, rp));
                 rc->start();
             });
         }
@@ -720,14 +711,10 @@ Group debuggerRecipe(RunControl *runControl, const DebuggerRunParameters &initia
             parametersModifier(storage->runParameters);
     };
 
-    const auto terminalKicker = [storage](const SingleBarrier &barrier) {
+    const auto terminalKicker = [storage](const StoredBarrier &barrier) {
         return terminalRecipe(storage, barrier);
     };
 
-    const auto debugServerKicker = [storage](const SingleBarrier &barrier) {
-        return debugServerRecipe(storage, barrier);
-    };
-
     const auto onDone = [storage] {
         if (storage->tempCoreFile.exists())
             storage->tempCoreFile.removeFile();
@@ -735,6 +722,12 @@ Group debuggerRecipe(RunControl *runControl, const DebuggerRunParameters &initia
             storage->runParameters.coreFile().removeFile();
     };
 
+    const auto useDebugServer = [storage] {
+        return storage->runControl->usesDebugChannel() && !storage->runParameters.skipDebugServer();
+    };
+
+    const ExecutableItem enginesRecipe = startEnginesRecipe(storage);
+
     return {
         storage,
         continueOnError,
@@ -743,40 +736,36 @@ Group debuggerRecipe(RunControl *runControl, const DebuggerRunParameters &initia
             fixupParamsRecipe(storage),
             coreFileRecipe(storage),
             When (terminalKicker) >> Do {
-                When (debugServerKicker) >> Do {
-                    startEnginesRecipe(storage)
+                If (useDebugServer) >> Then {
+                    When (debugServerTask(storage), &Process::started) >> Do {
+                        enginesRecipe
+                    }
+                } >> Else {
+                    enginesRecipe
                 }
             }
-        }.withCancel(canceler()),
+        }.withCancel(runControl->canceler()),
         finalizeRecipe(storage),
         onGroupDone(onDone)
     };
 }
 
-RunWorker *createDebuggerWorker(RunControl *runControl, const DebuggerRunParameters &initialParameters,
-                                const std::function<void(DebuggerRunParameters &)> &parametersModifier)
-{
-    return new RunWorker(runControl,
-                         debuggerRecipe(runControl, initialParameters, parametersModifier));
-}
-
 class DebuggerRunWorkerFactory final : public RunWorkerFactory
 {
 public:
     DebuggerRunWorkerFactory()
     {
-        setProducer([](RunControl *runControl) {
-            return createDebuggerWorker(runControl, DebuggerRunParameters::fromRunControl(runControl));
-        });
         setId(Constants::DEBUGGER_RUN_FACTORY);
+        setRecipeProducer([](RunControl *runControl) {
+            return debuggerRecipe(runControl, DebuggerRunParameters::fromRunControl(runControl));
+        });
 
         addSupportedRunMode(ProjectExplorer::Constants::DEBUG_RUN_MODE);
         addSupportedRunMode(ProjectExplorer::Constants::DAP_CMAKE_DEBUG_RUN_MODE);
         addSupportedRunMode(ProjectExplorer::Constants::DAP_GDB_DEBUG_RUN_MODE);
         addSupportedRunMode(ProjectExplorer::Constants::DAP_LLDB_DEBUG_RUN_MODE);
 
-        addSupportedDeviceType(ProjectExplorer::Constants::DESKTOP_DEVICE_TYPE);
-        addSupportedDeviceType(ProjectExplorer::Constants::DOCKER_DEVICE_TYPE);
+        setExecutionType(ProjectExplorer::Constants::STDPROCESS_EXECUTION_TYPE_ID);
 
         addSupportForLocalRunConfigs();
     }
@@ -787,6 +776,11 @@ void setupDebuggerRunWorker()
     static DebuggerRunWorkerFactory theDebuggerRunWorkerFactory;
 }
 
+QString msgAttachToProcess()
+{
+    return Tr::tr("&Attach to Process");
+}
+
 } // Debugger
 
 #include "debuggerruncontrol.moc"
