@@ -1,12 +1,11 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
 #include <debugger/debuggerengine.h>
 
 #include <qmldebug/qdebugmessageclient.h>
-#include <qmldebug/qmloutputparser.h>
 #include <qmljs/qmljsdocument.h>
 
 namespace Debugger::Internal {
@@ -25,7 +24,7 @@ public:
     void logServiceActivity(const QString &service, const QString &logMessage);
 
     void expressionEvaluated(quint32 queryId, const QVariant &result);
-    QString toFileInProject(const QUrl &fileUrl);
+    Utils::FilePath toFileInProject(const QUrl &fileUrl);
 
 private:
     void disconnected();
@@ -75,9 +74,9 @@ private:
     void assignValueInDebugger(WatchItem *item,
         const QString &expr, const QVariant &value) override;
 
-    void loadSymbols(const QString &moduleName) override;
+    void loadSymbols(const Utils::FilePath &moduleName) override;
     void loadAllSymbols() override;
-    void requestModuleSymbols(const QString &moduleName) override;
+    void requestModuleSymbols(const Utils::FilePath &moduleName) override;
     void reloadModules() override;
     void reloadRegisters() override {}
     void reloadSourceFiles() override;
@@ -91,7 +90,6 @@ private:
 
     bool companionPreventsActions() const override;
     bool hasCapability(unsigned) const override;
-    void quitDebugger() override;
 
     void doUpdateLocals(const UpdateParameters &params) override;
     Core::Context languageContext() const override;
