@@ -18,36 +18,37 @@
 #include <QCheckBox>
 #include <QFormLayout>
 
+using namespace Utils;
+
 namespace Gerrit::Internal {
 
 class GerritOptionsWidget : public Core::IOptionsPageWidget
 {
 public:
-    GerritOptionsWidget(const std::shared_ptr<GerritParameters> &p,
-                        const std::function<void()> &onChanged)
-        : m_parameters(p)
+    GerritOptionsWidget(const std::function<void()> &onChanged)
     {
-        auto hostLineEdit = new QLineEdit(p->server.host);
+        const GerritParameters &s = gerritSettings();
+        auto hostLineEdit = new QLineEdit(s.server.host);
 
-        auto userLineEdit = new QLineEdit(p->server.user.userName);
+        auto userLineEdit = new QLineEdit(s.server.user.userName);
 
         auto sshChooser = new Utils::PathChooser;
-        sshChooser->setFilePath(p->ssh);
+        sshChooser->setFilePath(s.ssh);
         sshChooser->setExpectedKind(Utils::PathChooser::ExistingCommand);
         sshChooser->setCommandVersionArguments({"-V"});
         sshChooser->setHistoryCompleter("Git.SshCommand.History");
 
         auto curlChooser = new Utils::PathChooser;
-        curlChooser->setFilePath(p->curl);
+        curlChooser->setFilePath(s.curl);
         curlChooser->setExpectedKind(Utils::PathChooser::ExistingCommand);
         curlChooser->setCommandVersionArguments({"-V"});
 
         auto portSpinBox = new QSpinBox(this);
         portSpinBox->setRange(1, 65535);
-        portSpinBox->setValue(p->server.port);
+        portSpinBox->setValue(s.server.port);
 
         auto httpsCheckBox = new QCheckBox(Git::Tr::tr("HTTPS"));
-        httpsCheckBox->setChecked(p->https);
+        httpsCheckBox->setChecked(s.https);
         httpsCheckBox->setToolTip(Git::Tr::tr(
             "Determines the protocol used to form a URL in case\n"
             "\"canonicalWebUrl\" is not configured in the file\n"
@@ -63,42 +64,46 @@ public:
             Git::Tr::tr("P&rotocol:"), httpsCheckBox
         }.attachTo(this);
 
-        setOnApply([this, hostLineEdit, userLineEdit, sshChooser,
-                    curlChooser, portSpinBox, httpsCheckBox, onChanged] {
-            GerritParameters newParameters;
-            newParameters.server = GerritServer(hostLineEdit->text().trimmed(),
-                                         static_cast<unsigned short>(portSpinBox->value()),
-                                         userLineEdit->text().trimmed(),
-                                         GerritServer::Ssh);
-            newParameters.ssh = sshChooser->filePath();
-            newParameters.curl = curlChooser->filePath();
-            newParameters.https = httpsCheckBox->isChecked();
+        setOnApply([hostLineEdit,
+                    userLineEdit,
+                    sshChooser,
+                    curlChooser,
+                    portSpinBox,
+                    httpsCheckBox,
+                    onChanged] {
+            GerritParameters &s = gerritSettings();
 
-            if (newParameters != *m_parameters) {
-                if (m_parameters->ssh == newParameters.ssh)
-                    newParameters.portFlag = m_parameters->portFlag;
-                else
-                    newParameters.setPortFlagBySshType();
-                *m_parameters = newParameters;
-                m_parameters->toSettings(Core::ICore::settings());
-                emit onChanged();
-            }
+            GerritServer server(hostLineEdit->text().trimmed(),
+                                static_cast<unsigned short>(portSpinBox->value()),
+                                userLineEdit->text().trimmed(),
+                                GerritServer::Ssh);
+            FilePath ssh = sshChooser->filePath();
+            FilePath curl = curlChooser->filePath();
+            bool https = httpsCheckBox->isChecked();
+
+            if (server == s.server && ssh == s.ssh && curl == s.curl && https == s.https)
+                return;
+
+            s.server = server;
+            s.ssh = ssh;
+            s.curl = curl;
+            s.https = https;
+            if (s.ssh != ssh)
+                s.setPortFlagBySshType();
+            s.toSettings();
+            emit onChanged();
         });
     }
-
-private:
-    const std::shared_ptr<GerritParameters> &m_parameters;
 };
 
 // GerritOptionsPage
 
-GerritOptionsPage::GerritOptionsPage(const std::shared_ptr<GerritParameters> &p,
-                                     const std::function<void()> &onChanged)
+GerritOptionsPage::GerritOptionsPage(const std::function<void()> &onChanged)
 {
     setId("Gerrit");
     setDisplayName(Git::Tr::tr("Gerrit"));
     setCategory(VcsBase::Constants::VCS_SETTINGS_CATEGORY);
-    setWidgetCreator([p, onChanged] { return new GerritOptionsWidget(p, onChanged); });
+    setWidgetCreator([onChanged] { return new GerritOptionsWidget(onChanged); });
 }
 
 } // Gerrit::Internal
