@@ -212,7 +212,7 @@ void typedAspectCreate(FilePathAspect *aspect, const std::string &key, const sol
     else if (key == "environment")
         aspect->setEnvironment(value.as<Environment>());
     else if (key == "baseFileName")
-        aspect->setBaseFileName(value.as<FilePath>());
+        aspect->setBaseDirectory(value.as<FilePath>());
     else if (key == "valueAcceptor")
         aspect->setValueAcceptor(
             [func = value.as<sol::main_function>()](const QString &oldValue, const QString &newValue)
@@ -435,6 +435,12 @@ void setupSettingsModule()
             sol::property([](SelectionAspect *aspect) {
                 return qvariant_cast<sol::object>(aspect->itemValue());
             }),
+            "volatileValue",
+            sol::property(&SelectionAspect::volatileValue, &SelectionAspect::setVolatileValue),
+            "itemValueForIndex",
+            [](SelectionAspect *aspect, int index) {
+                return qvariant_cast<sol::object>(aspect->itemValueForIndex(index));
+            },
             "addOption",
             sol::overload(
                 [](SelectionAspect &self, const QString &name) { self.addOption(name); },
