@@ -122,7 +122,7 @@ public:
         k->setValue(KIT_MCUTARGET_KITVERSION_KEY, KIT_VERSION);
         k->setValue(KIT_MCUTARGET_OS_KEY, static_cast<int>(mcuTarget->os()));
         k->setValue(KIT_MCUTARGET_TOOLCHAIN_KEY, mcuTarget->toolChainPackage()->toolchainName());
-        k->setAutoDetected(false);
+        k->setDetectionSource(DetectionSource::Manual);
         k->makeSticky();
         if (mcuTarget->toolChainPackage()->isDesktopToolchain())
             k->setDeviceTypeForIcon(DEVICE_TYPE);
@@ -507,12 +507,14 @@ static void askUserAboutMcuSupportKitsUpgrade(const SettingsHandler::Ptr &settin
 {
     const char upgradeMcuSupportKits[] = "UpgradeMcuSupportKits";
 
-    if (!ICore::infoBar()->canInfoBeAdded(upgradeMcuSupportKits))
+    InfoBar *infoBar = ICore::popupInfoBar();
+    if (!infoBar->canInfoBeAdded(upgradeMcuSupportKits))
         return;
 
     InfoBarEntry info(upgradeMcuSupportKits,
                       Tr::tr("New version of Qt for MCUs detected. Upgrade existing kits?"),
                       InfoBarEntry::GlobalSuppression::Enabled);
+    info.setInfoType(InfoLabel::Information);
     using McuKitManager::UpgradeOption;
     static UpgradeOption selectedOption = UpgradeOption::Keep;
 
@@ -534,7 +536,7 @@ static void askUserAboutMcuSupportKitsUpgrade(const SettingsHandler::Ptr &settin
         {},
         InfoBarEntry::ButtonAction::Hide);
 
-    ICore::infoBar()->addInfo(info);
+    infoBar->addInfo(info);
 }
 
 void createAutomaticKits(const SettingsHandler::Ptr &settingsHandler)
@@ -718,9 +720,8 @@ void fixExistingKits(const SettingsHandler::Ptr &settingsHandler)
         if (!kit->hasValue(Constants::KIT_MCUTARGET_KITVERSION_KEY))
             continue;
 
-        if (kit->isAutoDetected()) {
-            kit->setAutoDetected(false);
-        }
+        if (kit->detectionSource().isAutoDetected())
+            kit->setDetectionSource(DetectionSource::Manual);
 
         // Check if the MCU kits are flagged as supplying a QtQuick import path, in order
         // to tell the QMLJS code-model that it won't need to add a fall-back import
