@@ -41,7 +41,7 @@ public:
 
 private:
     void clearWidgets();
-    void addSubWidget(QWidget *widget, const QString &displayName);
+    void addSubWidget(QWidget *widget);
 
     void updateBuildSettings();
     void currentIndexChanged(int index);
@@ -56,8 +56,8 @@ private:
     void deleteConfiguration(BuildConfiguration *toDelete);
     QString uniqueName(const QString &name, bool allowCurrentName);
 
-    Target *m_target = nullptr;
-    BuildConfiguration *m_buildConfiguration = nullptr;
+    QPointer<Target> m_target;
+    QPointer<BuildConfiguration> m_buildConfiguration;
 
     QPushButton *m_addButton = nullptr;
     QPushButton *m_removeButton = nullptr;
@@ -67,24 +67,28 @@ private:
     QMenu *m_addButtonMenu = nullptr;
 
     QList<QWidget *> m_subWidgets;
+    QVBoxLayout *m_layout = nullptr;
 };
 
 BuildSettingsWidget::BuildSettingsWidget(Target *target)
     : m_target(target)
 {
-    auto vbox = new QVBoxLayout(this);
-    vbox->setContentsMargins(0, 0, 0, 0);
+    setWindowTitle(Tr::tr("Build Settings"));
+
+    m_layout = new QVBoxLayout(this);
+    m_layout->setContentsMargins(0, 0, 0, 0);
 
     if (!BuildConfigurationFactory::find(m_target)) {
         auto noSettingsLabel = new QLabel(this);
         noSettingsLabel->setText(Tr::tr("No build settings available"));
         noSettingsLabel->setFont(StyleHelper::uiFont(StyleHelper::UiElementH4));
-        vbox->addWidget(noSettingsLabel);
+        m_layout->addWidget(noSettingsLabel);
         return;
     }
 
     { // Edit Build Configuration row
         m_buildConfigurationComboBox = new QComboBox(this);
+        m_buildConfigurationComboBox->setObjectName("buildConfigCombo"); // used by Squish
         m_buildConfigurationComboBox->setSizeAdjustPolicy(QComboBox::AdjustToContents);
         m_buildConfigurationComboBox->setModel(m_target->buildConfigurationModel());
         setWheelScrollingWithoutFocusBlocked(m_buildConfigurationComboBox);
@@ -98,16 +102,17 @@ BuildSettingsWidget::BuildSettingsWidget(Target *target)
         m_cloneButton = new QPushButton(Tr::tr("Clone..."), this);
 
         auto hbox = new QHBoxLayout();
-        hbox->setContentsMargins(0, 0, 0, 0);
-        hbox->addWidget(new QLabel(Tr::tr("Edit build configuration:"), this));
+        hbox->setContentsMargins(0, 20, 0, 0);
+        hbox->addWidget(new QLabel(Tr::tr("Active build configuration:"), this));
         hbox->addWidget(m_buildConfigurationComboBox);
         hbox->addWidget(m_addButton);
         hbox->addWidget(m_removeButton);
         hbox->addWidget(m_renameButton);
         hbox->addWidget(m_cloneButton);
         hbox->addStretch();
-        vbox->addLayout(hbox);
+        m_layout->addLayout(hbox);
     }
+    m_layout->addStretch(1);
 
     m_buildConfiguration = m_target->activeBuildConfiguration();
     m_buildConfigurationComboBox->setCurrentIndex(
@@ -134,18 +139,20 @@ BuildSettingsWidget::BuildSettingsWidget(Target *target)
     connect(m_target, &Target::kitChanged, this, &BuildSettingsWidget::updateAddButtonMenu);
 }
 
-void BuildSettingsWidget::addSubWidget(QWidget *widget, const QString &displayName)
+void BuildSettingsWidget::addSubWidget(QWidget *widget)
 {
     widget->setParent(this);
     widget->setContentsMargins(0, 2, 0, 0);
 
     auto label = new QLabel(this);
-    label->setText(displayName);
+    label->setText(widget->windowTitle());
     label->setFont(StyleHelper::uiFont(StyleHelper::UiElementH4));
     label->setContentsMargins(0, 18, 0, 0);
 
-    layout()->addWidget(label);
-    layout()->addWidget(widget);
+    const int count = m_layout->count(); // last one is the stretch.
+    QTC_CHECK(count >= 1);
+    m_layout->insertWidget(count - 1, label);
+    m_layout->insertWidget(count, widget);
 
     m_subWidgets.append(label);
     m_subWidgets.append(widget);
@@ -185,9 +192,9 @@ void BuildSettingsWidget::updateBuildSettings()
     m_cloneButton->setEnabled(!bcs.isEmpty());
 
     if (m_buildConfiguration) {
-        m_buildConfiguration->addConfigWidgets([this](QWidget *w, const QString &displayName) {
-            addSubWidget(w, displayName);
-        });
+        const QList<QWidget *> configWidgets = m_buildConfiguration->createConfigWidgets();
+        for (QWidget *widget : configWidgets)
+            addSubWidget(widget);
     }
 }
 
@@ -222,7 +229,7 @@ void BuildSettingsWidget::createConfiguration(const BuildInfo &info_)
                                    Tr::tr("New Configuration"),
                                    Tr::tr("New configuration name:"),
                                    QLineEdit::Normal,
-                                   QString(),
+                                   info.typeName,
                                    &ok),
                                false)
                                .trimmed();
