@@ -25,6 +25,7 @@
 #include <utils/layoutbuilder.h>
 #include <utils/outputformatter.h>
 #include <utils/proxyaction.h>
+#include <utils/stylehelper.h>
 #include <utils/theme/theme.h>
 #include <utils/utilsicons.h>
 
@@ -33,6 +34,7 @@
 #include <QIcon>
 #include <QLabel>
 #include <QPlainTextEdit>
+#include <QPushButton>
 #include <QSpinBox>
 #include <QTextBlock>
 #include <QTextCharFormat>
@@ -127,6 +129,10 @@ CompileOutputWindow::CompileOutputWindow(QAction *cancelBuildAction) :
             Tr::tr("Discarded excessive compile output."),
             Constants::TASK_CATEGORY_COMPILE);
     });
+    connect(&s.overwriteColor, &Utils::BaseAspect::changed,
+            this, &CompileOutputWindow::updateFromSettings);
+    connect(&s.backgroundColor, &Utils::BaseAspect::changed,
+            this, &CompileOutputWindow::updateFromSettings);
 }
 
 CompileOutputWindow::~CompileOutputWindow()
@@ -139,7 +145,16 @@ CompileOutputWindow::~CompileOutputWindow()
 
 void CompileOutputWindow::updateFromSettings()
 {
+    QColor background;
+    if (compileOutputSettings().overwriteColor())
+            background = compileOutputSettings().backgroundColor();
+    if (!background.isValid())
+            background = Utils::creatorColor(Utils::Theme::PaletteBase);
+
+    m_outputWindow->outputFormatter()->setExplicitBackgroundColor(background);
+    Utils::StyleHelper::modifyPaletteBase(m_outputWindow, background);
 }
+
 bool CompileOutputWindow::hasFocus() const
 {
     return m_outputWindow->window()->focusWidget() == m_outputWindow;
@@ -222,7 +237,7 @@ void CompileOutputWindow::registerPositionOf(const Task &task, int linkedOutputL
                                              int offset)
 {
     m_outputWindow->registerPositionOf(
-        task.taskId, linkedOutputLines, skipLines, offset, Core::OutputWindow::TaskSource::Direct);
+        task.id(), linkedOutputLines, skipLines, offset, Core::OutputWindow::TaskSource::Direct);
 }
 
 void CompileOutputWindow::flush()
@@ -279,15 +294,41 @@ CompileOutputSettings::CompileOutputSettings()
     maxCharCount.setToSettingsTransformation([](const QVariant &v) { return v.toInt() / 100; });
     maxCharCount.setFromSettingsTransformation([](const QVariant &v) { return v.toInt() * 100; });
 
+    overwriteColor.setSettingsKey("ProjectExplorer/CompileOutput/OverwriteBackground");
+    overwriteColor.setLabelText(Tr::tr("Overwrite background color"));
+    overwriteColor.setToolTip("Customize background color of the compile output.\n"
+                              "Note: existing output will not get recolored.");
+
+    backgroundColor.setSettingsKey("ProjectExplorer/CompileOutput/BackgroundColor");
+    backgroundColor.setDefaultValue(QColor{});
+    backgroundColor.setMinimumSize({64, 0});
+    backgroundColor.setFromSettingsTransformation([](const QVariant &var) {
+        const QColor color = var.value<QColor>();
+        return color.isValid() ? color : Utils::creatorColor(Utils::Theme::PaletteBase);
+    });
+    backgroundColor.setEnabler(&overwriteColor);
+
     setLayouter([this] {
         using namespace Layouting;
         const QString msg = Tr::tr("Limit output to %1 characters");
         const QStringList parts = msg.split("%1") << QString() << QString();
+        auto resetColorButton = new QPushButton(Tr::tr("Reset"));
+        resetColorButton->setToolTip(Tr::tr("Reset to default.", "Color"));
+        connect(resetColorButton, &QPushButton::clicked, this, [this] {
+            backgroundColor.setVolatileValue(QColor{});
+        });
+        connect(&overwriteColor, &Utils::BoolAspect::volatileValueChanged,
+                resetColorButton, [this, resetColorButton] {
+            resetColorButton->setEnabled(overwriteColor.volatileValue());
+        });
+        resetColorButton->setEnabled(overwriteColor());
+
         return Column {
             wrapOutput,
             popUp,
             discardOutput,
             Row { parts.at(0), maxCharCount, parts.at(1), st },
+            Row { overwriteColor, backgroundColor, resetColorButton, st },
             st
         };
     });
