@@ -3,9 +3,12 @@
 
 #pragma once
 
+#include "devicesupport/idevicefwd.h"
 #include "projectexplorer_export.h"
 #include "task.h"
 
+#include <tasking/tasktree.h>
+
 #include <utils/aspects.h>
 
 #include <QPair>
@@ -28,6 +31,70 @@ namespace ProjectExplorer {
 class Kit;
 class KitAspect;
 
+using LogCallback = std::function<void(const QString &message)>;
+
+class DetectionSource
+{
+public:
+    enum DetectionType {
+        Manual,
+        FromSystem,
+        FromSdk,
+        Temporary,
+        Uninitialized,
+    };
+
+    DetectionSource() = default;
+    DetectionSource(DetectionType type, const QString &id = {})
+        : type(type), id(id)
+    {}
+
+    bool isAutoDetected() const
+    {
+        return type == FromSystem || type == FromSdk || type == Temporary;
+    }
+
+    bool isTemporary() const
+    {
+        return type == Temporary;
+    }
+
+    bool isSdkProvided() const
+    {
+        return type == FromSdk;
+    }
+
+    bool isSystemDetected() const
+    {
+        return type == FromSystem;
+    }
+
+    bool operator==(const DetectionSource &other) const
+    {
+        return type == other.type && id == other.id;
+    }
+
+    void fromMap(const Utils::Store &);
+    void toMap(Utils::Store &) const;
+
+    DetectionType type = Uninitialized;
+    QString id;
+
+private:
+    PROJECTEXPLORER_EXPORT friend QDebug operator<<(QDebug dbg, const DetectionSource &source);
+};
+
+PROJECTEXPLORER_EXPORT Tasking::Group kitDetectionRecipe(
+    const IDeviceConstPtr &device,
+    DetectionSource::DetectionType detectionType,
+    const LogCallback &logCallback);
+
+PROJECTEXPLORER_EXPORT Tasking::Group removeDetectedKitsRecipe(
+    const IDeviceConstPtr &device, const LogCallback &logCallback);
+
+PROJECTEXPLORER_EXPORT void listAutoDetected(
+    const IDeviceConstPtr &device, const LogCallback &logCallback);
+
 /**
  * @brief The KitAspectFactory class
  *
@@ -43,6 +110,7 @@ public:
     using ItemList = QList<Item>;
 
     Utils::Id id() const { return m_id; }
+    QList<Utils::Id> jsonKeys() const { return m_jsonKeys; }
     int priority() const { return m_priority; }
     QString displayName() const { return m_displayName; }
     QString description() const { return m_description; }
@@ -59,7 +127,7 @@ public:
 
     virtual int weight(const Kit *k) const;
 
-    virtual QString moduleForHeader(const Kit *k, const QString &className) const;
+    virtual QVariant getInfo(const Kit *k, Utils::Id request, const QVariant &input) const;
 
     virtual ItemList toUserOutput(const Kit *) const = 0;
 
@@ -84,11 +152,31 @@ public:
     static void handleKitsLoaded();
     static const QList<KitAspectFactory *> kitAspectFactories();
 
+    virtual std::optional<Tasking::ExecutableItem> autoDetect(
+        Kit *kit,
+        const Utils::FilePaths &searchPaths,
+        const DetectionSource &detectionSource,
+        const LogCallback &logCallback) const;
+
+    virtual std::optional<Tasking::ExecutableItem> removeAutoDetected(
+        const QString &detectionSourceId, const LogCallback &logCallback) const;
+
+    virtual void listAutoDetected(
+        const QString &detectionSourceId, const LogCallback &logCallback) const;
+
+    virtual Utils::Result<Tasking::ExecutableItem> createAspectFromJson(
+        const DetectionSource &detectionSource,
+        const Utils::FilePath &rootPath,
+        Kit *kit,
+        const QJsonValue &json,
+        const LogCallback &logCallback) const;
+
 protected:
     KitAspectFactory();
     ~KitAspectFactory();
 
     void setId(Utils::Id id) { m_id = id; }
+    void setJsonKeys(const QList<Utils::Id> &ids) { m_jsonKeys = ids; }
     void setDisplayName(const QString &name) { m_displayName = name; }
     void setDescription(const QString &desc) { m_description = desc; }
     void makeEssential() { m_essential = true; }
@@ -100,6 +188,7 @@ private:
     QString m_displayName;
     QString m_description;
     Utils::Id m_id;
+    QList<Utils::Id> m_jsonKeys;
     QList<Utils::Id> m_embeddableAspects;
     int m_priority = 0; // The higher the closer to the top.
     bool m_essential = false;
@@ -110,7 +199,14 @@ class PROJECTEXPLORER_EXPORT KitAspect : public Utils::BaseAspect
     Q_OBJECT
 
 public:
-    enum ItemRole { IdRole = Qt::UserRole + 100, IsNoneRole, TypeRole, QualityRole };
+    enum ItemRole {
+        IdRole = Qt::UserRole + 100,
+        IsNoneRole,
+        FromBuildDeviceRole,
+        FromRunDeviceRole,
+        TypeRole,
+        QualityRole
+    };
 
     KitAspect(Kit *kit, const KitAspectFactory *factory);
     ~KitAspect();
