@@ -62,7 +62,15 @@ public:
 
     ~KitNode() override { delete m_widget; }
 
-    Kit *kit() const { return m_kit; }
+    Kit *kit() const
+    {
+        if (m_widget) {
+            // This is initially the same as m_kit, but potentially gets updated by
+            // "apply" actions. See QTCREATORBUG-33829.
+            return m_widget->kit();
+        }
+        return m_kit;
+    }
 
     QVariant data(int, int role) const override
     {
@@ -150,10 +158,10 @@ public:
     void ensureWidget();
 
 private:
-    Kit *m_kit = m_kit;
-    KitModel *m_model = nullptr;
+    Kit * const m_kit;
+    KitModel * const m_model;
     KitManagerConfigWidget *m_widget = nullptr;
-    QBoxLayout *m_parentLayout = nullptr;
+    QBoxLayout * const m_parentLayout;
     bool m_isDefaultKit = false;
     bool m_hasUniqueName = true;
 };
