@@ -1,16 +1,17 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "projectimporter.h"
 
 #include "buildinfo.h"
+#include "devicesupport/devicekitaspects.h"
 #include "kit.h"
-#include "kitinformation.h"
 #include "kitmanager.h"
-#include "project.h"
 #include "projectexplorerconstants.h"
+#include "projectexplorertr.h"
 #include "target.h"
 #include "toolchain.h"
+#include "toolchainkitaspect.h"
 #include "toolchainmanager.h"
 
 #include <coreplugin/icore.h>
@@ -38,7 +39,7 @@ static Utils::Id fullId(Utils::Id id)
     const QString idStr = id.toString();
     QTC_ASSERT(!idStr.startsWith(prefix), return Utils::Id::fromString(idStr));
 
-    return Utils::Id::fromString(prefix + idStr);
+    return Utils::Id::fromString(prefix).withSuffix(idStr);
 }
 
 static bool hasOtherUsers(Utils::Id id, const QVariant &v, Kit *k)
@@ -53,9 +54,9 @@ static bool hasOtherUsers(Utils::Id id, const QVariant &v, Kit *k)
 
 ProjectImporter::ProjectImporter(const Utils::FilePath &path) : m_projectPath(path)
 {
-    useTemporaryKitAspect(ToolChainKitAspect::id(),
-                               [this](Kit *k, const QVariantList &vl) { cleanupTemporaryToolChains(k, vl); },
-                               [this](Kit *k, const QVariantList &vl) { persistTemporaryToolChains(k, vl); });
+    useTemporaryKitAspect(ToolchainKitAspect::id(),
+                               [this](Kit *k, const QVariantList &vl) { cleanupTemporaryToolchains(k, vl); },
+                               [this](Kit *k, const QVariantList &vl) { persistTemporaryToolchains(k, vl); });
 }
 
 ProjectImporter::~ProjectImporter()
@@ -84,28 +85,28 @@ const QList<BuildInfo> ProjectImporter::import(const Utils::FilePath &importPath
         if (silent)
             return;
         QMessageBox::critical(Core::ICore::dialogParent(),
-                              tr("No Build Found"),
-                              tr("No build found in %1 matching project %2.")
+                              Tr::tr("No Build Found"),
+                              Tr::tr("No build found in %1 matching project %2.")
                                   .arg(importPath.toUserOutput(), projectFilePath().toUserOutput()));
     };
-    qCDebug(log) << "Examining directory" << absoluteImportPath.toString();
+    qCDebug(log) << "Examining directory" << absoluteImportPath.toUserOutput();
     QString warningMessage;
     QList<void *> dataList = examineDirectory(absoluteImportPath, &warningMessage);
     if (dataList.isEmpty()) {
-        qCDebug(log) << "Nothing to import found in" << absoluteImportPath.toString();
+        qCDebug(log) << "Nothing to import found in" << absoluteImportPath.toUserOutput();
         handleFailure();
         return result;
     }
     if (!warningMessage.isEmpty()) {
-        qCDebug(log) << "Warning when examining" << absoluteImportPath.toString();
+        qCDebug(log) << "Warning when examining" << absoluteImportPath.toUserOutput();
         // we should ask user before importing
         if (silent)
             return result;
         QMessageBox dialog(Core::ICore::dialogParent());
-        dialog.setWindowTitle(tr("Import Warning"));
+        dialog.setWindowTitle(Tr::tr("Import Warning"));
         dialog.setText(warningMessage);
         dialog.setIcon(QMessageBox::Warning);
-        QPushButton *acceptButton = dialog.addButton(tr("Import Build"), QMessageBox::AcceptRole);
+        QPushButton *acceptButton = dialog.addButton(Tr::tr("Import Build"), QMessageBox::AcceptRole);
         dialog.addButton(QMessageBox::Cancel);
         dialog.exec();
         if (dialog.clickedButton() != acceptButton)
@@ -137,7 +138,14 @@ const QList<BuildInfo> ProjectImporter::import(const Utils::FilePath &importPath
             }
 
             auto factory = BuildConfigurationFactory::find(k, projectFilePath());
+            if (!factory) {
+                qCDebug(log) << "No factory for kit" << k->displayName();
+                continue;
+            }
             for (BuildInfo i : infoList) {
+                const QVariantMap extraInfo = i.extraInfo.toMap();
+                if (!extraInfo["hideImportedSuffix"].toBool())
+                    i.displayName = Tr::tr("%1 (imported)").arg(i.displayName);
                 i.kitId = k->id();
                 i.factory = factory;
                 if (!result.contains(i))
@@ -173,7 +181,7 @@ Target *ProjectImporter::preferredTarget(const QList<Target *> &possibleTargets)
             return t;
         if (pickedFallback)
             continue;
-        if (DeviceTypeKitAspect::deviceTypeId(t->kit()) == Constants::DESKTOP_DEVICE_TYPE) {
+        if (RunDeviceTypeKitAspect::deviceTypeId(t->kit()) == Constants::DESKTOP_DEVICE_TYPE) {
             activeTarget = t;
             pickedFallback = true;
         }
@@ -188,8 +196,7 @@ void ProjectImporter::markKitAsTemporary(Kit *k) const
     UpdateGuard guard(*this);
 
     const QString name = k->displayName();
-    k->setUnexpandedDisplayName(QCoreApplication::translate("ProjectExplorer::ProjectImporter",
-                                                  "%1 - temporary").arg(name));
+    k->setUnexpandedDisplayName(Tr::tr("%1 - temporary").arg(name));
 
     k->setValue(KIT_TEMPORARY_NAME, k->displayName());
     k->setValue(KIT_FINAL_NAME, name);
@@ -263,7 +270,7 @@ void ProjectImporter::addProject(Kit *k) const
 
     UpdateGuard guard(*this);
     QStringList projects = k->value(TEMPORARY_OF_PROJECTS, QStringList()).toStringList();
-    projects.append(m_projectPath.toString()); // note: There can be more than one instance of the project added!
+    projects.append(m_projectPath.toUrlishString()); // note: There can be more than one instance of the project added!
     k->setValueSilently(TEMPORARY_OF_PROJECTS, projects);
 }
 
@@ -275,7 +282,7 @@ void ProjectImporter::removeProject(Kit *k) const
 
     UpdateGuard guard(*this);
     QStringList projects = k->value(TEMPORARY_OF_PROJECTS, QStringList()).toStringList();
-    projects.removeOne(m_projectPath.toString());
+    projects.removeOne(m_projectPath.toUrlishString());
 
     if (projects.isEmpty()) {
         cleanupKit(k);
@@ -296,8 +303,7 @@ Kit *ProjectImporter::createTemporaryKit(const KitSetupFunction &setup) const
     UpdateGuard guard(*this);
     const auto init = [&](Kit *k) {
         KitGuard kitGuard(k);
-        k->setUnexpandedDisplayName(QCoreApplication::translate("ProjectExplorer::ProjectImporter",
-                                                                "Imported Kit"));
+        k->setUnexpandedDisplayName(Tr::tr("Imported Kit"));
         k->setup();
         setup(k);
         k->fix();
@@ -312,31 +318,31 @@ bool ProjectImporter::findTemporaryHandler(Utils::Id id) const
     return Utils::contains(m_temporaryHandlers, [id](const TemporaryInformationHandler &ch) { return ch.id == id; });
 }
 
-static ToolChain *toolChainFromVariant(const QVariant &v)
+static Toolchain *toolChainFromVariant(const QVariant &v)
 {
     const QByteArray tcId = v.toByteArray();
-    return ToolChainManager::findToolChain(tcId);
+    return ToolchainManager::findToolchain(tcId);
 }
 
-void ProjectImporter::cleanupTemporaryToolChains(Kit *k, const QVariantList &vl)
+void ProjectImporter::cleanupTemporaryToolchains(Kit *k, const QVariantList &vl)
 {
-    for (const QVariant &v : vl) {
-        ToolChain *tc = toolChainFromVariant(v);
-        QTC_ASSERT(tc, continue);
-        ToolChainManager::deregisterToolChain(tc);
-        ToolChainKitAspect::setToolChain(k, nullptr);
-    }
+    const Toolchains toolchains = Utils::transform(vl, toolChainFromVariant);
+    for (Toolchain * const tc : toolchains)
+        ToolchainKitAspect::clearToolchain(k, tc->language());
+    ToolchainManager::deregisterToolchains(toolchains);
 }
 
-void ProjectImporter::persistTemporaryToolChains(Kit *k, const QVariantList &vl)
+void ProjectImporter::persistTemporaryToolchains(Kit *k, const QVariantList &vl)
 {
+    Toolchains toDeregister;
     for (const QVariant &v : vl) {
-        ToolChain *tmpTc = toolChainFromVariant(v);
+        Toolchain *tmpTc = toolChainFromVariant(v);
         QTC_ASSERT(tmpTc, continue);
-        ToolChain *actualTc = ToolChainKitAspect::toolChain(k, tmpTc->language());
+        Toolchain *actualTc = ToolchainKitAspect::toolchain(k, tmpTc->language());
         if (tmpTc && actualTc != tmpTc)
-            ToolChainManager::deregisterToolChain(tmpTc);
+            toDeregister << tmpTc;
     }
+    ToolchainManager::deregisterToolchains(toDeregister);
 }
 
 void ProjectImporter::useTemporaryKitAspect(Utils::Id id,
@@ -368,18 +374,15 @@ bool ProjectImporter::hasKitWithTemporaryData(Utils::Id id, const QVariant &data
     });
 }
 
-static ProjectImporter::ToolChainData createToolChains(const ToolChainDescription &tcd)
+static ProjectImporter::ToolchainData createToolChains(const ToolchainDescription &tcd)
 {
-    ProjectImporter::ToolChainData data;
+    ProjectImporter::ToolchainData data;
 
-    for (ToolChainFactory *factory : ToolChainFactory::allToolChainFactories()) {
+    for (ToolchainFactory *factory : ToolchainFactory::allToolchainFactories()) {
         data.tcs = factory->detectForImport(tcd);
         if (data.tcs.isEmpty())
             continue;
-
-        for (ToolChain *tc : std::as_const(data.tcs))
-            ToolChainManager::registerToolChain(tc);
-
+        ToolchainManager::registerToolchains(data.tcs);
         data.areTemporary = true;
         break;
     }
@@ -387,16 +390,16 @@ static ProjectImporter::ToolChainData createToolChains(const ToolChainDescriptio
     return data;
 }
 
-ProjectImporter::ToolChainData
-ProjectImporter::findOrCreateToolChains(const ToolChainDescription &tcd) const
+ProjectImporter::ToolchainData
+ProjectImporter::findOrCreateToolchains(const ToolchainDescription &tcd) const
 {
-    ToolChainData result;
-    result.tcs = ToolChainManager::toolchains([&tcd](const ToolChain *tc) {
+    ToolchainData result;
+    result.tcs = ToolchainManager::toolchains([&tcd](const Toolchain *tc) {
         return tc->language() == tcd.language && tc->matchesCompilerCommand(tcd.compilerPath);
     });
-    for (const ToolChain *tc : std::as_const(result.tcs)) {
+    for (const Toolchain *tc : std::as_const(result.tcs)) {
         const QByteArray tcId = tc->id();
-        result.areTemporary = result.areTemporary ? true : hasKitWithTemporaryData(ToolChainKitAspect::id(), tcId);
+        result.areTemporary = result.areTemporary ? true : hasKitWithTemporaryData(ToolchainKitAspect::id(), tcId);
     }
     if (!result.tcs.isEmpty())
         return result;
