@@ -18,7 +18,6 @@
 #include <utils/qtcprocess.h>
 #include <utils/qtcassert.h>
 
-#include <QAction>
 #include <QMessageBox>
 
 using namespace Core;
@@ -216,7 +215,7 @@ TaskFile *TaskFile::openTasks(const FilePath &filePath)
 
 bool StopMonitoringHandler::canHandle(const ProjectExplorer::Task &task) const
 {
-    return task.category == Constants::TASK_CATEGORY_TASKLIST_ID;
+    return task.category() == Constants::TASK_CATEGORY_TASKLIST_ID;
 }
 
 void StopMonitoringHandler::handle(const ProjectExplorer::Task &task)
@@ -226,11 +225,11 @@ void StopMonitoringHandler::handle(const ProjectExplorer::Task &task)
     TaskFile::stopMonitoring();
 }
 
-QAction *StopMonitoringHandler::createAction(QObject *parent) const
+QAction *StopMonitoringHandler::createAction() const
 {
     const QString text = Tr::tr("Stop Monitoring");
     const QString toolTip = Tr::tr("Stop monitoring task files.");
-    auto stopMonitoringAction = new QAction(text, parent);
+    auto stopMonitoringAction = new QAction(text);
     stopMonitoringAction->setToolTip(toolTip);
     return stopMonitoringAction;
 }
