@@ -6,10 +6,11 @@
 #include <utils/filepath.h>
 #include <utils/qtcprocess.h>
 
-#include <QFutureWatcher>
 #include <QTimer>
 #include <QUrl>
 
+namespace Tasking { class Group; }
+
 namespace Python::Internal {
 
 class PipPackageInfo
@@ -45,42 +46,20 @@ public:
     QString version;
 };
 
-class Pip : public QObject
+class PipInstallerData
 {
 public:
-    static Pip *instance(const Utils::FilePath &python);
+    QString packagesDisplayName() const;
 
-    QFuture<PipPackageInfo> info(const PipPackage &package);
-
-private:
-    Pip(const Utils::FilePath &python);
-
-    Utils::FilePath m_python;
+    Utils::FilePath python;
+    Utils::FilePath workingDirectory;
+    Utils::FilePath requirementsFile;
+    Utils::FilePath targetPath;
+    QList<PipPackage> packages;
+    bool upgrade = false;
+    bool silent = false;
 };
 
-class PipInstallTask : public QObject
-{
-    Q_OBJECT
-public:
-    explicit PipInstallTask(const Utils::FilePath &python);
-    void setPackage(const PipPackage &package);
-    void run();
-
-signals:
-    void finished(bool success);
-
-private:
-    void cancel();
-    void handleDone();
-    void handleOutput();
-    void handleError();
-
-    const Utils::FilePath m_python;
-    PipPackage m_package;
-    Utils::QtcProcess m_process;
-    QFutureInterface<void> m_future;
-    QFutureWatcher<void> m_watcher;
-    QTimer m_killTimer;
-};
+Tasking::Group pipInstallerTask(const PipInstallerData &data);
 
 } // Python::Internal
