@@ -1,12 +1,16 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "qbsprojectparser.h"
 
 #include "qbsproject.h"
 #include "qbsprojectmanagerconstants.h"
+#include "qbsprojectmanagertr.h"
 #include "qbssettings.h"
 
+#include <coreplugin/progressmanager/progressmanager.h>
+#include <projectexplorer/devicesupport/devicekitaspects.h>
+#include <projectexplorer/kitmanager.h>
 #include <utils/qtcassert.h>
 
 #include <QDir>
@@ -14,6 +18,7 @@
 #include <QFutureWatcher>
 #include <QJsonArray>
 
+using namespace ProjectExplorer;
 using namespace Utils;
 
 namespace QbsProjectManager::Internal {
@@ -22,24 +27,38 @@ namespace QbsProjectManager::Internal {
 // QbsProjectParser:
 // --------------------------------------------------------------------
 
-QbsProjectParser::QbsProjectParser(QbsBuildSystem *buildSystem, QFutureInterface<bool> *fi)
+QbsProjectParser::QbsProjectParser(QbsBuildSystem *buildSystem)
     : m_projectFilePath(buildSystem->project()->projectFilePath()),
       m_session(buildSystem->session()),
-      m_fi(fi)
+      m_device(BuildDeviceKitAspect::device(buildSystem->kit()))
 {
+    m_fi = new QFutureInterface<bool>();
+    m_fi->setProgressRange(0, 0);
+    Core::ProgressManager::addTask(m_fi->future(),
+                                   Tr::tr("Reading Project \"%1\"")
+                                       .arg(buildSystem->project()->displayName()),
+                                   "Qbs.QbsEvaluate");
+    m_fi->reportStarted();
     auto * const watcher = new QFutureWatcher<bool>(this);
     connect(watcher, &QFutureWatcher<bool>::canceled, this, &QbsProjectParser::cancel);
-    watcher->setFuture(fi->future());
+    watcher->setFuture(m_fi->future());
 }
 
 QbsProjectParser::~QbsProjectParser()
 {
-    if (m_session && m_parsing)
-        m_session->cancelCurrentJob();
-    m_fi = nullptr; // we do not own m_fi, do not delete
+    if (m_parsing) {
+        m_session->disconnect(this);
+        cancel();
+    }
+
+    if (m_fi) {
+        m_fi->reportCanceled();
+        m_fi->reportFinished();
+        delete m_fi;
+    }
 }
 
-void QbsProjectParser::parse(const QVariantMap &config, const Environment &env,
+void QbsProjectParser::parse(const Store &config, const Environment &env,
                              const FilePath &dir, const QString &configName)
 {
     QTC_ASSERT(m_session, return);
@@ -48,15 +67,19 @@ void QbsProjectParser::parse(const QVariantMap &config, const Environment &env,
     m_environment = env;
     QJsonObject request;
     request.insert("type", "resolve-project");
-    QVariantMap userConfig = config;
+    Store userConfig = config;
     request.insert("top-level-profile",
                    userConfig.take(Constants::QBS_CONFIG_PROFILE_KEY).toString());
     request.insert("configuration-name", configName);
     request.insert("force-probe-execution",
                    userConfig.take(Constants::QBS_FORCE_PROBES_KEY).toBool());
-    if (QbsSettings::useCreatorSettingsDirForQbs())
-        request.insert("settings-directory", QbsSettings::qbsSettingsBaseDir());
-    request.insert("overridden-properties", QJsonObject::fromVariantMap(userConfig));
+    request.insert(Constants::QBS_RESTORE_BEHAVIOR_KEY,
+                   userConfig.take(Constants::QBS_RESTORE_BEHAVIOR_KEY).toString());
+    const IDeviceConstPtr device = m_device.lock();
+    QTC_ASSERT(device, return);
+    if (QbsSettings::useCreatorSettingsDirForQbs(device))
+        request.insert("settings-directory", QbsSettings::qbsSettingsBaseDir(device).path());
+    request.insert("overridden-properties", QJsonObject::fromVariantMap(mapFromStore(userConfig)));
 
     // People don't like it when files are created as a side effect of opening a project,
     // so do not store the build graph if the build directory does not exist yet.
@@ -67,10 +90,10 @@ void QbsProjectParser::parse(const QVariantMap &config, const Environment &env,
     request.insert("override-build-graph-data", true);
     static const auto envToJson = [](const Environment &env) {
         QJsonObject envObj;
-        for (auto it = env.constBegin(); it != env.constEnd(); ++it) {
-            if (env.isEnabled(it))
-                envObj.insert(env.key(it), env.value(it));
-        }
+        env.forEachEntry([&](const QString &key, const QString &value, bool enabled) {
+            if (enabled)
+                envObj.insert(key, value);
+        });
         return envObj;
     };
     request.insert("environment", envToJson(env));
@@ -81,9 +104,9 @@ void QbsProjectParser::parse(const QVariantMap &config, const Environment &env,
     connect(m_session, &QbsSession::projectResolved, this, [this](const ErrorInfo &error) {
         m_error = error;
         m_projectData = m_session->projectData();
-        emit done(!m_error.hasError());
+        finish(!m_error.hasError());
     });
-    connect(m_session, &QbsSession::errorOccurred, this, [this] { emit done(false); });
+    connect(m_session, &QbsSession::errorOccurred, this, [this] { finish(false); });
     connect(m_session, &QbsSession::taskStarted, this,
             [this](const QString &description, int maxProgress) {
         Q_UNUSED(description)
@@ -98,6 +121,7 @@ void QbsProjectParser::parse(const QVariantMap &config, const Environment &env,
         if (m_fi)
             m_fi->setProgressValue(progress);
     });
+    m_parsing = true;
     m_session->sendRequest(request);
 }
 
@@ -107,4 +131,16 @@ void QbsProjectParser::cancel()
         m_session->cancelCurrentJob();
 }
 
+void QbsProjectParser::finish(bool success)
+{
+    m_parsing = false;
+    m_session->disconnect(this);
+    if (!success)
+        m_fi->reportCanceled();
+    m_fi->reportFinished();
+    delete m_fi;
+    m_fi = nullptr;
+    emit done(success);
+}
+
 } // QbsProjectManager::Internal
