@@ -1,5 +1,5 @@
 // Copyright (C) 2021 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 #pragma once
 
 #include <abstractview.h>
@@ -33,7 +33,7 @@ class NodeListView : public AbstractView
     Q_OBJECT
 
 public:
-    explicit NodeListView(AbstractView *parent);
+    explicit NodeListView(ExternalDependenciesInterface &externalDependencies);
     ~NodeListView() override;
 
     int currentNode() const;
