@@ -17,7 +17,6 @@ QT_FORWARD_DECLARE_CLASS(QPixmap)
 
 namespace QmlDesigner {
 
-class CreateTextures;
 class DesignerActionManager;
 class Model;
 class ModelNode;
@@ -88,7 +87,7 @@ public:
     void updateToolTipPixmap(const ModelNode &node, const QPixmap &pixmap);
 
 signals:
-    void toolTipPixmapUpdated(const QString &id, const QPixmap &pixmap) const;
+    void toolTipPixmapUpdated(const QString &id, const QPixmap &pixmap);
 
 private:
     void moveNodesInteractive(NodeAbstractProperty &parentProperty, const QList<ModelNode> &modelNodes,
@@ -96,16 +95,17 @@ private:
     void handleInternalDrop(const QMimeData *mimeData, int rowNumber, const QModelIndex &dropModelIndex);
     void handleItemLibraryItemDrop(const QMimeData *mimeData, int rowNumber, const QModelIndex &dropModelIndex);
 
-    bool dropAsImage3dTexture(const ModelNode &targetNode, const NodeAbstractProperty &targetProp,
-                              const QString &imagePath, ModelNode &newNode, bool &outMoveNodesAfter);
-    ModelNode createTextureNode(const NodeAbstractProperty &targetProp, const QString &imagePath);
+    bool dropAsImage3dTexture(const ModelNode &targetNode,
+                              const NodeAbstractProperty &targetProp,
+                              const QString &imagePath,
+                              ModelNode &newNode,
+                              bool &outMoveNodesAfter);
     QList<QPersistentModelIndex> nodesToPersistentIndex(const QList<ModelNode> &modelNodes);
     void addImport(const QString &importName);
     QList<ModelNode> filteredList(const NodeListProperty &property, bool filter, bool reverseOrder) const;
     bool moveNodeToParent(const NodeAbstractProperty &targetProperty, const ModelNode &newModelNode);
 
     QPointer<NavigatorView> m_view;
-    Utils::UniqueObjectPtr<CreateTextures> m_createTextures;
     mutable QHash<ModelNode, QModelIndex> m_nodeIndexHash;
     mutable QHash<ModelNode, QList<ModelNode> > m_rowCache;
     bool m_showOnlyVisibleItems = true;
