@@ -1,27 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2018 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2018 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
@@ -52,6 +30,7 @@ class TimelineKeyframeItem;
 class TimelinePlaceholder;
 class TimelineGraphicsLayout;
 class TimelineToolBar;
+class ExternalDependenciesInterface;
 
 class AbstractScrollGraphicsScene : public QGraphicsScene
 {
@@ -88,11 +67,7 @@ public:
 
     virtual void invalidateScrollbar() = 0;
 
-    virtual qreal snap(qreal frame, bool snapToPlayhead = true)
-    {
-        Q_UNUSED(snapToPlayhead);
-        return frame;
-    }
+    virtual qreal snap(qreal frame, [[maybe_unused]] bool snapToPlayhead = true) { return frame; }
 
     QGraphicsView *graphicsView() const;
     QGraphicsView *rulerView() const;
@@ -113,7 +88,8 @@ class TimelineGraphicsScene : public AbstractScrollGraphicsScene
     Q_OBJECT
 
 public:
-    explicit TimelineGraphicsScene(TimelineWidget *parent);
+    explicit TimelineGraphicsScene(TimelineWidget *parent,
+                                   ExternalDependenciesInterface &m_externalDependencies);
 
     ~TimelineGraphicsScene() override;
 
@@ -130,6 +106,7 @@ public:
     void setStartFrame(int frame);
     void setEndFrame(int frame);
 
+    TimelineRulerSectionItem *layoutRuler() const;
     TimelineView *timelineView() const;
     TimelineWidget *timelineWidget() const;
     TimelineToolBar *toolBar() const;
@@ -217,6 +194,8 @@ private:
 
     TimelineToolDelegate m_tools;
 
+    ExternalDependenciesInterface &m_externalDependencies;
+
     // sorted, unique cache of keyframes positions, used for snapping
     QVector<qreal> m_keyframePositionsCache;
     QElapsedTimer m_usageTimer;
