@@ -2,7 +2,7 @@
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "qmljsbundleprovider.h"
-#include "qmljscodestylesettingspage.h"
+#include "qmljscodestylesettings.h"
 #include "qmljsfunctionfilter.h"
 #include "qmljsmodelmanager.h"
 #include "qmljstoolsconstants.h"
@@ -10,35 +10,51 @@
 #include "qmljstoolstr.h"
 #include "qmljstools_test.h"
 
+#include <coreplugin/actionmanager/actioncontainer.h>
+#include <coreplugin/actionmanager/actionmanager.h>
+#include <coreplugin/coreconstants.h>
 #include <coreplugin/icontext.h>
 #include <coreplugin/icore.h>
-#include <coreplugin/coreconstants.h>
-#include <coreplugin/actionmanager/actionmanager.h>
-#include <coreplugin/actionmanager/actioncontainer.h>
 #include <coreplugin/progressmanager/progressmanager.h>
 
 #include <extensionsystem/iplugin.h>
 
+#include <projectexplorer/devicesupport/idevice.h>
+
 #include <qmljseditor/qmljseditorconstants.h>
 
 #include <QMenu>
 
 using namespace Core;
+using namespace ProjectExplorer;
 
 namespace QmlJSTools::Internal {
 
+class QmlRuntimeToolFactory : public DeviceToolAspectFactory
+{
+public:
+    QmlRuntimeToolFactory()
+    {
+        setToolId(Constants::QML_TOOL_ID);
+        setToolType(DeviceToolAspect::RunTool);
+        setFilePattern({"qml"});
+        setLabelText(Tr::tr("QML runtime executable:"));
+        setToolTip(Tr::tr("The QML runtime executable to use on the device."));
+    }
+};
+
 class QmlJSToolsPluginPrivate : public QObject
 {
 public:
     QmlJSToolsPluginPrivate();
 
-    QmlJSToolsSettings settings;
     ModelManager modelManager;
 
     QAction resetCodeModelAction{Tr::tr("Reset Code Model"), nullptr};
 
     QmlJSCodeStyleSettingsPage codeStyleSettingsPage;
     BasicBundleProvider basicBundleProvider;
+    QmlRuntimeToolFactory qmlRuntimeToolFactory;
 };
 
 QmlJSToolsPluginPrivate::QmlJSToolsPluginPrivate()
@@ -94,6 +110,8 @@ private:
 #ifdef WITH_TESTS
         addTestCreator(createQmlJSToolsTest);
 #endif
+        setupQmlJSToolsSettings();
+
         d = new QmlJSToolsPluginPrivate;
 
         setupQmlJSFunctionsFilter();
