@@ -1,31 +1,10 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "inputeventsmodel.h"
-#include "qmlprofilermodelmanager.h"
 #include "qmlprofilereventtypes.h"
+#include "qmlprofilermodelmanager.h"
+#include "qmlprofilertr.h"
 
 #include <tracing/timelineformattime.h>
 
@@ -33,12 +12,11 @@
 #include <QMouseEvent>
 #include <QMetaEnum>
 
-namespace QmlProfiler {
-namespace Internal {
+namespace QmlProfiler::Internal {
 
 InputEventsModel::InputEventsModel(QmlProfilerModelManager *manager,
                                    Timeline::TimelineModelAggregator *parent) :
-    QmlProfilerTimelineModel(manager, Event, MaximumRangeType, ProfileInputEvents, parent),
+    QmlProfilerTimelineModel(manager, Event, UndefinedRangeType, ProfileInputEvents, parent),
     m_keyTypeId(-1), m_mouseTypeId(-1)
 {
 }
@@ -58,12 +36,12 @@ QVariantList InputEventsModel::labels() const
     QVariantList result;
 
     QVariantMap element;
-    element.insert(QLatin1String("description"), QVariant(tr("Mouse Events")));
+    element.insert(QLatin1String("description"), QVariant(Tr::tr("Mouse Events")));
     element.insert(QLatin1String("id"), QVariant(Mouse));
     result << element;
 
     element.clear();
-    element.insert(QLatin1String("description"), QVariant(tr("Keyboard Events")));
+    element.insert(QLatin1String("description"), QVariant(Tr::tr("Keyboard Events")));
     element.insert(QLatin1String("id"), QVariant(Key));
     result << element;
 
@@ -72,62 +50,62 @@ QVariantList InputEventsModel::labels() const
 
 QMetaEnum InputEventsModel::metaEnum(const char *name)
 {
-    return staticQtMetaObject.enumerator(staticQtMetaObject.indexOfEnumerator(name));
+    return Qt::staticMetaObject.enumerator(Qt::staticMetaObject.indexOfEnumerator(name));
 }
 
 QVariantMap InputEventsModel::details(int index) const
 {
     QVariantMap result;
-    result.insert(tr("Timestamp"), Timeline::formatTime(startTime(index),
+    result.insert(Tr::tr("Timestamp"), Timeline::formatTime(startTime(index),
                                                         modelManager()->traceDuration()));
     QString type;
     const Item &event = m_data[index];
     switch (event.type) {
     case InputKeyPress:
-        type = tr("Key Press");
+        type = Tr::tr("Key Press");
         Q_FALLTHROUGH();
     case InputKeyRelease:
         if (type.isEmpty())
-            type = tr("Key Release");
+            type = Tr::tr("Key Release");
         if (event.a != 0) {
-            result.insert(tr("Key"), QLatin1String(metaEnum("Key").valueToKey(event.a)));
+            result.insert(Tr::tr("Key"), QLatin1String(metaEnum("Key").valueToKey(event.a)));
         }
         if (event.b != 0) {
-            result.insert(tr("Modifiers"),
+            result.insert(Tr::tr("Modifiers"),
                           QLatin1String(metaEnum("KeyboardModifiers").valueToKeys(event.b)));
         }
         break;
     case InputMouseDoubleClick:
-        type = tr("Double Click");
+        type = Tr::tr("Double Click");
         Q_FALLTHROUGH();
     case InputMousePress:
         if (type.isEmpty())
-            type = tr("Mouse Press");
+            type = Tr::tr("Mouse Press");
         Q_FALLTHROUGH();
     case InputMouseRelease:
         if (type.isEmpty())
-            type = tr("Mouse Release");
-        result.insert(tr("Button"), QLatin1String(metaEnum("MouseButtons").valueToKey(event.a)));
-        result.insert(tr("Result"), QLatin1String(metaEnum("MouseButtons").valueToKeys(event.b)));
+            type = Tr::tr("Mouse Release");
+        result.insert(Tr::tr("Button"), QLatin1String(metaEnum("MouseButtons").valueToKey(event.a)));
+        result.insert(Tr::tr("Result"), QLatin1String(metaEnum("MouseButtons").valueToKeys(event.b)));
         break;
     case InputMouseMove:
-        type = tr("Mouse Move");
-        result.insert(tr("X"), QString::number(event.a));
-        result.insert(tr("Y"), QString::number(event.b));
+        type = Tr::tr("Mouse Move");
+        result.insert(Tr::tr("X"), QString::number(event.a));
+        result.insert(Tr::tr("Y"), QString::number(event.b));
         break;
     case InputMouseWheel:
-        type = tr("Mouse Wheel");
-        result.insert(tr("Angle X"), QString::number(event.a));
-        result.insert(tr("Angle Y"), QString::number(event.b));
+        type = Tr::tr("Mouse Wheel");
+        result.insert(Tr::tr("Angle X"), QString::number(event.a));
+        result.insert(Tr::tr("Angle Y"), QString::number(event.b));
         break;
     case InputKeyUnknown:
-        type = tr("Keyboard Event");
+        type = Tr::tr("Keyboard Event");
         break;
     case InputMouseUnknown:
-        type = tr("Mouse Event");
+        type = Tr::tr("Mouse Event");
         break;
     default:
-        type = tr("Unknown");
+        type = Tr::tr("Unknown");
         break;
     }
 
@@ -149,6 +127,8 @@ int InputEventsModel::collapsedRow(int index) const
 
 void InputEventsModel::loadEvent(const QmlEvent &event, const QmlEventType &type)
 {
+    if (type.detailType() >= MaximumInputEventType)
+        return;
     m_data.insert(insert(event.timestamp(), 0, type.detailType()),
                   Item(static_cast<InputEventType>(event.number<qint32>(0)),
                              event.number<qint32>(1), event.number<qint32>(2)));
@@ -180,5 +160,4 @@ InputEventsModel::Item::Item(InputEventType type, int a, int b) :
 {
 }
 
-} // namespace Internal
-} // namespace QmlProfiler
+} // namespace QmlProfiler::Internal
