@@ -3,17 +3,13 @@
 
 #pragma once
 
-namespace ProjectExplorer {
-class RunControl;
-class RunWorker;
-}
+namespace ProjectExplorer { class RunControl; }
 namespace Tasking { class Group; }
 
 namespace QmlProfiler::Internal {
 
 Tasking::Group qmlProfilerRecipe(ProjectExplorer::RunControl *runControl);
-
-ProjectExplorer::RunWorker *createLocalQmlProfilerWorker(ProjectExplorer::RunControl *runControl);
+Tasking::Group localQmlProfilerRecipe(ProjectExplorer::RunControl *runControl);
 
 void setupQmlProfilerRunning();
 
