@@ -1,17 +1,18 @@
 // Copyright (C) 2016 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
+
 #pragma once
 
 #include <QObject>
 
-namespace QmlProfiler {
-namespace Internal {
+namespace QmlProfiler::Internal {
 
 class QmlEventTypeTest : public QObject
 {
     Q_OBJECT
+
 public:
-    explicit QmlEventTypeTest(QObject *parent = nullptr);
+    QmlEventTypeTest();
 
 private slots:
     void testAccessors();
@@ -19,5 +20,4 @@ private slots:
     void testStreamOps();
 };
 
-} // namespace Internal
-} // namespace QmlProfiler
+} // namespace QmlProfiler::Internal
