@@ -3,7 +3,7 @@
 
 #include "qmlprofilertraceview_test.h"
 
-#include <QtTest>
+#include <QTest>
 
 namespace QmlProfiler::Internal {
 
