@@ -26,6 +26,8 @@
 #include <extensionsystem/pluginmanager.h>
 #include <extensionsystem/pluginspec.h>
 
+#include <projectexplorer/buildconfiguration.h>
+#include <projectexplorer/buildinfo.h>
 #include <projectexplorer/deploymentdata.h>
 #include <projectexplorer/devicesupport/devicekitaspects.h>
 #include <projectexplorer/devicesupport/idevice.h>
@@ -37,47 +39,45 @@
 #include <utils/algorithm.h>
 #include <utils/fileutils.h>
 #include <utils/filesystemwatcher.h>
+#include <utils/mimeconstants.h>
 #include <utils/qtcassert.h>
 
 #include <texteditor/textdocument.h>
 
 #include <QAction>
-#include <QtCore5Compat/qtextcodec.h>
 
 using namespace ProjectExplorer;
+using namespace Utils;
+using namespace ExtensionSystem;
+
 namespace QmlProjectManager {
 
 namespace {
 Q_LOGGING_CATEGORY(infoLogger, "QmlProjectManager.QmlBuildSystem", QtInfoMsg)
 }
 
-ExtensionSystem::IPlugin *findMcuSupportPlugin()
+IPlugin *findMcuSupportPlugin()
 {
-    const ExtensionSystem::PluginSpec *pluginSpec = Utils::findOrDefault(
-        ExtensionSystem::PluginManager::plugins(),
-        Utils::equal(&ExtensionSystem::PluginSpec::id, QString("mcusupport")));
-
-    if (pluginSpec)
-        return pluginSpec->plugin();
-    return nullptr;
+    const PluginSpec *pluginSpec = PluginManager::specById(QString("mcusupport"));
+    return pluginSpec ? pluginSpec->plugin() : nullptr;
 }
 
-void updateMcuBuildStep(Target *target, bool mcuEnabled)
+void updateMcuBuildStep(BuildConfiguration *bc, bool mcuEnabled)
 {
     if (auto plugin = findMcuSupportPlugin()) {
         QMetaObject::invokeMethod(
             plugin,
             "updateDeployStep",
             Qt::DirectConnection,
-            Q_ARG(ProjectExplorer::Target*, target),
+            Q_ARG(ProjectExplorer::BuildConfiguration *, bc),
             Q_ARG(bool, mcuEnabled));
     } else if (mcuEnabled) {
         qWarning() << "Failed to find McuSupport plugin but qtForMCUs is enabled in the project";
     }
 }
 
-QmlBuildSystem::QmlBuildSystem(Target *target)
-    : BuildSystem(target)
+QmlBuildSystem::QmlBuildSystem(BuildConfiguration *bc)
+    : BuildSystem(bc)
     , m_fileGen(new QmlProjectExporter::Exporter(this))
 {
     // refresh first - project information is used e.g. to decide the default RC's
@@ -86,16 +86,16 @@ QmlBuildSystem::QmlBuildSystem(Target *target)
     updateDeploymentData();
 //    registerMenuButtons(); //is wip
 
-    connect(target->project(), &Project::activeTargetChanged, this, [this](Target *target) {
+    connect(project(), &Project::activeBuildConfigurationChanged, this, [this](BuildConfiguration *bc) {
         refresh(RefreshOptions::NoFileRefresh);
         m_fileGen->updateProject(qmlProject());
-        updateMcuBuildStep(target, qtForMCUs());
+        updateMcuBuildStep(bc, qtForMCUs());
     });
-    connect(target->project(), &Project::projectFileIsDirty, this, [this] {
+    connect(project(), &Project::projectFileIsDirty, this, [this] {
         refresh(RefreshOptions::Project);
         m_fileGen->updateProject(qmlProject());
         m_fileGen->updateMenuAction();
-        updateMcuBuildStep(project()->activeTarget(), qtForMCUs());
+        updateMcuBuildStep(project()->activeBuildConfiguration(), qtForMCUs());
     });
 
     // FIXME: Check. Probably bogus after the BuildSystem move.
@@ -175,7 +175,7 @@ void QmlBuildSystem::triggerParsing()
     refresh(RefreshOptions::Project);
 }
 
-Utils::FilePath QmlBuildSystem::canonicalProjectDir() const
+FilePath QmlBuildSystem::canonicalProjectDir() const
 {
     return projectFilePath()
             .canonicalPath()
@@ -196,29 +196,22 @@ void QmlBuildSystem::refresh(RefreshOptions options)
         parseProjectFiles();
     }
 
-    auto modelManager = QmlJS::ModelManagerInterface::instance();
-    if (!modelManager)
-        return;
-
-    QmlJS::ModelManagerInterface::ProjectInfo projectInfo
-            = modelManager->defaultProjectInfoForProject(project(),
-                                                         project()->files(Project::HiddenRccFolders));
-
-    for (const QString &importPath : absoluteImportPaths()) {
-        projectInfo.importPaths.maybeInsert(Utils::FilePath::fromString(importPath),
-                                            QmlJS::Dialect::Qml);
-    }
-
-    modelManager->updateProjectInfo(projectInfo, project());
+    updateQmlCodeModel();
 
     guard.markAsSuccess();
 
     emit projectChanged();
 }
 
+void QmlBuildSystem::updateQmlCodeModelInfo(QmlCodeModelInfo &projectInfo)
+{
+    for (const QString &importPath : absoluteImportPaths())
+        projectInfo.qmlImportPaths.append(FilePath::fromString(importPath));
+}
+
 void QmlBuildSystem::initProjectItem()
 {
-    auto projectPath = projectFilePath();
+    const FilePath projectPath = projectFilePath();
 
     m_projectItem.reset(new QmlProjectItem{projectPath});
 
@@ -234,19 +227,19 @@ void QmlBuildSystem::initMcuProjectItems()
 
     const QStringList mcuProjectFiles = m_projectItem->qmlProjectModules();
     for (const QString &mcuProjectFile : mcuProjectFiles) {
-        auto qmlProjectItem = QSharedPointer<QmlProjectItem>(
-            new QmlProjectItem{Utils::FilePath::fromString(mcuProjectFile)});
+        FilePath mcuProjectFilePath = projectFilePath().parentDir().resolvePath(mcuProjectFile);
+        auto qmlProjectItem = QSharedPointer<QmlProjectItem>(new QmlProjectItem{mcuProjectFilePath});
 
         m_mcuProjectItems.append(qmlProjectItem);
         connect(qmlProjectItem.data(), &QmlProjectItem::filesChanged, this, &QmlBuildSystem::refreshFiles);
         m_fileGen->updateProjectItem(m_projectItem.data(), false);
 
-        m_mcuProjectFilesWatcher.addFile(mcuProjectFile, Utils::FileSystemWatcher::WatchModifiedDate);
+        m_mcuProjectFilesWatcher.addFile(mcuProjectFilePath, FileSystemWatcher::WatchModifiedDate);
 
         connect(&m_mcuProjectFilesWatcher,
-                &Utils::FileSystemWatcher::fileChanged,
+                &FileSystemWatcher::fileChanged,
                 this,
-                [this](const QString &file) {
+                [this](const FilePath &file) {
                     Q_UNUSED(file)
                     initMcuProjectItems();
                     refresh(RefreshOptions::Files);
@@ -262,13 +255,12 @@ void QmlBuildSystem::parseProjectFiles()
 
     const QString mainFileName = m_projectItem->mainFile();
     if (!mainFileName.isEmpty()) {
-        Utils::FilePath mainFilePath = canonicalProjectDir().resolvePath(mainFileName);
-        Utils::FileReader reader;
-        QString errorMessage;
-        if (!reader.fetch(mainFilePath, &errorMessage)) {
+        const FilePath mainFilePath = canonicalProjectDir().resolvePath(mainFileName);
+        const Result<QByteArray> res = mainFilePath.fileContents();
+        if (!res) {
             Core::MessageManager::writeFlashing(
                 Tr::tr("Warning while loading project file %1.").arg(projectFilePath().toUserOutput()));
-            Core::MessageManager::writeSilently(errorMessage);
+            Core::MessageManager::writeSilently(res.error());
         }
     }
 
@@ -287,7 +279,7 @@ void QmlBuildSystem::generateProjectTree()
         newRoot->addNestedNode(std::make_unique<FileNode>(file, fileType));
     }
 
-    for (const auto &mcuProjectItem : m_mcuProjectItems) {
+    for (const auto &mcuProjectItem : std::as_const(m_mcuProjectItems)) {
         for (const auto &file : mcuProjectItem->files()) {
             // newRoot->addNestedNode(std::make_unique<FileNode>(file, FileType::Project));
             const FileType fileType = (file == projectFilePath())
@@ -304,11 +296,11 @@ void QmlBuildSystem::generateProjectTree()
 }
 
 bool QmlBuildSystem::setFileSettingInProjectFile(const QString &setting,
-                                                 const Utils::FilePath &mainFilePath,
+                                                 const FilePath &mainFilePath,
                                                  const QString &oldFile)
 {
     // make sure to change it also in the qmlproject file
-    const Utils::FilePath qmlProjectFilePath = project()->projectFilePath();
+    const FilePath qmlProjectFilePath = project()->projectFilePath();
     Core::FileChangeBlocker fileChangeBlocker(qmlProjectFilePath);
     const QList<Core::IEditor *> editors = Core::DocumentModel::editorsForFilePath(
                 qmlProjectFilePath);
@@ -320,24 +312,19 @@ bool QmlBuildSystem::setFileSettingInProjectFile(const QString &setting,
                 return false;
     }
 
-    QString fileContent;
-    QString error;
-    Utils::TextFileFormat textFileFormat;
-    const QTextCodec *codec = QTextCodec::codecForName("UTF-8"); // qml files are defined to be utf-8
-    Utils::TextFileFormat::ReadResult readResult = Utils::TextFileFormat::readFile(qmlProjectFilePath,
-                                                                                   codec,
-                                                                                   &fileContent,
-                                                                                   &textFileFormat,
-                                                                                   &error);
-    if (readResult != Utils::TextFileFormat::ReadSuccess) {
-        qWarning() << "Failed to read file" << qmlProjectFilePath << ":" << error;
-    }
+    TextFileFormat textFileFormat;
+    // qml files are defined to be utf-8
+    const TextFileFormat::ReadResult readResult =
+            textFileFormat.readFile(qmlProjectFilePath, TextEncoding::Utf8);
+    if (readResult.code != TextFileFormat::ReadSuccess)
+        qWarning() << "Failed to read file" << qmlProjectFilePath << ":" << readResult.error;
 
     const QString settingQmlCode = setting + ":";
 
-    const Utils::FilePath projectDir = project()->projectFilePath().parentDir();
+    const FilePath projectDir = project()->projectFilePath().parentDir();
     const QString relativePath = mainFilePath.relativeChildPath(projectDir).path();
 
+    QString fileContent = readResult.content;
     if (fileContent.indexOf(settingQmlCode) < 0) {
         QString addedText = QString("\n    %1 \"%2\"\n").arg(settingQmlCode, relativePath);
         auto index = fileContent.lastIndexOf("}");
@@ -353,8 +340,8 @@ bool QmlBuildSystem::setFileSettingInProjectFile(const QString &setting,
         fileContent.replace(match.capturedStart(1), match.capturedLength(1), relativePath);
     }
 
-    if (!textFileFormat.writeFile(qmlProjectFilePath, fileContent, &error))
-        qWarning() << "Failed to write file" << qmlProjectFilePath << ":" << error;
+    if (const Result<> res = textFileFormat.writeFile(qmlProjectFilePath, fileContent); !res)
+        qWarning() << "Failed to write file" << qmlProjectFilePath << ":" << res.error();
 
     refresh(RefreshOptions::Project);
     return true;
@@ -370,7 +357,7 @@ void QmlBuildSystem::setBlockFilesUpdate(bool newBlockFilesUpdate)
     m_blockFilesUpdate = newBlockFilesUpdate;
 }
 
-Utils::FilePath QmlBuildSystem::getStartupQmlFileWithFallback() const
+FilePath QmlBuildSystem::getStartupQmlFileWithFallback() const
 {
     const auto currentProject = project();
 
@@ -383,7 +370,7 @@ Utils::FilePath QmlBuildSystem::getStartupQmlFileWithFallback() const
     if (projectFilePath().endsWith(Constants::fakeProjectName))
         return {};
 
-    const auto getFirstFittingFile = [](const Utils::FilePaths &files) -> Utils::FilePath {
+    const auto getFirstFittingFile = [](const FilePaths &files) -> FilePath {
         for (const auto &file : files) {
             if (file.exists())
                 return file;
@@ -396,15 +383,15 @@ Utils::FilePath QmlBuildSystem::getStartupQmlFileWithFallback() const
 
     //we will check mainUiFile and mainFile twice:
     //first priority if it's ui.qml file, second if it's just a qml file
-    const Utils::FilePath mainUiFile = mainUiFilePath();
+    const FilePath mainUiFile = mainUiFilePath();
     if (mainUiFile.exists() && mainUiFile.completeSuffix() == uiqmlstr)
         return mainUiFile;
 
-    const Utils::FilePath mainQmlFile = mainFilePath();
+    const FilePath mainQmlFile = mainFilePath();
     if (mainQmlFile.exists() && mainQmlFile.completeSuffix() == uiqmlstr)
         return mainQmlFile;
 
-    const Utils::FilePaths uiFiles = currentProject->files([&](const ProjectExplorer::Node *node) {
+    const FilePaths uiFiles = currentProject->files([&](const ProjectExplorer::Node *node) {
         return node->filePath().completeSuffix() == uiqmlstr;
     });
     if (!uiFiles.isEmpty()) {
@@ -420,7 +407,7 @@ Utils::FilePath QmlBuildSystem::getStartupQmlFileWithFallback() const
         return mainQmlFile;
 
     //maybe it's also worth priotizing qml files containing common words like "Screen"?
-    const Utils::FilePaths qmlFiles = currentProject->files([&](const ProjectExplorer::Node *node) {
+    const FilePaths qmlFiles = currentProject->files([&](const ProjectExplorer::Node *node) {
         return node->filePath().completeSuffix() == qmlstr;
     });
     if (!qmlFiles.isEmpty()) {
@@ -429,7 +416,7 @@ Utils::FilePath QmlBuildSystem::getStartupQmlFileWithFallback() const
     }
 
     //if no source files exist in the project, lets try to open the .qmlproject file itself
-    const Utils::FilePath projectFile = projectFilePath();
+    const FilePath projectFile = projectFilePath();
     if (projectFile.exists())
         return projectFile;
 
@@ -441,12 +428,12 @@ QmlBuildSystem *QmlBuildSystem::getStartupBuildSystem()
     return qobject_cast<QmlProjectManager::QmlBuildSystem *>(activeBuildSystemForActiveProject());
 }
 
-void QmlBuildSystem::addQmlProjectModule(const Utils::FilePath &path)
+void QmlBuildSystem::addQmlProjectModule(const FilePath &path)
 {
     m_projectItem->addQmlProjectModule(path.toFSPathString());
 }
 
-Utils::FilePath QmlBuildSystem::mainFilePath() const
+FilePath QmlBuildSystem::mainFilePath() const
 {
     const QString fileName = mainFile();
     if (fileName.isEmpty() || fileName.isNull()) {
@@ -455,7 +442,7 @@ Utils::FilePath QmlBuildSystem::mainFilePath() const
     return projectDirectory().pathAppended(fileName);
 }
 
-Utils::FilePath QmlBuildSystem::mainUiFilePath() const
+FilePath QmlBuildSystem::mainUiFilePath() const
 {
     const QString fileName = mainUiFile();
     if (fileName.isEmpty() || fileName.isNull()) {
@@ -464,18 +451,18 @@ Utils::FilePath QmlBuildSystem::mainUiFilePath() const
     return projectDirectory().pathAppended(fileName);
 }
 
-bool QmlBuildSystem::setMainFileInProjectFile(const Utils::FilePath &newMainFilePath)
+bool QmlBuildSystem::setMainFileInProjectFile(const FilePath &newMainFilePath)
 {
     return setFileSettingInProjectFile("mainFile", newMainFilePath, mainFile());
 }
 
-bool QmlBuildSystem::setMainUiFileInProjectFile(const Utils::FilePath &newMainUiFilePath)
+bool QmlBuildSystem::setMainUiFileInProjectFile(const FilePath &newMainUiFilePath)
 {
     return setMainUiFileInMainFile(newMainUiFilePath)
            && setFileSettingInProjectFile("mainUiFile", newMainUiFilePath, m_projectItem->mainUiFile());
 }
 
-bool QmlBuildSystem::setMainUiFileInMainFile(const Utils::FilePath &newMainUiFilePath)
+bool QmlBuildSystem::setMainUiFileInMainFile(const FilePath &newMainUiFilePath)
 {
     Core::FileChangeBlocker fileChangeBlocker(mainFilePath());
     const QList<Core::IEditor *> editors = Core::DocumentModel::editorsForFilePath(mainFilePath());
@@ -487,30 +474,29 @@ bool QmlBuildSystem::setMainUiFileInMainFile(const Utils::FilePath &newMainUiFil
                 return false;
     }
 
-    QString fileContent;
-    QString error;
-    Utils::TextFileFormat textFileFormat;
-    const QTextCodec *codec = QTextCodec::codecForName("UTF-8"); // qml files are defined to be utf-8
-    if (Utils::TextFileFormat::readFile(mainFilePath(), codec, &fileContent, &textFileFormat, &error)
-            != Utils::TextFileFormat::ReadSuccess) {
-        qWarning() << "Failed to read file" << mainFilePath() << ":" << error;
-    }
+    TextFileFormat textFileFormat;
+    // qml files are defined to be utf-8
+    const TextFileFormat::ReadResult res =
+            textFileFormat.readFile(mainFilePath(), TextEncoding::Utf8);
+    if (res.code != TextFileFormat::ReadSuccess)
+        qWarning() << "Failed to read file" << mainFilePath() << ":" << res.error;
 
     const QString currentMain = QString("%1 {").arg(mainUiFilePath().baseName());
     const QString newMain = QString("%1 {").arg(newMainUiFilePath.baseName());
 
+    QString fileContent = res.content;
     if (fileContent.contains(currentMain))
         fileContent.replace(currentMain, newMain);
 
-    if (!textFileFormat.writeFile(mainFilePath(), fileContent, &error))
-        qWarning() << "Failed to write file" << mainFilePath() << ":" << error;
+    if (const Result<> res = textFileFormat.writeFile(mainFilePath(), fileContent); !res)
+        qWarning() << "Failed to write file" << mainFilePath() << ":" << res.error();
 
     return true;
 }
 
-Utils::FilePath QmlBuildSystem::targetDirectory() const
+FilePath QmlBuildSystem::targetDirectory() const
 {
-    Utils::FilePath result;
+    FilePath result;
     if (RunDeviceTypeKitAspect::deviceTypeId(kit()) == ProjectExplorer::Constants::DESKTOP_DEVICE_TYPE) {
         result = canonicalProjectDir();
     } else if (IDevice::ConstPtr device = RunDeviceKitAspect::device(kit())) {
@@ -520,11 +506,11 @@ Utils::FilePath QmlBuildSystem::targetDirectory() const
     return result;
 }
 
-Utils::FilePath QmlBuildSystem::targetFile(const Utils::FilePath &sourceFile) const
+FilePath QmlBuildSystem::targetFile(const FilePath &sourceFile) const
 {
-    const Utils::FilePath sourceDir = m_projectItem ? m_projectItem->sourceDirectory()
+    const FilePath sourceDir = m_projectItem ? m_projectItem->sourceDirectory()
                                              : canonicalProjectDir();
-    const Utils::FilePath relative = sourceFile.relativePathFrom(sourceDir);
+    const QString relative = sourceFile.relativePathFromDir(sourceDir);
     return targetDirectory().resolvePath(relative);
 }
 
@@ -580,16 +566,15 @@ void QmlBuildSystem::refreshFiles(const QSet<QString> & /*added*/, const QSet<QS
     refresh(RefreshOptions::Files);
     if (!removed.isEmpty()) {
         if (auto modelManager = QmlJS::ModelManagerInterface::instance()) {
-            modelManager->removeFiles(
-                        Utils::transform<QList<Utils::FilePath>>(removed, [](const QString &s) {
-                return Utils::FilePath::fromString(s);
+            modelManager->removeFiles(Utils::transform<FilePaths>(removed, [](const QString &s) {
+                return FilePath::fromString(s);
             }));
         }
     }
     updateDeploymentData();
 }
 
-QVariant QmlBuildSystem::additionalData(Utils::Id id) const
+QVariant QmlBuildSystem::additionalData(Id id) const
 {
     if (id == Constants::customFileSelectorsData)
         return fileSelectors();
@@ -627,20 +612,20 @@ bool QmlBuildSystem::supportsAction(Node *context, ProjectAction action, const N
     return BuildSystem::supportsAction(context, action, node);
 }
 
-bool QmlBuildSystem::addFiles(Node *context, const Utils::FilePaths &filePaths, Utils::FilePaths *)
+bool QmlBuildSystem::addFiles(Node *context, const FilePaths &filePaths, FilePaths *)
 {
     if (!dynamic_cast<Internal::QmlProjectNode *>(context))
         return false;
 
-    Utils::FilePaths toAdd;
-    for (const Utils::FilePath &filePath : filePaths) {
+    FilePaths toAdd;
+    for (const FilePath &filePath : filePaths) {
         if (!m_projectItem->matchesFile(filePath.toUrlishString()))
             toAdd << filePaths;
     }
     return toAdd.isEmpty();
 }
 
-bool QmlBuildSystem::deleteFiles(Node *context, const Utils::FilePaths &filePaths)
+bool QmlBuildSystem::deleteFiles(Node *context, const FilePaths &filePaths)
 {
     if (dynamic_cast<Internal::QmlProjectNode *>(context))
         return true;
@@ -649,8 +634,8 @@ bool QmlBuildSystem::deleteFiles(Node *context, const Utils::FilePaths &filePath
 }
 
 bool QmlBuildSystem::renameFiles(Node *context,
-                                 const Utils::FilePairs &filesToRename,
-                                 Utils::FilePaths *notRenamed)
+                                 const FilePairs &filesToRename,
+                                 FilePaths *notRenamed)
 {
     if (!dynamic_cast<Internal::QmlProjectNode *>(context))
         return BuildSystem::renameFiles(context, filesToRename, notRenamed);
@@ -699,7 +684,7 @@ bool QmlBuildSystem::qt6Project() const
     return m_projectItem->versionQt() == "6";
 }
 
-Utils::EnvironmentItems QmlBuildSystem::environment() const
+EnvironmentItems QmlBuildSystem::environment() const
 {
     return m_projectItem->environment();
 }
@@ -754,7 +739,7 @@ QStringList QmlBuildSystem::importPaths() const
     return m_projectItem->importPaths();
 }
 
-void QmlBuildSystem::addImportPath(const Utils::FilePath &path)
+void QmlBuildSystem::addImportPath(const FilePath &path)
 {
     m_projectItem->addImportPath(path.toFSPathString());
 }
@@ -767,7 +752,7 @@ QStringList QmlBuildSystem::mockImports() const
 QStringList QmlBuildSystem::absoluteImportPaths() const
 {
     return Utils::transform<QStringList>(allImports(), [&](const QString &importPath) {
-        Utils::FilePath filePath = Utils::FilePath::fromString(importPath);
+        FilePath filePath = FilePath::fromString(importPath);
         if (filePath.isAbsolutePath())
             return projectDirectory().resolvePath(importPath).path();
         return (projectDirectory() / importPath).path();
@@ -777,10 +762,9 @@ QStringList QmlBuildSystem::absoluteImportPaths() const
 QStringList QmlBuildSystem::targetImportPaths() const
 {
     return Utils::transform<QStringList>(allImports(), [&](const QString &importPath) {
-        const Utils::FilePath filePath = Utils::FilePath::fromString(importPath);
-        if (filePath.isAbsolutePath()) {
+        const FilePath filePath = FilePath::fromString(importPath);
+        if (filePath.isAbsolutePath())
             return importPath;
-        }
         return (targetDirectory() / importPath).path();
     });
 }
@@ -800,4 +784,28 @@ QString QmlBuildSystem::versionDesignStudio() const
     return m_projectItem->versionDesignStudio();
 }
 
+class QmlBuildConfigurationFactory final : public BuildConfigurationFactory
+{
+public:
+    QmlBuildConfigurationFactory()
+    {
+        registerBuildConfiguration<BuildConfiguration>("QmlBuildConfiguration");
+        setSupportedProjectType(QmlProjectManager::Constants::QML_PROJECT_ID);
+        setSupportedProjectMimeTypeName(Utils::Constants::QMLPROJECT_MIMETYPE);
+        setBuildGenerator(
+            [](const Kit *, const FilePath &projectPath, bool /* forSetup */) -> QList<BuildInfo> {
+                BuildInfo bi;
+                bi.buildDirectory = projectPath;
+                bi.displayName = bi.typeName = msgBuildConfigurationDefault();
+                bi.showBuildConfigs = bi.showBuildDirConfigWidget = false;
+                return {bi};
+            });
+    }
+};
+
+void setupQmlBuildConfiguration()
+{
+    static const QmlBuildConfigurationFactory theQmlBuildConfigurationFactory;
+}
+
 } // namespace QmlProjectManager
