@@ -41,6 +41,10 @@ public:
                                    const QString &manifestPath,
                                    const QString &examplesPath);
 
+    static void openExampleProject(const QString &manifestPath, const QString &name);
+    static std::optional<QString> getExampleDescription(
+        const QString &manifestPath, const QString &name);
+
 signals:
     // content of QtVersion objects with qmake path might have changed
     void qtVersionsChanged(const QList<int> &addedIds, const QList<int> &removedIds = {},
