@@ -12,6 +12,8 @@
 #include "serializer.h"
 #include "stateitem.h"
 
+#include <utils/theme/theme.h>
+
 #include <QDebug>
 #include <QPainter>
 #include <QPainterPath>
@@ -30,8 +32,10 @@ ConnectableItem::ConnectableItem(const QPointF &p, BaseItem *parent)
     setFlag(QGraphicsItem::ItemSendsScenePositionChanges, true);
     setAcceptDrops(true);
 
+    const bool isDark = Utils::creatorTheme()->colorScheme() == Qt::ColorScheme::Dark;
+
     m_selectedPen.setStyle(Qt::DotLine);
-    m_selectedPen.setColor(QColor(0x44, 0x44, 0xed));
+    m_selectedPen.setColor(isDark ? QColor(0x74, 0x74, 0xed) : QColor(0x44, 0x44, 0xed));
     m_selectedPen.setCosmetic(true);
     m_releasedFromParentBrush = QBrush(QColor(0x98, 0x98, 0x98));
 
@@ -43,17 +47,17 @@ ConnectableItem::~ConnectableItem()
 {
     setBlockUpdates(true);
 
-    const QVector<ConnectableItem *> overlappedItems = m_overlappedItems;
+    const QList<ConnectableItem *> overlappedItems = m_overlappedItems;
     for (ConnectableItem *item : overlappedItems)
         item->removeOverlappingItem(this);
     m_overlappedItems.clear();
 
-    const QVector<TransitionItem *> outputTransitions = m_outputTransitions;
+    const QList<TransitionItem *> outputTransitions = m_outputTransitions;
     for (TransitionItem *transition : outputTransitions)
         transition->disconnectItem(this);
     m_outputTransitions.clear();
 
-    const QVector<TransitionItem *> inputTransitions = m_inputTransitions;
+    const QList<TransitionItem *> inputTransitions = m_inputTransitions;
     for (TransitionItem *transition : inputTransitions)
         transition->disconnectItem(this);
     m_inputTransitions.clear();
@@ -737,7 +741,7 @@ void ConnectableItem::removeOverlappingItem(ConnectableItem *item)
 
 void ConnectableItem::checkOverlapping()
 {
-    QVector<ConnectableItem*> overlappedItems;
+    QList<ConnectableItem*> overlappedItems;
     const QList<QGraphicsItem *> items = collidingItems();
     for (QGraphicsItem *it : items) {
         if (it->type() >= InitialStateType && it->parentItem() == parentItem()) {
@@ -770,12 +774,12 @@ bool ConnectableItem::canStartTransition(ItemType type) const
     return true;
 }
 
-QVector<TransitionItem*> ConnectableItem::outputTransitions() const
+QList<TransitionItem*> ConnectableItem::outputTransitions() const
 {
     return m_outputTransitions;
 }
 
-QVector<TransitionItem*> ConnectableItem::inputTransitions() const
+QList<TransitionItem*> ConnectableItem::inputTransitions() const
 {
     return m_inputTransitions;
 }
