@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
@@ -10,8 +10,7 @@ class QColor;
 class QString;
 QT_END_NAMESPACE
 
-namespace Valgrind {
-namespace Internal {
+namespace Valgrind::Internal {
 
 namespace CallgrindHelper
 {
@@ -32,5 +31,4 @@ namespace CallgrindHelper
     QString toPercent(float costs, const QLocale &locale = QLocale());
 }
 
-} // namespace Internal
-} // namespace Valgrind
+} // namespace Valgrind::Internal
