@@ -67,7 +67,7 @@ public:
     ValgrindProcessPrivate(ValgrindProcess *owner)
         : q(owner)
     {
-        connect(&m_taskTreeRunner, &TaskTreeRunner::done, this, [this](DoneWith result) {
+        connect(&m_taskTreeRunner, &SingleTaskTreeRunner::done, this, [this](DoneWith result) {
             emit q->done(toDoneResult(result == DoneWith::Success));
         });
     }
@@ -84,7 +84,7 @@ public:
     QHostAddress m_localServerAddress;
     bool m_useTerminal = false;
 
-    TaskTreeRunner m_taskTreeRunner;
+    SingleTaskTreeRunner m_taskTreeRunner;
 
 signals:
     void stopRequested();
@@ -100,13 +100,13 @@ Group ValgrindProcessPrivate::runRecipe() const
     };
 
     Storage<ValgrindStorage> storage;
-    SingleBarrier xmlBarrier;
+    StoredBarrier xmlBarrier;
 
     const auto isSetupValid = [this, storage, xmlBarrier] {
         ValgrindStorage *storagePtr = storage.activeStorage();
         storagePtr->m_valgrindCommand.setExecutable(m_valgrindCommand.executable());
         if (!m_localServerAddress.isNull()) {
-            Barrier *barrier = xmlBarrier->barrier();
+            Barrier *barrier = xmlBarrier.activeStorage();
             const QString ip = m_localServerAddress.toString();
 
             QTcpServer *xmlServer = new QTcpServer;
@@ -182,8 +182,9 @@ Group ValgrindProcessPrivate::runRecipe() const
         });
         connect(this, &ValgrindProcessPrivate::stopRequested, processPtr, &Process::stop);
     };
-    const auto onProcessDone = [this, storage](const Process &process) {
-        emit q->processErrorReceived(process.errorString(), process.result());
+    const auto onProcessDone = [this, storage](const Process &process, DoneWith result) {
+        if (result == DoneWith::Error)
+            emit q->processErrorReceived(process.errorString(), process.result());
     };
 
     const auto isAddressValid = [this] { return !m_localServerAddress.isNull(); };
@@ -194,8 +195,9 @@ Group ValgrindProcessPrivate::runRecipe() const
         parser.setSocket(storage->m_xmlSocket.release());
     };
 
-    const auto onParserDone = [this](const Parser &parser) {
-        emit q->internalError(parser.errorString());
+    const auto onParserDone = [this](const Parser &parser, DoneWith result) {
+        if (result == DoneWith::Error)
+            emit q->internalError(parser.errorString());
     };
 
     const Group root {
@@ -203,10 +205,10 @@ Group ValgrindProcessPrivate::runRecipe() const
         xmlBarrier,
         If (isSetupValid) >> Then {
             parallel,
-            ProcessTask(onProcessSetup, onProcessDone, CallDoneIf::Error),
+            ProcessTask(onProcessSetup, onProcessDone),
             If (isAddressValid) >> Then {
                 waitForBarrierTask(xmlBarrier),
-                ParserTask(onParserSetup, onParserDone, CallDoneIf::Error)
+                ParserTask(onParserSetup, onParserDone)
             }
         } >> Else {
             errorItem
