@@ -8,13 +8,13 @@
 #include "xmlprotocol/error.h"
 
 #include <coreplugin/dialogs/ioptionspage.h>
-
-#include <debugger/analyzer/analyzericons.h>
-#include <debugger/debuggertr.h>
+#include <coreplugin/documentmanager.h>
 
 #include <utils/algorithm.h>
+#include <utils/fileutils.h>
 #include <utils/layoutbuilder.h>
 #include <utils/qtcassert.h>
+#include <utils/shutdownguard.h>
 #include <utils/utilsicons.h>
 
 #include <QListView>
@@ -58,15 +58,15 @@ void SuppressionAspect::addSuppressionFile(const FilePath &suppression)
 
 void SuppressionAspectPrivate::slotAddSuppression()
 {
-    const FilePaths files =
-            FileUtils::getOpenFilePaths(nullptr,
-                      Tr::tr("Valgrind Suppression Files"),
-                      globalSettings().lastSuppressionDirectory(),
-                      Tr::tr("Valgrind Suppression File (*.supp);;All Files (*)"));
+    const FilePaths files = FileUtils::getOpenFilePaths(
+        Tr::tr("Valgrind Suppression Files"),
+        globalSettings().lastSuppressionDirectory(),
+        Tr::tr("Valgrind Suppression File (*.supp)") + ";;"
+            + Core::DocumentManager::allFilesFilterString());
     //dialog.setHistory(conf->lastSuppressionDialogHistory());
     if (!files.isEmpty()) {
         for (const FilePath &file : files)
-            m_model.appendRow(new QStandardItem(file.toString()));
+            m_model.appendRow(new QStandardItem(file.toUrlishString()));
         globalSettings().lastSuppressionDirectory.setValue(files.at(0).absolutePath());
         //conf->setLastSuppressionDialogHistory(dialog.history());
         if (!isGlobal)
@@ -116,7 +116,7 @@ SuppressionAspect::~SuppressionAspect()
     delete d;
 }
 
-void SuppressionAspect::addToLayout(Layouting::LayoutItem &parent)
+void SuppressionAspect::addToLayoutImpl(Layouting::Layout &parent)
 {
     QTC_CHECK(!d->addEntry);
     QTC_CHECK(!d->removeEntry);
@@ -168,7 +168,7 @@ bool SuppressionAspect::guiToBuffer()
 void SuppressionAspect::bufferToGui()
 {
     d->m_model.clear();
-    for (const FilePath &file : m_buffer)
+    for (const FilePath &file : std::as_const(m_buffer))
         d->m_model.appendRow(new QStandardItem(file.toUserOutput()));
 }
 
@@ -392,24 +392,24 @@ ValgrindSettings::ValgrindSettings(bool global)
         // clang-format on
     });
 
-    if (global) {
+    if (global)
         readSettings();
-    } else {
-        // FIXME: Is this needed?
-        connect(this, &AspectContainer::fromMapFinished, [this] {
-            // FIXME: Update project page e.g. on "Restore Global", aspects
-            // there are 'autoapply', and Aspect::cancel() is normally part of
-            // the 'manual apply' machinery.
-            setAutoApply(false);
-            cancel();
-            setAutoApply(true);
-        });
+}
+
+QString ValgrindSettings::leakCheckOnFinishOptionString() const
+{
+    switch (leakCheckOnFinish()) {
+    case ValgrindSettings::LeakCheckOnFinishNo: return "no";
+    case ValgrindSettings::LeakCheckOnFinishYes: return "full";
+    case ValgrindSettings::LeakCheckOnFinishSummaryOnly:
+    default: return "summary";
     }
+    return {};
 }
 
 ValgrindSettings &globalSettings()
 {
-    static ValgrindSettings theSettings{true};
+    static GuardedObject<ValgrindSettings> theSettings{true};
     return theSettings;
 }
 
@@ -423,8 +423,6 @@ public:
         setId(ANALYZER_VALGRIND_SETTINGS);
         setDisplayName(Tr::tr("Valgrind"));
         setCategory("T.Analyzer");
-        setDisplayCategory(::Debugger::Tr::tr("Analyzer"));
-        setCategoryIconPath(Analyzer::Icons::SETTINGSCATEGORY_ANALYZER);
         setSettingsProvider([] { return &globalSettings(); });
     }
 };
