@@ -1,12 +1,15 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "nicknamedialog.h"
 
+#include "vcsbasetr.h"
+
 #include <utils/fancylineedit.h>
-#include <utils/fileutils.h>
+#include <utils/filepath.h>
 #include <utils/itemviews.h>
 #include <utils/layoutbuilder.h>
+#include <utils/stringutils.h>
 
 #include <QDebug>
 #include <QDialogButtonBox>
@@ -213,33 +216,31 @@ QString NickNameDialog::nickName() const
         if (const QStandardItem *item = m_model->itemFromIndex(sourceIndex))
             return NickNameEntry::nickNameOf(item);
     }
-    return QString();
+    return {};
 }
 
 QStandardItemModel *NickNameDialog::createModel(QObject *parent)
 {
     auto model = new QStandardItemModel(parent);
-    QStringList headers;
-    headers << tr("Name") << tr("Email")
-            << tr("Alias") << tr("Alias email");
+    QStringList headers = {Tr::tr("Name"), Tr::tr("Email"), Tr::tr("Alias"), Tr::tr("Alias email")};
     model->setHorizontalHeaderLabels(headers);
     return model;
 }
 
-bool NickNameDialog::populateModelFromMailCapFile(const FilePath &fileName,
-                                                  QStandardItemModel *model,
-                                                  QString *errorMessage)
+Result<> NickNameDialog::populateModelFromMailCapFile(const FilePath &fileName,
+                                                      QStandardItemModel *model)
 {
     if (const int rowCount = model->rowCount())
         model->removeRows(0, rowCount);
     if (fileName.isEmpty())
-        return true;
-    FileReader reader;
-    if (!reader.fetch(fileName, QIODevice::Text, errorMessage))
-         return false;
+        return ResultOk;
+    const Result<QByteArray> res = fileName.fileContents();
+    if (!res)
+         return ResultError(res.error());
+
     // Split into lines and read
     NickNameEntry entry;
-    const QStringList lines = QString::fromUtf8(reader.data()).trimmed().split(QLatin1Char('\n'));
+    const QStringList lines = QString::fromUtf8(normalizeNewlines(*res)).trimmed().split('\n');
     const int count = lines.size();
     for (int i = 0; i < count; i++) {
         if (entry.parse(lines.at(i))) {
@@ -251,7 +252,7 @@ bool NickNameDialog::populateModelFromMailCapFile(const FilePath &fileName,
         }
     }
     model->sort(0);
-    return true;
+    return ResultOk;
 }
 
 QStringList NickNameDialog::nickNameList(const QStandardItemModel *model)
