@@ -8,8 +8,11 @@
 #include "vcscommand.h"
 #include "vcsenums.h"
 
+#include <solutions/tasking/tasktreerunner.h>
+
 #include <utils/id.h>
 #include <utils/processenums.h>
+#include <utils/textcodec.h>
 
 #include <QStringList>
 #include <QVariant>
@@ -17,22 +20,29 @@
 #include <functional>
 
 QT_BEGIN_NAMESPACE
-class QTextCodec;
 class QToolBar;
 QT_END_NAMESPACE
 
-namespace Utils {
-class Process;
-}
+namespace Utils { class Process; }
 
 namespace VcsBase {
 
-class CommandResult;
 class VcsBaseEditorConfig;
 class VcsBaseEditorWidget;
 
 using CommandHandler = std::function<void(const CommandResult &)>;
 
+class VCSBASE_EXPORT VcsCommandData
+{
+public:
+    Utils::FilePath workingDirectory;
+    QStringList arguments;
+    RunFlags flags = RunFlags::None;
+    Core::ProgressParser progressParser = {};
+    Utils::TextEncoding encoding = {};
+    CommandHandler commandHandler = {};
+};
+
 class VCSBASE_EXPORT VcsBaseClientImpl : public QObject
 {
 public:
@@ -42,26 +52,16 @@ public:
     virtual Utils::FilePath vcsBinary(const Utils::FilePath &forDirectory) const;
     int vcsTimeoutS() const;
 
-    static VcsCommand *createVcsCommand(const Utils::FilePath &defaultWorkingDir,
-                                        const Utils::Environment &environment);
-
     VcsBaseEditorWidget *createVcsEditor(Utils::Id kind, QString title,
-                                         const Utils::FilePath &source, QTextCodec *codec,
+                                         const Utils::FilePath &source,
+                                         const Utils::TextEncoding &encoding,
                                          const char *registerDynamicProperty,
                                          const QString &dynamicPropertyValue) const;
 
-    VcsCommand *createCommand(const Utils::FilePath &workingDirectory,
-                              VcsBaseEditorWidget *editor = nullptr) const;
-
     void setupCommand(Utils::Process &process,
                       const Utils::FilePath &workingDirectory,
                       const QStringList &args) const;
 
-    void enqueueJob(VcsCommand *cmd,
-                    const QStringList &args,
-                    const Utils::FilePath &forDirectory,
-                    const ExitCodeInterpreter &interpreter = {}) const;
-
     virtual Utils::Environment processEnvironment(const Utils::FilePath &appliedTo) const;
 
     // VCS functionality:
@@ -76,24 +76,21 @@ public:
     // Fully synchronous VCS execution (QProcess-based)
     CommandResult vcsSynchronousExec(const Utils::FilePath &workingDir,
                                      const QStringList &args, RunFlags flags = RunFlags::None,
-                                     int timeoutS = -1, QTextCodec *codec = nullptr) const;
+                                     int timeoutS = -1, const Utils::TextEncoding &encoding = {}) const;
     CommandResult vcsSynchronousExec(const Utils::FilePath &workingDir,
                                      const Utils::CommandLine &cmdLine,
                                      RunFlags flags = RunFlags::None,
-                                     int timeoutS = -1, QTextCodec *codec = nullptr) const;
+                                     int timeoutS = -1, const Utils::TextEncoding &encoding = {}) const;
 
-    void vcsExecWithHandler(const Utils::FilePath &workingDirectory,
-                            const QStringList &arguments,
-                            const QObject *context,
-                            const CommandHandler &handler,
-                            RunFlags additionalFlags = RunFlags::None,
-                            QTextCodec *codec = nullptr) const;
-    void vcsExec(const Utils::FilePath &workingDirectory,
-                 const QStringList &arguments,
-                 RunFlags additionalFlags = RunFlags::None) const;
-    void vcsExecWithEditor(const Utils::FilePath &workingDirectory,
-                           const QStringList &arguments,
-                           VcsBaseEditorWidget *editor) const;
+    void executeInEditor(const Utils::FilePath &workingDirectory,
+                         const QStringList &arguments,
+                         VcsBaseEditorWidget *editor) const;
+    void executeInEditor(const Utils::FilePath &workingDirectory,
+                         const Utils::CommandLine &command,
+                         VcsBaseEditorWidget *editor) const;
+    void enqueueTask(const Tasking::ExecutableItem &task);
+    Tasking::ExecutableItem commandTask(const VcsCommandData &data) const;
+    void enqueueCommand(const VcsCommandData &data);
 
 protected:
     void resetCachedVcsInfo(const Utils::FilePath &workingDir);
@@ -104,6 +101,7 @@ private:
     void saveSettings();
 
     VcsBaseSettings *m_baseSettings = nullptr; // Aspect based.
+    Tasking::SequentialTaskTreeRunner m_taskTreeRunner;
 };
 
 class VCSBASE_EXPORT VcsBaseClient : public VcsBaseClientImpl
@@ -130,14 +128,12 @@ public:
                                    const QString &fileName,
                                    const QStringList &extraOptions = {});
     virtual bool synchronousMove(const Utils::FilePath &workingDir,
-                                 const QString &from, const QString &to,
-                                 const QStringList &extraOptions = {});
-    virtual bool synchronousPull(const Utils::FilePath &workingDir,
-                                 const QString &srcLocation,
-                                 const QStringList &extraOptions = {});
-    virtual bool synchronousPush(const Utils::FilePath &workingDir,
-                                 const QString &dstLocation,
+                                 const Utils::FilePath &from, const Utils::FilePath &to,
                                  const QStringList &extraOptions = {});
+    void pull(const Utils::FilePath &workingDir, const QString &srcLocation,
+              const QStringList &extraOptions = {}, const CommandHandler &commandHandler = {});
+    void push(const Utils::FilePath &workingDir, const QString &dstLocation,
+              const QStringList &extraOptions = {});
     void annotate(const Utils::FilePath &workingDir, const QString &file,
                   int lineNumber = -1, const QString &revision = {},
                   const QStringList &extraOptions = {}, int firstLine = -1) override;
@@ -176,7 +172,8 @@ public:
 signals:
     void parsedStatus(const QList<VcsBase::VcsBaseClient::StatusItem> &statusList);
     // Passes on changed signals from VcsJob to Control
-    void changed(const QVariant &v);
+    void repositoryChanged(const Utils::FilePath &repository);
+    void filesChanged(const Utils::FilePaths &files);
 
 public:
     enum VcsCommandTag
