@@ -47,6 +47,7 @@
 #include <tools/hostosinfo.h>
 #include <tools/profile.h>
 #include <tools/settings.h>
+#include <tools/stlutils.h>
 #include <tools/toolchains.h>
 
 #include <QtCore/qdir.h>
@@ -230,12 +231,9 @@ private:
 static bool doesProfileTargetOS(const Profile &profile, const QString &os)
 {
     const auto target = profile.value(QStringLiteral("qbs.targetPlatform"));
-    if (target.isValid()) {
-        return Internal::contains(HostOsInfo::canonicalOSIdentifiers(
-                                      target.toString().toStdString()),
-                                  os.toStdString());
-    }
-    return Internal::contains(HostOsInfo::hostOSIdentifiers(), os.toStdString());
+    if (target.isValid())
+        return Internal::contains(HostOsInfo::canonicalOSIdentifiers(target.toString()), os);
+    return Internal::contains(HostOsInfo::hostOSIdentifiers(), os);
 }
 
 static QString buildProfileName(const QFileInfo &cfi)
@@ -269,11 +267,8 @@ static QStringList buildCompilerNameFilters(const QString &compilerName)
         QLatin1String("*-*-*-*-") + compilerName + QLatin1String("-[1-9]*")
     };
 
-    std::transform(filters.begin(), filters.end(), filters.begin(),
-                   [](const auto &filter) {
-        return HostOsInfo::appendExecutableSuffix(filter);
-    });
-
+    Internal::transform(filters, [](const auto &filter) {
+        return HostOsInfo::appendExecutableSuffix(filter); });
     return filters;
 }
 
@@ -531,7 +526,7 @@ void gccProbe(Settings *settings, std::vector<Profile> &profiles, const QString
 
     std::vector<QFileInfo> candidates;
     const auto filters = buildCompilerNameFilters(compilerName);
-    for (const auto &searchPath : qAsConst(searchPaths)) {
+    for (const auto &searchPath : std::as_const(searchPaths)) {
         const QDir dir(searchPath);
         const QStringList fileNames = dir.entryList(
                     filters, QDir::Files | QDir::Executable);
@@ -579,7 +574,7 @@ void gccProbe(Settings *settings, std::vector<Profile> &profiles, const QString
         });
     }
 
-    for (const auto &candidate : qAsConst(candidates)) {
+    for (const auto &candidate : std::as_const(candidates)) {
         const QString toolchainType = toolchainTypeFromCompilerName(
                     candidate.baseName());
         const QString profileName = buildProfileName(candidate);
