@@ -1,6 +1,7 @@
 /****************************************************************************
 **
 ** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2019 Jochen Ulrich <jochenulrich@t-online.de>
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qbs.
@@ -42,7 +43,7 @@
 
 #include "abstractcommandexecutor.h"
 
-#include <QString>
+#include <QtCore/qstring.h>
 
 namespace qbs {
 class CodeLocation;
@@ -55,8 +56,8 @@ class JsCommandExecutor : public AbstractCommandExecutor
 {
     Q_OBJECT
 public:
-    explicit JsCommandExecutor(const Logger &logger, QObject *parent = 0);
-    ~JsCommandExecutor();
+    explicit JsCommandExecutor(const Logger &logger, QObject *parent = nullptr);
+    ~JsCommandExecutor() override;
 
 signals:
     void startRequested(const JavaScriptCommand *cmd, Transformer *transformer);
@@ -64,9 +65,9 @@ signals:
 private:
     void onJavaScriptCommandFinished();
 
-    void doReportCommandDescription();
-    void doStart();
-    void cancel();
+    void doReportCommandDescription(const QString &productName) override;
+    bool doStart() override;
+    void cancel(const qbs::ErrorInfo &reason) override;
 
     void waitForFinished();
 
