@@ -64,7 +64,7 @@ static QString windowsSystem32Path()
 #ifdef Q_OS_WIN
     wchar_t str[UNICODE_STRING_MAX_CHARS];
     if (SUCCEEDED(SHGetFolderPath(NULL, CSIDL_SYSTEM, NULL, 0, str)))
-        return QString::fromUtf16(reinterpret_cast<ushort*>(str));
+        return QString::fromUtf16(reinterpret_cast<char16_t*>(str));
 #endif
     return {};
 }
@@ -124,14 +124,12 @@ QString VsEnvironmentDetector::findVcVarsAllBat(const MSVC &msvc,
     QString fullPath = dir.absoluteFilePath(path);
     if (dir.exists(path))
         return fullPath;
-    else
-        searchedPaths.push_back(fullPath);
+    searchedPaths.push_back(fullPath);
     path = QStringLiteral("Auxiliary/Build/") + vcvarsallbat;
     fullPath = dir.absoluteFilePath(path);
     if (dir.exists(path))
         return fullPath;
-    else
-        searchedPaths.push_back(fullPath);
+    searchedPaths.push_back(fullPath);
     return {};
 }
 
