@@ -112,7 +112,7 @@ def lineUnderCursor(window):
     return textUnderCursor(window, QTextCursor.StartOfLine, QTextCursor.EndOfLine)
 
 def textUnderCursor(window, fromPos, toPos):
-    cursor = window.textCursor()
+    cursor = textCursorForWidget(window)
     oldposition = cursor.position()
     cursor.movePosition(fromPos)
     cursor.movePosition(toPos, QTextCursor.KeepAnchor)
@@ -120,18 +120,6 @@ def textUnderCursor(window, fromPos, toPos):
     cursor.setPosition(oldposition)
     return str(returnValue)
 
-def which(program):
-    # Don't use spawn.find_executable because it can't find .bat or
-    # .cmd files and doesn't check whether a file is executable (!)
-    if platform.system() in ('Windows', 'Microsoft'):
-        command = "where"
-    else:
-        command = "which"
-    foundPath = getOutputFromCmdline([command, program], acceptedError=1)
-    if foundPath:
-        return foundPath.splitlines()[0]
-    else:
-        return None
 
 # this function removes the user files of given pro file(s)
 # can be called with a single string object or a list of strings holding path(s) to
@@ -140,17 +128,25 @@ def which(program):
 def cleanUpUserFiles(pathsToProFiles=None):
     if pathsToProFiles==None:
         return False
+
+    def __processSinglePathToProjectFile__(pathToProjFile, fileList):
+        dir, fileName = os.path.split(pathToProjFile)
+        fileList.extend(glob.glob(os.path.join(dir, ".qtcreator", fileName + ".user*")))
+        # needed to be kept for a while - remove with QC19?
+        fileList.extend(glob.glob(pathToProjFile + ".user*"))
+
+    fileList = []
     if isString(pathsToProFiles):
-        filelist = glob.glob(pathsToProFiles+".user*")
+        __processSinglePathToProjectFile__(pathsToProFiles, fileList)
     elif isinstance(pathsToProFiles, (list, tuple)):
-        filelist = []
         for p in pathsToProFiles:
-            filelist.extend(glob.glob(p+".user*"))
+            __processSinglePathToProjectFile__(p, fileList)
     else:
         test.fatal("Got an unsupported object.")
         return False
     doneWithoutErrors = True
-    for file in filelist:
+
+    for file in fileList:
         try:
             file = os.path.abspath(file)
             os.remove(file)
