@@ -1,27 +1,5 @@
-############################################################################
-#
 # Copyright (C) 2016 The Qt Company Ltd.
-# Contact: https://www.qt.io/licensing/
-#
-# This file is part of Qt Creator.
-#
-# Commercial License Usage
-# Licensees holding valid commercial Qt licenses may use this file in
-# accordance with the commercial license agreement provided with the
-# Software or, alternatively, in accordance with the terms contained in
-# a written agreement between you and The Qt Company. For licensing terms
-# and conditions see https://www.qt.io/terms-conditions. For further
-# information use the contact form at https://www.qt.io/contact-us.
-#
-# GNU General Public License Usage
-# Alternatively, this file may be used under the terms of the GNU
-# General Public License version 3 as published by the Free Software
-# Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-# included in the packaging of this file. Please review the following
-# information to ensure the GNU General Public License requirements will
-# be met: https://www.gnu.org/licenses/gpl-3.0.html.
-#
-############################################################################
+# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 source("../../shared/qtcreator.py")
 
@@ -29,7 +7,7 @@ focusDocumentPath = "keyinteraction.Resources.keyinteraction\.qrc./keyinteractio
 
 def main():
     target = Targets.DESKTOP_5_14_1_DEFAULT
-    sourceExample = os.path.join(Qt5Path.examplesPath(target), "quick/keyinteraction")
+    sourceExample = os.path.join(QtPath.examplesPath(target), "quick/keyinteraction")
     proFile = "keyinteraction.pro"
     if not neededFilePresent(os.path.join(sourceExample, proFile)):
         return
@@ -37,7 +15,7 @@ def main():
     if not startedWithoutPluginError():
         return
     # add docs to have the correct tool tips
-    addHelpDocumentation([os.path.join(Qt5Path.docsPath(target), "qtquick.qch")])
+    addHelpDocumentation([os.path.join(QtPath.docsPath(target), "qtquick.qch")])
     templateDir = prepareTemplate(sourceExample)
     openQmakeProject(os.path.join(templateDir, proFile), [target])
     openDocument(focusDocumentPath % "focus\\.qml")
@@ -87,7 +65,6 @@ def testRenameId():
         formerTxt = editor.plainText
         originalText = originalTexts.get(file).replace("mainView", "renamedView")
         test.compare(originalText,formerTxt, "Comparing %s" % file.replace("Core.","").replace("\\",""))
-    invokeMenuItem("File","Save All")
 
 def __invokeFindUsage__(filename, line, additionalKeyPresses, expectedCount):
     openDocument(focusDocumentPath % filename)
