@@ -1,5 +1,5 @@
 # Copyright (C) 2016 The Qt Company Ltd.
-# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 source("../../shared/qtcreator.py")
 
@@ -12,10 +12,13 @@ def main():
         mouseClick(waitForObjectItem(":Options_QListView", "Environment"))
         clickOnTab(":Options.qt_tabwidget_tabbar_QTabBar", "Interface")
         languageName = testData.field(lang, "language")
+        locale = QLocale(testData.field(lang, "ISO"))
         if "%1" in languageName:
-            country = str(QLocale.countryToString(QLocale(testData.field(lang, "ISO")).country()))
+            country = str(QLocale.countryToString(locale.country()))
             languageName = languageName.replace("%1", country)
-        selectFromCombo(":User Interface.languageBox_QComboBox", languageName)
+        natName = "%s (%s)" % (str(locale.nativeLanguageName()), str(locale.nativeTerritoryName()))
+        comboLanguageName = natName + " - " + languageName
+        selectFromCombo(":User Interface.languageBox_QComboBox", comboLanguageName)
         clickButton(waitForObject(":Options.OK_QPushButton"))
         clickButton(waitForObject(":Restart required.Later_QPushButton"))
         test.verify(waitFor("not object.exists(':Options_Core::Internal::SettingsDialog')", 5000),
@@ -32,6 +35,5 @@ def main():
         except:
             test.fail("Creator seems to be missing %s translation" % languageName)
             sendEvent("QCloseEvent", ":Qt Creator_Core::Internal::MainWindow")
-        waitForCleanShutdown()
         __removeTestingDir__()
         copySettingsToTmpDir()
