@@ -25,6 +25,7 @@ auto IsItemLibraryEntry(QmlDesigner::TypeId typeId,
                         Utils::SmallStringView iconPath,
                         Utils::SmallStringView category,
                         Utils::SmallStringView import,
+                        QmlDesigner::Storage::ModuleKind moduleKind,
                         Utils::SmallStringView toolTip,
                         Utils::SmallStringView templatePath,
                         PropertiesMatcher propertiesMatcher,
@@ -37,12 +38,31 @@ auto IsItemLibraryEntry(QmlDesigner::TypeId typeId,
                  Field("iconPath", &ItemLibraryEntry::iconPath, iconPath),
                  Field("category", &ItemLibraryEntry::category, category),
                  Field("import", &ItemLibraryEntry::import, import),
+                 Field("moduleKind", &ItemLibraryEntry::moduleKind, moduleKind),
                  Field("toolTip", &ItemLibraryEntry::toolTip, toolTip),
                  Field("templatePath", &ItemLibraryEntry::templatePath, templatePath),
                  Field("properties", &ItemLibraryEntry::properties, propertiesMatcher),
                  Field("extraFilePaths", &ItemLibraryEntry::extraFilePaths, extraFilePathsMatcher));
 }
 
+inline auto IsItemLibraryEntry(QmlDesigner::TypeId typeId,
+                               Utils::SmallStringView typeName,
+                               Utils::SmallStringView name,
+                               Utils::SmallStringView category,
+                               Utils::SmallStringView import,
+                               QmlDesigner::Storage::ModuleKind moduleKind,
+                               QmlDesigner::SourceId componentSourceId)
+{
+    using QmlDesigner::Storage::Info::ItemLibraryEntry;
+    return AllOf(Field("typeId", &ItemLibraryEntry::typeId, typeId),
+                 Field("typeName", &ItemLibraryEntry::typeName, typeName),
+                 Field("name", &ItemLibraryEntry::name, name),
+                 Field("category", &ItemLibraryEntry::category, category),
+                 Field("import", &ItemLibraryEntry::import, import),
+                 Field("moduleKind", &ItemLibraryEntry::moduleKind, moduleKind),
+                 Field("componentSourceId", &ItemLibraryEntry::componentSourceId, componentSourceId));
+}
+
 MATCHER_P3(IsItemLibraryProperty,
            name,
            type,
@@ -58,7 +78,7 @@ MATCHER_P3(IsItemLibraryProperty,
 
 template<typename IconPathMatcher, typename TypeTraitsMatcher, typename HintsJsonMatcher, typename ItemLibraryJsonMatcher>
 auto IsTypeAnnotation(QmlDesigner::SourceId sourceId,
-                      QmlDesigner::SourceId directorySourceId,
+                      QmlDesigner::DirectoryPathId directoryId,
                       Utils::SmallStringView typeName,
                       QmlDesigner::ModuleId moduleId,
                       IconPathMatcher iconPath,
@@ -68,7 +88,7 @@ auto IsTypeAnnotation(QmlDesigner::SourceId sourceId,
 {
     using QmlDesigner::Storage::Synchronization::TypeAnnotation;
     return AllOf(Field("sourceId", &TypeAnnotation::sourceId, sourceId),
-                 Field("directory sourceId", &TypeAnnotation::directorySourceId, directorySourceId),
+                 Field("directory sourceId", &TypeAnnotation::directoryId, directoryId),
                  Field("typeName", &TypeAnnotation::typeName, typeName),
                  Field("moduleId", &TypeAnnotation::moduleId, moduleId),
                  Field("iconPath", &TypeAnnotation::iconPath, iconPath),
