@@ -12,4 +12,8 @@ class ProjectStorageObserverMock : public QmlDesigner::ProjectStorageObserver
 public:
     MOCK_METHOD(void, removedTypeIds, (const QmlDesigner::TypeIds &), (override));
     MOCK_METHOD(void, exportedTypesChanged, (), (override));
+    MOCK_METHOD(void,
+                exportedTypeNamesChanged,
+                (const ExportedTypeNames &added, const ExportedTypeNames &removed),
+                (override));
 };
